# Author: Bryden Fields
# Email: bryden.fields@york.ac.uk

# Initial set-up --------------

library(MASS)
library(labdsv)
library(tidyverse)
library(ggpubr)
library(vegan)
library(grid)
library(lattice)
library(dplyr)

# info can be found here: http://ecology.msu.montana.edu/labdsv/R/labs/lab9/lab9.html
# https://ourcodingclub.github.io/2018/05/04/ordination.html#section6
# https://www.flutterbys.com.au/stats/tut/tut15.1.html
# http://finzi.psych.upenn.edu/R/library/vegan/html/metaMDS.html

#set the working directory to the directory this script is in.
#setwd("~/whatever/folder/you/are/working/from")
setwd("/Users/brydenfields/Documents/Publications/2023_Clovergenotype_paper/scripts")



# nodA - NMDS for Block 1 plots only ------------


# can upload pca matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/abundance_data/clovergeno_noda_pca_matrix_ra.csv")
# rename column 1
names(ra.data)[1] <- 'sample'

# remove Block 2 data.
ra.data <- ra.data %>%
  filter(Block %in% '1')

# add environmental data to separate metadata file
env_data <- ra.data[ ,c("sample", "plot", "F2_plot", "F2", "plot_rep", "Block")]

# remove five end columns to remove metadata
x2 = ncol(ra.data) -5
ra.data2 <- ra.data[,1:x2]

# remove columns if they are all 0 abundance (These would have only been alleles present in Block 2)
# there shouldn't be any to remove
ra.data2 <- ra.data2[, colSums(ra.data2 != 0) > 0]

# make sample names row names
row.names(ra.data2) <- ra.data2$sample
ra.data2$sample <- NULL

#then produce dist matrices.
d = vegdist(ra.data2, method = "bray")

# non-metric MDS can also be calculated with metaMDS as part of the vegan package. 
# To calculate a NMDS, use the nmds() function on a dissimilarity/distance matrix.
# print the distance matrix
d

# In this part, we define a function NMDS.scree() that automatically 
# performs a NMDS for 1-10 dimensions and plots the nr of dimensions vs the stress
NMDS.scree <- function(x) { #where x is the name of the data frame variable
  plot(rep(1, 10), replicate(10, metaMDS(x, autotransform = F, k = 1)$stress), xlim = c(1, 10),ylim = c(0, 0.30), xlab = "# of Dimensions", ylab = "Stress", main = "NMDS stress plot")
  for (i in 1:10) {
    points(rep(i + 1,10),replicate(10, metaMDS(x, autotransform = F, k = i + 1)$stress))
  }
}


# A plot of stress (a measure of goodness-of-fit) vs. dimensionality can be used to assess the proper choice of dimensions. The stress values themselves can be used as an indicator. Stress values >0.2 are generally poor and potentially uninterpretable, whereas values <0.1 are good and <0.05 are excellent. Stress values between 0.1 and 0.2 are useable but some of the distances will be misleading. Finding the inflexion point can instruct the selection of a minimum number of dimensions
# Use the function that we just defined to choose the optimal nr of dimensions
NMDS.scree(d)

# calculate the NMDS using metaMDS to 2 dimensions
# instead of using random starts for finding the best fit of the data, start with the default
# PCO (classical MDS) configuration, so technically the NMDS can't have a worse result than the NMDS.
d.nmds <- metaMDS(d, k = 2)

# print NMDS
d.nmds
# Call:
#   metaMDS(comm = d, k = 2) 
# global Multidimensional Scaling using monoMDS
# Data:     d 
# Distance: bray 
# Dimensions: 2 
# Stress:     0.1127423 
# Stress type 1, weak ties
# Two convergent solutions found after 20 tries
# Scaling: centring, PC rotation 
# Species: scores missing

# produce stress plot of observed dissimilarity vs ordination distance
stressplot(d.nmds)

# plot NMDS data points with labelled samples
plot(d.nmds, type="t")

# assign the point dimensions to x and y variables for the plot. There are upto 2 dimensions calculated which can be plotted. 
nmds_data <- as.data.frame(d.nmds$points)
nmds_data$sample <- row.names(nmds_data)

# match env_data to nmds_data
nmds_data <- merge(nmds_data, env_data, by = 'sample', all.x = T)
row.names(nmds_data) <- nmds_data$sample

# change plot_rep to just 1 or 2
nmds_data$plot_rep <- ifelse(nmds_data$plot_rep == "plot 1", "1", 
                             ifelse(nmds_data$plot_rep == "plot 2", "2", "NA"))

# colourblind palette
unique(nmds_data$F2)
cbPalette <- c("#E69F00", "#56B4E9", "#009E73", "#D55E00", "#CC79A7")

# plot nodA NMDS data
(nmdsplot <- ggplot(nmds_data, aes(MDS1, MDS2, color = F2, fill = F2,
                                   group = F2, shape = plot_rep)) +
    coord_fixed() +
    geom_point(size = 4) +
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour = "Clover cross", fill = "Clover cross", shape = "Plot") +
    # stat_chull(geom = "polygon", alpha = 0.2) +
    stat_conf_ellipse(geom = "polygon", alpha = 0.2, level = 0.95, bary = TRUE) + # 95% confidence ellipses around bary centres
    scale_color_manual(values = cbPalette) +
    scale_fill_manual(values = cbPalette) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/NMDS_nodA_block1_ra_Co1Co2_k2.pdf', plot = nmdsplot, width = 30, height = 25, unit = 'cm')


# A dataset containing environmental data also needs to be made to look at environmental vectors.
# The envfit function is run using the same method above with metaMDS
# https://www.rpubs.com/RGrieger/545184
# https://oliviarata.wordpress.com/2014/04/17/ordinations-in-ggplot2/
# https://stackoverflow.com/questions/14711470/plotting-envfit-vectors-vegan-package-in-ggplot2

# set seed
set.seed(6)

# this fits environmental vectors
d.spp.fit <- envfit(d.nmds, ra.data2, permutations = 999)

# print results
d.spp.fit

# ***VECTORS
# 
# NMDS1    NMDS2     r2 Pr(>r)    
# seq_1  -0.26012 -0.96558 0.7034  0.001 ***
# seq_2   0.99052  0.13740 0.9226  0.001 ***
# seq_3  -0.81447  0.58021 0.8604  0.001 ***
# seq_4  -0.12847  0.99171 0.2014  0.030 *  
# seq_5  -0.09685 -0.99530 0.1338  0.159    
# seq_6   0.12109  0.99264 0.1802  0.073 .  
# seq_7  -0.15286  0.98825 0.2289  0.022 *  
# seq_8   0.00480 -0.99999 0.2316  0.020 *  
# seq_9  -0.86945  0.49403 0.5229  0.001 ***
# seq_10 -0.78777 -0.61597 0.0181  0.788    
# seq_11 -0.21300 -0.97705 0.5595  0.001 ***
# seq_12 -0.86819 -0.49622 0.0432  0.544    
# seq_13 -0.58357 -0.81206 0.1147  0.206    
# seq_14  0.73821  0.67457 0.0686  0.416    
# seq_15  0.39257 -0.91972 0.1666  0.083 .  
# seq_16  0.28081 -0.95976 0.0565  0.468    
# seq_17  0.82674 -0.56258 0.1808  0.076 .  
# seq_18 -0.79963  0.60050 0.3246  0.006 ** 
# seq_19 -0.53364 -0.84571 0.1926  0.058 .  
# seq_20  0.12197  0.99253 0.2377  0.014 *  
# seq_21 -0.86791 -0.49672 0.2868  0.015 *  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# Permutation: free
# Number of permutations: 999


#save species intrinsic values into dataframe
spp.scrs <- as.data.frame(scores(d.spp.fit, display = "vectors")) 

#add species names to dataframe
spp.scrs <- cbind(spp.scrs, Species = rownames(spp.scrs)) 

#add pvalues to dataframe so you can select species which are significant
spp.scrs <- cbind(spp.scrs, pval = d.spp.fit$vectors$pvals) 

#subset data to show species significant at 0.05
sig.spp.scrs <- subset(spp.scrs, pval<=0.05) 

# rename NMDS1 and NMDS2 to MDS1 and MDS2 just so it fits with the previous nmds data graph for continuity
names(sig.spp.scrs)[1:2] <- c('MDS1', 'MDS2')

# Adding significant environmental factors to the plot
# which correlate significantly (p<0.05) with NMDS 1 and 2
# for some reason just adding the required geom_ layers to nmdsplot made before did not work
# simiarly a warning of grid.Call is made - but I think this is just due to the arrows being much bigger. 
(nmdsplot2 <- ggplot(data = nmds_data, aes(MDS1, MDS2)) +
    coord_fixed() +
    geom_point(aes(color = F2, fill = F2, group = F2, shape = plot_rep), size = 4) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover cross", fill="Clover cross", shape = "Plot") +
    #stat_chull(aes(color = F2, fill = F2, group = F2_plot), geom = "polygon", alpha = 0.2) +
    stat_conf_ellipse(aes(color = F2, fill = F2, group = F2), geom = "polygon", alpha = 0.2, level = 0.95, bary = TRUE) + # 95% confidence ellipses around bary centres
    scale_color_manual(values = cbPalette) +
    scale_fill_manual(values = cbPalette) +
    # add vector arrows of significant species
    geom_segment(data = sig.spp.scrs, aes(x = 0, xend=MDS1, y=0, yend=MDS2),
                 arrow = arrow(length = unit(0.25, "cm")),
                 colour = "grey10", lwd=0.3) +
    # add labels for species, use ggrepel::geom_text_repel so that labels do not overlap
    ggrepel::geom_text_repel(data = sig.spp.scrs,
                             aes(x=MDS1, y=MDS2, label = Species),
                             cex = 6, direction = "both", segment.size = 0.25,
                             max.overlaps = getOption("ggrepel.max.overlaps", default = 20)) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/NMDS_nodA_block1_ra_Co1Co2_k2_intrinsicspeciesvariables0.05.pdf', plot = nmdsplot2, width = 30, height = 25, unit = 'cm')



# nodD - NMDS for Block 1 plots only ------------


# remove all data in global environment before starting this section - a refresh start. 

#can upload pca matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/abundance_data/clovergeno_nodd_pca_matrix_ra.csv")
names(ra.data)[1] <- 'sample'

# remove Block 2 data.
ra.data <- ra.data %>%
  filter(Block %in% '1')

# add environmental data to separate metadata file
env_data <- ra.data[ ,c("sample", "plot", "F2_plot", "F2", "plot_rep", "Block")]

# remove five end columns to remove metadata
x2 = ncol(ra.data) -5
ra.data2 <- ra.data[,1:x2]

# remove columns if they are all 0 abundance (These would have only been alleles present in Block 2)
# there shouldn't be any to remove
ra.data2 <- ra.data2[, colSums(ra.data2 != 0) > 0]

# make sample names row names
row.names(ra.data2) <- ra.data2$sample
ra.data2$sample <- NULL

#then produce dist matrices.
d = vegdist(ra.data2, method = "bray")

# non-metric MDS can also be calculated with metaMDS as part of the vegan package. 
# To calculate a NMDS, use the nmds() function on a dissimilarity/distance matrix.
# print the distance matrix
d

# In this part, we define a function NMDS.scree() that automatically 
# performs a NMDS for 1-10 dimensions and plots the nr of dimensions vs the stress
NMDS.scree <- function(x) { #where x is the name of the data frame variable
  plot(rep(1, 10), replicate(10, metaMDS(x, autotransform = F, k = 1)$stress), xlim = c(1, 10),ylim = c(0, 0.30), xlab = "# of Dimensions", ylab = "Stress", main = "NMDS stress plot")
  for (i in 1:10) {
    points(rep(i + 1,10),replicate(10, metaMDS(x, autotransform = F, k = i + 1)$stress))
  }
}


# A plot of stress (a measure of goodness-of-fit) vs. dimensionality can be used to assess the proper choice of dimensions. The stress values themselves can be used as an indicator. Stress values >0.2 are generally poor and potentially uninterpretable, whereas values <0.1 are good and <0.05 are excellent, leaving little danger of misinterpretation. Stress values between 0.1 and 0.2 are useable but some of the distances will be misleading. Finding the inflexion point can instruct the selection of a minimum number of dimensions
# Use the function that we just defined to choose the optimal nr of dimensions
NMDS.scree(d)

# calculate the NMDS using metaMDS to 2 dimensions
# instead of using random starts for finding the best fit of the data, start with the default
# PCO (classical MDS) configuration, so technically the NMDS can't have a worse result than the NMDS.
d.nmds <- metaMDS(d, k = 2)

# print NMDS
d.nmds
# Call:
#   metaMDS(comm = d, k = 2) 
# global Multidimensional Scaling using monoMDS
# Data:     d 
# Distance: bray 
# Dimensions: 2 
# Stress:     0.1181696 
# Stress type 1, weak ties
# Two convergent solutions found after 20 tries
# Scaling: centring, PC rotation 
# Species: scores missing

# produce stress plot of observed dissimilarity vs ordination distance
stressplot(d.nmds)

# plot NMDS data points with labelled samples
plot(d.nmds, type="t")

# assign the point dimensions to x and y variables for the plot. There are upto 2 dimensions calculated which can be plotted. 
nmds_data <- as.data.frame(d.nmds$points)
nmds_data$sample <- row.names(nmds_data)

# match env_data to nmds_data
nmds_data <- merge(nmds_data, env_data, by = 'sample', all.x = T)
row.names(nmds_data) <- nmds_data$sample

# change plot_rep to just 1 or 2
nmds_data$plot_rep <- ifelse(nmds_data$plot_rep == "plot 1", "1", 
                             ifelse(nmds_data$plot_rep == "plot 2", "2", "NA"))

# colourblind palette
unique(nmds_data$F2)
cbPalette <- c("#E69F00", "#56B4E9", "#009E73", "#D55E00", "#CC79A7")

# plot nodD NMDS data
(nmdsplot <- ggplot(nmds_data, aes(MDS1, MDS2, color = F2, fill = F2,
                                   group = F2, shape = plot_rep)) +
    coord_fixed() +
    geom_point(size = 4) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover cross", fill="Clover cross", shape = "Plot") +
    #stat_chull(geom = "polygon", alpha = 0.2) +
    stat_conf_ellipse(geom = "polygon", alpha = 0.2, level = 0.95, bary = TRUE) + # 95% confidence ellipses around bary centres
    scale_color_manual(values = cbPalette) +
    scale_fill_manual(values = cbPalette) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/NMDS_nodD_block1_ra_Co1Co2_k2.pdf', plot = nmdsplot, width = 30, height = 25, unit = 'cm')


# A dataset containing environmental data also needs to be made to look at environmental vectors.
# The envfit function is run using the same method above with metaMDS
# https://www.rpubs.com/RGrieger/545184
# https://oliviarata.wordpress.com/2014/04/17/ordinations-in-ggplot2/
# https://stackoverflow.com/questions/14711470/plotting-envfit-vectors-vegan-package-in-ggplot2

# set seed
set.seed(6)

# this fits environmental vectors
d.spp.fit <- envfit(d.nmds, ra.data2, permutations = 999)

# print results
d.spp.fit

# ***VECTORS
# 
# NMDS1    NMDS2     r2 Pr(>r)    
# seq_1  -0.99971  0.02416 0.9435  0.001 ***
# seq_2   0.47582 -0.87955 0.4422  0.001 ***
# seq_3   0.43474  0.90056 0.8957  0.001 ***
# seq_4   0.36391 -0.93143 0.4119  0.006 ** 
# seq_5   0.89266 -0.45074 0.5276  0.001 ***
# seq_6   0.07419 -0.99724 0.1853  0.098 .  
# seq_7   0.45336 -0.89133 0.4141  0.008 ** 
# seq_8  -0.72248  0.69139 0.0003  0.995    
# seq_9  -0.53297 -0.84613 0.0777  0.226    
# seq_10  0.20782  0.97817 0.1828  0.063 .  
# seq_11 -0.06600  0.99782 0.1262  0.151    
# seq_12  0.38608 -0.92247 0.1063  0.200    
# seq_14  0.60816 -0.79381 0.2047  0.101    
# seq_15  0.98705  0.16040 0.0850  0.301    
# seq_16  0.23004  0.97318 0.5464  0.001 ***
# seq_17  0.38297 -0.92376 0.1239  0.153    
# seq_18 -0.61642 -0.78742 0.0574  0.357    
# seq_19 -0.83615 -0.54850 0.1112  0.196    
# seq_20 -0.09916  0.99507 0.2158  0.036 *  
# seq_21  0.19509 -0.98079 0.2310  0.045 *  
# seq_22  0.84893 -0.52851 0.2954  0.009 ** 
# seq_24 -0.14242  0.98981 0.0444  0.535    
# seq_25  0.97936 -0.20215 0.0312  0.624    
# ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# Permutation: free
# Number of permutations: 999

#save species intrinsic values into dataframe
spp.scrs <- as.data.frame(scores(d.spp.fit, display = "vectors")) 

#add species names to dataframe
spp.scrs <- cbind(spp.scrs, Species = rownames(spp.scrs)) 

#add pvalues to dataframe so you can select species which are significant
spp.scrs <- cbind(spp.scrs, pval = d.spp.fit$vectors$pvals) 

#subset data to show species significant at 0.05
sig.spp.scrs <- subset(spp.scrs, pval<=0.05) 

# rename NMDS1 and NMDS2 to MDS1 and MDS2 just so it fits with the previous nmds data graph for continuity
names(sig.spp.scrs)[1:2] <- c('MDS1', 'MDS2')

# Adding significant environmental factors to the plot
# which correlate significantly (p<0.05) with NMDS 1 and 2
# for some reason just adding the required geom_ layers to nmdsplot made before did not work
# simiarly a warning of grid.Call is made - but I think this is just due to the arrows being much bigger. 
(nmdsplot2 <- ggplot(data = nmds_data, aes(MDS1, MDS2)) +
    coord_fixed() +
    geom_point(aes(color = F2, fill = F2, group = F2, shape = plot_rep), size = 4) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover cross", fill="Clover cross", shape = "Plot") +
    #stat_chull(aes(color = F2, fill = F2, group = F2_plot), geom = "polygon", alpha = 0.2) +
    stat_conf_ellipse(aes(color = F2, fill = F2, group = F2), geom = "polygon", alpha = 0.2, level = 0.95, bary = TRUE) + # 95% confidence ellipses around bary centres
    scale_color_manual(values = cbPalette) +
    scale_fill_manual(values = cbPalette) +
    # add vector arrows of significant species
    geom_segment(data = sig.spp.scrs, aes(x = 0, xend=MDS1, y=0, yend=MDS2),
                 arrow = arrow(length = unit(0.25, "cm")),
                 colour = "grey10", lwd=0.3) +
    # add labels for species, use ggrepel::geom_text_repel so that labels do not overlap
    ggrepel::geom_text_repel(data = sig.spp.scrs,
                             aes(x=MDS1, y=MDS2, label = Species),
                             cex = 6, direction = "both", segment.size = 0.25, 
                             max.overlaps = getOption("ggrepel.max.overlaps", default = 20)) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/NMDS_nodD_block1_ra_Co1Co2_k2_intrinsicspeciesvariables0.05.pdf', plot = nmdsplot2, width = 30, height = 25, unit = 'cm')



# recA - NMDS for Block 1 plots only ------------


# remove all data in global environment before starting this section - a refresh start. 

# can upload pca matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/abundance_data/clovergeno_reca_pca_matrix_ra.csv")
names(ra.data)[1] <- 'sample'

# remove Block 2 data.
ra.data <- ra.data %>%
  filter(Block %in% '1')

# add environmental data to separate metadata file
env_data <- ra.data[ ,c("sample", "plot", "F2_plot", "F2", "plot_rep", "Block")]

# remove five end columns to remove metadata
x2 = ncol(ra.data) -5
ra.data2 <- ra.data[,1:x2]

# remove columns if they are all 0 abundance (These would have only been alleles present in Block 2)
# there shouldn't be any to remove
ra.data2 <- ra.data2[, colSums(ra.data2 != 0) > 0]

# make sample names row names
row.names(ra.data2) <- ra.data2$sample
ra.data2$sample <- NULL

#then produce dist matrices.
d = vegdist(ra.data2, method = "bray")

# non-metric MDS can also be calculated with metaMDS as part of the vegan package. 
# To calculate a NMDS, use the nmds() function on a dissimilarity/distance matrix.
# print the distance matrix
d

# In this part, we define a function NMDS.scree() that automatically 
# performs a NMDS for 1-10 dimensions and plots the nr of dimensions vs the stress
NMDS.scree <- function(x) { #where x is the name of the data frame variable
  plot(rep(1, 10), replicate(10, metaMDS(x, autotransform = F, k = 1)$stress), xlim = c(1, 10),ylim = c(0, 0.30), xlab = "# of Dimensions", ylab = "Stress", main = "NMDS stress plot")
  for (i in 1:10) {
    points(rep(i + 1,10),replicate(10, metaMDS(x, autotransform = F, k = i + 1)$stress))
  }
}


# A plot of stress (a measure of goodness-of-fit) vs. dimensionality can be used to assess the proper choice of dimensions. The stress values themselves can be used as an indicator. Stress values >0.2 are generally poor and potentially uninterpretable, whereas values <0.1 are good and <0.05 are excellent, leaving little danger of misinterpretation. Stress values between 0.1 and 0.2 are useable but some of the distances will be misleading. Finding the inflexion point can instruct the selection of a minimum number of dimensions
# Use the function that we just defined to choose the optimal nr of dimensions
NMDS.scree(d)

# calculate the NMDS using metaMDS to 2 dimensions
# instead of using random starts for finding the best fit of the data, start with the default
# PCO (classical MDS) configuration, so technically the NMDS can't have a worse result than the NMDS.
d.nmds <- metaMDS(d, k = 2)

# print NMDS
d.nmds
# Call:
# metaMDS(comm = d, k = 2) 
# 
# global Multidimensional Scaling using monoMDS
# 
# Data:     d 
# Distance: bray 
# 
# Dimensions: 2 
# Stress:     0.0002183156 
# Stress type 1, weak ties
# Two convergent solutions found after 20 tries
# Scaling: centring, PC rotation 
# Species: scores missing

# produce stress plot of observed dissimilarity vs ordination distance
stressplot(d.nmds)

# plot NMDS data points with labelled samples
plot(d.nmds, type="t")

# assign the point dimensions to x and y variables for the plot. There are upto 2 dimensions calculated which can be plotted. 
nmds_data <- as.data.frame(d.nmds$points)
nmds_data$sample <- row.names(nmds_data)

# match env_data to nmds_data
nmds_data <- merge(nmds_data, env_data, by = 'sample', all.x = T)
row.names(nmds_data) <- nmds_data$sample

# change plot_rep to just 1 or 2
nmds_data$plot_rep <- ifelse(nmds_data$plot_rep == "plot 1", "1", 
                             ifelse(nmds_data$plot_rep == "plot 2", "2", "NA"))

# colourblind palette
unique(nmds_data$F2)
cbPalette <- c("#E69F00", "#56B4E9", "#009E73", "#D55E00", "#CC79A7")

# plot recA NMDS data
(nmdsplot <- ggplot(nmds_data, aes(MDS1, MDS2, color = F2, fill = F2,
                                   group = F2, shape = plot_rep)) +
    #coord_fixed() +
    geom_point(size = 4) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover cross", fill="Clover cross", shape = "Plot") +
    #stat_chull(geom = "polygon", alpha = 0.2) +
    stat_conf_ellipse(geom = "polygon", alpha = 0.2, level = 0.95, bary = TRUE) + # 95% confidence ellipses around bary centres
    scale_color_manual(values = cbPalette) +
    scale_fill_manual(values = cbPalette) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/NMDS_recA_block1_ra_Co1Co2_k2.pdf', plot = nmdsplot, width = 30, height = 25, unit = 'cm')


# A dataset containing environmental data also needs to be made to look at environmental vectors.
# The envfit function is run using the same method above with metaMDS
# https://www.rpubs.com/RGrieger/545184
# https://oliviarata.wordpress.com/2014/04/17/ordinations-in-ggplot2/
# https://stackoverflow.com/questions/14711470/plotting-envfit-vectors-vegan-package-in-ggplot2

# set seed
set.seed(6)

# this fits environmental vectors
d.spp.fit <- envfit(d.nmds, ra.data2, permutations = 999)

# print results
d.spp.fit

# ***VECTORS
# 
# NMDS1      NMDS2     r2 Pr(>r)    
# seq_1  -0.0069466  0.9999800 0.9843  0.001 ***
# seq_2   0.0083114 -0.9999700 0.9872  0.001 ***
# seq_3   0.0007837 -1.0000000 0.3712  0.017 *  
# seq_5   0.0013441 -1.0000000 0.0591  0.235    
# seq_6   0.0067701 -0.9999800 0.1428  0.116    
# seq_7   0.0002703  1.0000000 0.0033  0.952    
# seq_8   0.0127606 -0.9999200 0.1540  0.152    
# seq_10  0.0034534  0.9999900 0.0735  0.277    
# ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# Permutation: free
# Number of permutations: 999


#save species intrinsic values into dataframe
spp.scrs <- as.data.frame(scores(d.spp.fit, display = "vectors")) 

#add species names to dataframe
spp.scrs <- cbind(spp.scrs, Species = rownames(spp.scrs)) 

#add pvalues to dataframe so you can select species which are significant
spp.scrs <- cbind(spp.scrs, pval = d.spp.fit$vectors$pvals) 

#subset data to show species significant at 0.05
sig.spp.scrs <- subset(spp.scrs, pval<=0.05) 

# rename NMDS1 and NMDS2 to MDS1 and MDS2 just so it fits with the previous nmds data graph for continuity
names(sig.spp.scrs)[1:2] <- c('MDS1', 'MDS2')

# Adding significant environmental factors to the plot
# which correlate significantly (p<0.05) with NMDS 1 and 2
# for some reason just adding the required geom_ layers to nmdsplot made before did not work
# simiarly a warning of grid.Call is made - but I think this is just due to the arrows being much bigger. 
(nmdsplot2 <- ggplot(data = nmds_data, aes(MDS1, MDS2)) +
    #coord_fixed() +
    geom_point(aes(color = F2, fill = F2, group = F2, shape = plot_rep), size = 4) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover cross", fill="Clover cross", shape = "Plot") +
    #stat_chull(aes(color = F2, fill = F2, group = F2_plot), geom = "polygon", alpha = 0.2) +
    stat_conf_ellipse(aes(color = F2, fill = F2, group = F2), geom = "polygon", alpha = 0.2, level = 0.95, bary = TRUE) + # 95% confidence ellipses around bary centres
    scale_color_manual(values = cbPalette) +
    scale_fill_manual(values = cbPalette) +
    # add vector arrows of significant species
    geom_segment(data = sig.spp.scrs, aes(x = 0, xend=MDS1, y=0, yend=MDS2),
                 arrow = arrow(length = unit(0.25, "cm")),
                 colour = "grey10", lwd=0.3) +
    # add labels for species, use ggrepel::geom_text_repel so that labels do not overlap
    ggrepel::geom_text_repel(data = sig.spp.scrs,
                             aes(x=MDS1, y=MDS2, label = Species),
                             cex = 6, direction = "both", segment.size = 0.25) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/NMDS_recA_block1_ra_Co1Co2_k2_intrinsicspeciesvariables0.05.pdf', plot = nmdsplot2, width = 30, height = 25, unit = 'cm')



# rpoB - NMDS for Block 1 plots only ------------


# remove all data in global environment before starting this section - a refresh start. 

# can upload pca matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/abundance_data/clovergeno_rpob_pca_matrix_ra.csv")
names(ra.data)[1] <- 'sample'

# remove Block 2 data.
ra.data <- ra.data %>%
  filter(Block %in% '1')

# add environmental data to separate metadata file
env_data <- ra.data[ ,c("sample", "plot", "F2_plot", "F2", "plot_rep", "Block")]

# remove five end columns to remove metadata
x2 = ncol(ra.data) -5
ra.data2 <- ra.data[,1:x2]

# remove columns if they are all 0 abundance (These would have only been alleles present in Block 2)
# there shouldn't be any to remove
ra.data2 <- ra.data2[, colSums(ra.data2 != 0) > 0]

# make sample names row names
row.names(ra.data2) <- ra.data2$sample
ra.data2$sample <- NULL

#then produce dist matrices.
d = vegdist(ra.data2, method = "bray")

# non-metric MDS can also be calculated with metaMDS as part of the vegan package. 
# To calculate a NMDS, use the nmds() function on a dissimilarity/distance matrix.
# print the distance matrix
d

# In this part, we define a function NMDS.scree() that automatically 
# performs a NMDS for 1-10 dimensions and plots the nr of dimensions vs the stress
NMDS.scree <- function(x) { #where x is the name of the data frame variable
  plot(rep(1, 10), replicate(10, metaMDS(x, autotransform = F, k = 1)$stress), xlim = c(1, 10),ylim = c(0, 0.30), xlab = "# of Dimensions", ylab = "Stress", main = "NMDS stress plot")
  for (i in 1:10) {
    points(rep(i + 1,10),replicate(10, metaMDS(x, autotransform = F, k = i + 1)$stress))
  }
}


# A plot of stress (a measure of goodness-of-fit) vs. dimensionality can be used to assess the proper choice of dimensions. The stress values themselves can be used as an indicator. Stress values >0.2 are generally poor and potentially uninterpretable, whereas values <0.1 are good and <0.05 are excellent, leaving little danger of misinterpretation. Stress values between 0.1 and 0.2 are useable but some of the distances will be misleading. Finding the inflexion point can instruct the selection of a minimum number of dimensions
# Use the function that we just defined to choose the optimal nr of dimensions
NMDS.scree(d)

# calculate the NMDS using metaMDS to 2 dimensions
# instead of using random starts for finding the best fit of the data, start with the default
# PCO (classical MDS) configuration, so technically the NMDS can't have a worse result than the NMDS.
d.nmds <- metaMDS(d, k = 2)

# print NMDS
d.nmds
# Call:
# metaMDS(comm = d, k = 2) 
# global Multidimensional Scaling using monoMDS
# Data:     d 
# Distance: bray 
# Dimensions: 2 
# Stress:     0.08020448 
# Stress type 1, weak ties
# Two convergent solutions found after 20 tries
# Scaling: centring, PC rotation 
# Species: scores missing


# produce stress plot of observed dissimilarity vs ordination distance
stressplot(d.nmds)

# plot NMDS data points with labelled samples
plot(d.nmds, type="t")

# assign the point dimensions to x and y variables for the plot. There are upto 2 dimensions calculated which can be plotted. 
nmds_data <- as.data.frame(d.nmds$points)
nmds_data$sample <- row.names(nmds_data)

# match env_data to nmds_data
nmds_data <- merge(nmds_data, env_data, by = 'sample', all.x = T)
row.names(nmds_data) <- nmds_data$sample

# change plot_rep to just 1 or 2
nmds_data$plot_rep <- ifelse(nmds_data$plot_rep == "plot 1", "1", 
                             ifelse(nmds_data$plot_rep == "plot 2", "2", "NA"))

# colourblind palette
unique(nmds_data$F2)
cbPalette <- c("#E69F00", "#56B4E9", "#009E73", "#D55E00", "#CC79A7")

# plot rpoB NMDS data
(nmdsplot <- ggplot(nmds_data, aes(MDS1, MDS2, color = F2, fill = F2,
                                   group = F2, shape = plot_rep)) +
    coord_fixed() +
    geom_point(size = 4) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover cross", fill="Clover cross", shape = "Plot") +
    #stat_chull(geom = "polygon", alpha = 0.2) +
    stat_conf_ellipse(geom = "polygon", alpha = 0.2, level = 0.95, bary = TRUE) + # 95% confidence ellipses around bary centres
    scale_color_manual(values = cbPalette) +
    scale_fill_manual(values = cbPalette) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/NMDS_rpoB_block1_ra_Co1Co2_k2.pdf', plot = nmdsplot, width = 30, height = 25, unit = 'cm')


# A dataset containing environmental data also needs to be made to look at environmental vectors.
# The envfit function is run using the same method above with metaMDS
# https://www.rpubs.com/RGrieger/545184
# https://oliviarata.wordpress.com/2014/04/17/ordinations-in-ggplot2/
# https://stackoverflow.com/questions/14711470/plotting-envfit-vectors-vegan-package-in-ggplot2

# set seed
set.seed(6)

# this fits environmental vectors
d.spp.fit <- envfit(d.nmds, ra.data2, permutations = 999)

# print results
d.spp.fit

# ***VECTORS
# 
# NMDS1    NMDS2     r2 Pr(>r)    
# seq_1   0.65195 -0.75826 0.8347  0.001 ***
# seq_2  -0.96781  0.25170 0.9376  0.001 ***
# seq_3   0.53699  0.84359 0.8897  0.001 ***
# seq_4  -0.45150 -0.89227 0.5974  0.001 ***
# seq_5  -0.19395 -0.98101 0.1856  0.080 .  
# seq_6  -0.53066 -0.84758 0.1674  0.087 .  
# seq_7   0.65992  0.75134 0.0467  0.539    
# seq_8   0.70562  0.70859 0.1648  0.081 .  
# seq_9  -0.46001  0.88791 0.0408  0.560    
# seq_10 -0.83514 -0.55004 0.2455  0.027 *  
# seq_11 -0.29802  0.95456 0.0263  0.710    
# seq_12  0.31113  0.95037 0.2059  0.044 *  
# seq_13 -0.19936 -0.97993 0.0256  0.713    
# seq_14 -0.31305 -0.94974 0.0552  0.420    
# seq_15 -0.73462  0.67848 0.0538  0.449    
# seq_16  0.86801  0.49655 0.0075  0.911    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# Permutation: free
# Number of permutations: 999


#save species intrinsic values into dataframe
spp.scrs <- as.data.frame(scores(d.spp.fit, display = "vectors")) 

#add species names to dataframe
spp.scrs <- cbind(spp.scrs, Species = rownames(spp.scrs)) 

#add pvalues to dataframe so you can select species which are significant
spp.scrs <- cbind(spp.scrs, pval = d.spp.fit$vectors$pvals) 

#subset data to show species significant at 0.05
sig.spp.scrs <- subset(spp.scrs, pval<=0.05) 

# rename NMDS1 and NMDS2 to MDS1 and MDS2 just so it fits with the previous nmds data graph for continuity
names(sig.spp.scrs)[1:2] <- c('MDS1', 'MDS2')

# Adding significant environmental factors to the plot
# which correlate significantly (p<0.05) with NMDS 1 and 2
# for some reason just adding the required geom_ layers to nmdsplot made before did not work
# simiarly a warning of grid.Call is made - but I think this is just due to the arrows being much bigger. 
(nmdsplot2 <- ggplot(data = nmds_data, aes(MDS1, MDS2)) +
    coord_fixed() +
    geom_point(aes(color = F2, fill = F2, group = F2, shape = plot_rep), size = 4) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover cross", fill="Clover cross", shape = "Plot") +
    #stat_chull(aes(color = F2, fill = F2, group = F2_plot), geom = "polygon", alpha = 0.2) +
    stat_conf_ellipse(aes(color = F2, fill = F2, group = F2), geom = "polygon", alpha = 0.2, level = 0.95, bary = TRUE) + # 95% confidence ellipses around bary centres
    scale_color_manual(values = cbPalette) +
    scale_fill_manual(values = cbPalette) +
    # add vector arrows of significant species
    geom_segment(data = sig.spp.scrs, aes(x = 0, xend=MDS1, y=0, yend=MDS2),
                 arrow = arrow(length = unit(0.25, "cm")),
                 colour = "grey10", lwd=0.3) +
    # add labels for species, use ggrepel::geom_text_repel so that labels do not overlap
    ggrepel::geom_text_repel(data = sig.spp.scrs,
                             aes(x=MDS1, y=MDS2, label = Species),
                             cex = 6, direction = "both", segment.size = 0.25) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/NMDS_rpoB_block1_ra_Co1Co2_k2_intrinsicspeciesvariables0.05.pdf', plot = nmdsplot2, width = 30, height = 25, unit = 'cm')



# allgenes - NMDS for Block 1 plots only ------------


# remove all data in global environment before starting this section - a refresh start. 

# can upload already pca matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/abundance_data/clovergeno_allgenes_pca_matrix_withingene_ra.csv")
names(ra.data)[1] <- 'sample'

# remove Block 2 data.
ra.data <- ra.data %>%
  filter(Block %in% '1')

# add environmental data to separate metadata file
env_data <- ra.data[ ,c("sample", "plot", "F2_plot", "F2", "plot_rep", "Block")]

# remove five end columns to remove metadata
x2 = ncol(ra.data) -5
ra.data2 <- ra.data[,1:x2]

# remove columns if they are all 0 abundance (These would have only been alleles present in Block 2)
# there shouldn't be any to remove
ra.data2 <- ra.data2[, colSums(ra.data2 != 0) > 0]

# make sample names row names
row.names(ra.data2) <- ra.data2$sample
ra.data2$sample <- NULL

#then produce dist matrices.
d = vegdist(ra.data2, method = "bray")

# non-metric MDS can also be calculated with metaMDS as part of the vegan package. 
# To calculate a NMDS, use the nmds() function on a dissimilarity/distance matrix.
# print the distance matrix
d

# In this part, we define a function NMDS.scree() that automatically 
# performs a NMDS for 1-10 dimensions and plots the nr of dimensions vs the stress
NMDS.scree <- function(x) { #where x is the name of the data frame variable
  plot(rep(1, 10), replicate(10, metaMDS(x, autotransform = F, k = 1)$stress), xlim = c(1, 10),ylim = c(0, 0.30), xlab = "# of Dimensions", ylab = "Stress", main = "NMDS stress plot")
  for (i in 1:10) {
    points(rep(i + 1,10),replicate(10, metaMDS(x, autotransform = F, k = i + 1)$stress))
  }
}


# A plot of stress (a measure of goodness-of-fit) vs. dimensionality can be used to assess the proper choice of dimensions. The stress values themselves can be used as an indicator. Stress values >0.2 are generally poor and potentially uninterpretable, whereas values <0.1 are good and <0.05 are excellent, leaving little danger of misinterpretation. Stress values between 0.1 and 0.2 are useable but some of the distances will be misleading. Finding the inflexion point can instruct the selection of a minimum number of dimensions
# Use the function that we just defined to choose the optimal nr of dimensions
NMDS.scree(d)

# calculate the NMDS using metaMDS to 2 dimensions
# instead of using random starts for finding the best fit of the data, start with the default
# PCO (classical MDS) configuration, so technically the NMDS can't have a worse result than the NMDS.
d.nmds <- metaMDS(d, k = 2)

# print NMDS
d.nmds
# Call:
# metaMDS(comm = d, k = 2) 
# global Multidimensional Scaling using monoMDS
# Data:     d 
# Distance: bray 
# Dimensions: 2 
# Stress:     0.09086052 
# Stress type 1, weak ties
# Two convergent solutions found after 20 tries
# Scaling: centring, PC rotation 
# Species: scores missing

# produce stress plot of observed dissimilarity vs ordination distance
stressplot(d.nmds)

# plot NMDS data points with labelled samples
plot(d.nmds, type="t")

# assign the point dimensions to x and y variables for the plot. There are upto 2 dimensions calculated which can be plotted. 
nmds_data <- as.data.frame(d.nmds$points)
nmds_data$sample <- row.names(nmds_data)

# match env_data to nmds_data
nmds_data <- merge(nmds_data, env_data, by = 'sample', all.x = T)
row.names(nmds_data) <- nmds_data$sample

# change plot_rep to just 1 or 2
nmds_data$plot_rep <- ifelse(nmds_data$plot_rep == "plot 1", "1", 
                             ifelse(nmds_data$plot_rep == "plot 2", "2", "NA"))

# colourblind palette
unique(nmds_data$F2)
cbPalette <- c("#E69F00", "#56B4E9", "#009E73", "#D55E00", "#CC79A7")

# plot all genes NMDS data
(nmdsplot <- ggplot(nmds_data, aes(MDS1, MDS2, color = F2, fill = F2,
                                   group = F2, shape = plot_rep)) +
    coord_fixed() +
    geom_point(size = 4) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover cross", fill="Clover cross", shape = "Plot") +
    #stat_chull(geom = "polygon", alpha = 0.2) +
    stat_conf_ellipse(geom = "polygon", alpha = 0.2, level = 0.95, bary = TRUE) + # 95% confidence ellipses around bary centres
    scale_color_manual(values = cbPalette) +
    scale_fill_manual(values = cbPalette) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Fig4/NMDS_allgenes_block1_ra_Co1Co2_k2.pdf', plot = nmdsplot, width = 30, height = 25, unit = 'cm')



# allgenes - NMDS for KLONDIKE plots only ------------


# can upload already pca matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/abundance_data/clovergeno_allgenes_pca_matrix_withingene_ra.csv")
names(ra.data)[1] <- 'sample'

# keep Klondike plot data.
ra.data <- ra.data %>%
  filter(F2 %in% 'Klondike')

# add environmental data to separate metadata file
env_data <- ra.data[ ,c("sample", "plot", "F2_plot", "F2", "plot_rep", "Block")]

# remove five end columns to remove metadata
x2 = ncol(ra.data) -5
ra.data2 <- ra.data[,1:x2]

# remove columns if they are all 0 abundance (These would have only been alleles present in Block 2)
# there shouldn't be any to remove
ra.data2 <- ra.data2[, colSums(ra.data2 != 0) > 0]

# make sample names row names
row.names(ra.data2) <- ra.data2$sample
ra.data2$sample <- NULL

#then produce dist matrices.
d = vegdist(ra.data2, method = "bray")

# non-metric MDS can also be calculated with metaMDS as part of the vegan package. 
# To calculate a NMDS, use the nmds() function on a dissimilarity/distance matrix.
# print the distance matrix
d

# In this part, we define a function NMDS.scree() that automatically 
# performs a NMDS for 1-10 dimensions and plots the nr of dimensions vs the stress
NMDS.scree <- function(x) { #where x is the name of the data frame variable
  plot(rep(1, 10), replicate(10, metaMDS(x, autotransform = F, k = 1)$stress), xlim = c(1, 10),ylim = c(0, 0.30), xlab = "# of Dimensions", ylab = "Stress", main = "NMDS stress plot")
  for (i in 1:10) {
    points(rep(i + 1,10),replicate(10, metaMDS(x, autotransform = F, k = i + 1)$stress))
  }
}

# A plot of stress (a measure of goodness-of-fit) vs. dimensionality can be used to assess the proper choice of dimensions. The stress values themselves can be used as an indicator. Stress values >0.2 are generally poor and potentially uninterpretable, whereas values <0.1 are good and <0.05 are excellent, leaving little danger of misinterpretation. Stress values between 0.1 and 0.2 are useable but some of the distances will be misleading. Finding the inflexion point can instruct the selection of a minimum number of dimensions
# Use the function that we just defined to choose the optimal nr of dimensions
NMDS.scree(d)

# calculate the NMDS using metaMDS to 2 dimensions
# instead of using random starts for finding the best fit of the data, start with the default
# PCO (classical MDS) configuration, so technically the NMDS can't have a worse result than the NMDS.
d.nmds <- metaMDS(d, k = 2)

# print NMDS
d.nmds
# Call:
#   metaMDS(comm = d, k = 2) 
# 
# global Multidimensional Scaling using monoMDS
# 
# Data:     d 
# Distance: bray 
# 
# Dimensions: 2 
# Stress:     8.053271e-05 
# Stress type 1, weak ties
# No convergent solutions - best solution after 20 tries
# Scaling: centring, PC rotation 
# Species: scores missing


# produce stress plot of observed dissimilarity vs ordination distance
stressplot(d.nmds)

# plot NMDS data points with labelled samples
plot(d.nmds, type="t")

# assign the point dimensions to x and y variables for the plot. There are upto 2 dimensions calculated which can be plotted. 
nmds_data <- as.data.frame(d.nmds$points)
nmds_data$sample <- row.names(nmds_data)

# match env_data to nmds_data
nmds_data <- merge(nmds_data, env_data, by = 'sample', all.x = T)
row.names(nmds_data) <- nmds_data$sample

# colourblind palette pink colour for klondike plots
unique(nmds_data$F2)
cbPalette <- c("#CC79A7")

# change NMDS plot labels to just individual plots
nmds_data$plot_rep <- ifelse(nmds_data$plot_rep == 'plot 1', 'a (Block 1)', 
                             ifelse(nmds_data$plot_rep == 'plot 2', 'b (Block 1)',
                                    ifelse(nmds_data$plot_rep == 'plot 3', 'c (Block 2)', 'NA')))

# klondike palette
klondikeplotpalette <- gray.colors(3, start = 0.0, end = 0.8, gamma = 2.2)

# plot NMDS data again
(nmdsplot <- ggplot(nmds_data, aes(MDS1, MDS2, color = plot_rep, fill = plot_rep, 
                                   group = plot_rep, shape = plot_rep)) +
    #coord_fixed() +
    geom_point(size = 4) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Klondike\nplot", fill="Klondike\nplot", shape = "Klondike\nplot") +
    #stat_chull(geom = "polygon", alpha = 0.2) +
    stat_conf_ellipse(geom = "polygon", alpha = 0.2, level = 0.95, bary = TRUE) + # 95% confidence ellipses around bary centres
    scale_color_manual(values = klondikeplotpalette) +
    scale_fill_manual(values = klondikeplotpalette) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Fig5/NMDS_allgenes_klondikeonly_ra_Co1Co2_k2.pdf', plot = nmdsplot, width = 30, height = 20, unit = 'cm')

