# Author: Bryden Fields
# Email: bryden.fields@york.ac.uk

# Initial set-up ----------

library(tidyverse)
library(ggplot2)
library(reshape2)
library(plyr)
library(RColorBrewer)
library(vegan)
library(devtools)
library(pairwiseAdonis)

#set the working directory to the directory this script is in.
#setwd("~/whatever/folder/you/are/working/from")
setwd("/Users/brydenfields/Documents/Publications/2023_Clovergenotype_paper/scripts")

source('summarySE.R')



# Genospecies differences for confirmed sequence assignment totals ----------


# read in relative abundance genospecies files for recA and rpob
data_reca_con <- read.csv('../data/raw_data/abundance_data/clovergeno_reca_pca_matrix_ra_genospecies.csv')

data_rpob_con <- read.csv('../data/raw_data/abundance_data/clovergeno_rpob_pca_matrix_ra_genospecies.csv')


# remove the single sequence frequencies and keep only the genospecies totals
data_reca_con <- data_reca_con[,c(1, (ncol(data_reca_con) - 5):ncol(data_reca_con))]
data_rpob_con <- data_rpob_con[,c(1, (ncol(data_rpob_con) - 5):ncol(data_rpob_con))]

# remove block 2 plots
data_reca_con <- data_reca_con[1:30, ]
data_rpob_con <- data_rpob_con[1:30, ]

# melt dataframe into 3 columns; sample name, genospecies, relative abundance
data_reca_con <- melt(data_reca_con, value.name = 'genospecies_reca_ra')
names(data_reca_con)[1:2] <- c('sample', 'genospecies')

data_rpob_con <- melt(data_rpob_con, value.name = 'genospecies_rpob_ra')
names(data_rpob_con)[1:2] <- c('sample', 'genospecies')


# merge the two dataframes together so we get 4 columns; sample name, genospecies, rpoB ra, recA ra.
data_2genes_con <- merge(data_rpob_con, data_reca_con, by = c('sample', 'genospecies'), all.x = T)

# genospecies palette with additional grey colour added.
genoPalette <- c("#466EA9","#EA877A", "#4D9A7A", "#8E569D", "#DA367E", "grey")

# create correlation graph of recA genospecies frequency vs rpoB genospecies frequency
(graph1 <- ggplot(data_2genes_con, aes(genospecies_rpob_ra, genospecies_reca_ra, 
                                    color = genospecies, fill = genospecies)) +
        geom_point(size = 5) +
        xlab(~italic("rpoB")~"frequency") +
        ylab(~italic("recA")~"frequency") + 
        labs(colour = "Genospecies", fill = "Genospecies") +
        scale_color_manual(values = genoPalette) +
        scale_fill_manual(values = genoPalette) +
        guides(colour = guide_legend(override.aes = list(size=9))) +
        theme_bw() +
        theme(legend.title = element_text(size = 35), 
              axis.text.x = element_text(size = 30),
              axis.text.y = element_text(size = 30),
              axis.title=element_text(size = 35),
              legend.text = element_text(size = 30))
)
#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
# ggsave('../data/data_output/figures/Fig4/genospecies_reca_rpob_ra_frequencies_conftotals_block1.pdf', plot = graph1, width = 25, height = 20, unit = 'cm')

# calculate pearsons correlation coefficient.
cor.test(data_2genes_con$genospecies_rpob_ra, data_2genes_con$genospecies_reca_ra, method=c("pearson"))
# t = 41.193, df = 178, p-value < 2.2e-16
# R2 = 0.9513465



# read in metadata csv file
envir <- read.csv('../data/raw_data/abundance_data/plot_environment_data_v3.csv')

# merge metadata with genospecies frequency data
data_2genes_envir_con <- merge(data_2genes_con, envir, by = "sample", all.x = T)


# create mean and summary stats
data_rpobmeans_con <- summarySE(data_2genes_envir_con, measurevar = "genospecies_rpob_ra", 
                            groupvars = c("F2", "genospecies"))
data_recameans_con <- summarySE(data_2genes_envir_con, measurevar = "genospecies_reca_ra", 
                            groupvars = c("F2", "genospecies"))


# make stacked bar charts instead.
# melt data and then combine into one figure
data_2genes_envir_con_melt <- melt(data_2genes_envir_con[c('sample', 'genospecies', 'genospecies_rpob_ra', 'genospecies_reca_ra', 'F2')])

names(data_2genes_envir_con_melt)[4:5] <- c('genospecies_gene_ra', 'ra')

data_2genes_envir_con_melt$genospecies_gene_ra <- factor(data_2genes_envir_con_melt$genospecies_gene_ra,
                                                         levels = c('genospecies_rpob_ra', 'genospecies_reca_ra'), 
                                                         labels = c('rpoB', 'recA'))

(barplot <- ggplot(data_2genes_envir_con_melt, aes(sample, ra, 
                                               fill = genospecies)) +
    geom_bar(position = "stack", stat = 'identity', color = "black") +
    xlab("Samples") +
    ylab("Frequency") + 
    labs(colour = "Genospecies", fill = "Genospecies") +
    scale_color_manual(values = genoPalette) +
    scale_fill_manual(values = genoPalette) +
    facet_grid(genospecies_gene_ra ~ F2, scales = "free_x") +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_blank(),
          axis.ticks.x = element_blank(),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          strip.text = element_text(size = 25),
          strip.text.y = element_text(face = "italic"),
          legend.text = element_text(size = 25))
)
#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Fig4/reca_rpob_genospeciesfrequency_stackbar_block1.pdf', plot = barplot, width = 30, height = 20, unit = 'cm')



# stats between clover genotypes -------------

# calculate statistical significance of genospecies relative frequency differences between clover genotypes
# rpob
mod_rpob_con <- aov(genospecies_rpob_ra ~ F2 * genospecies, data = data_2genes_envir_con)
summary(mod_rpob_con)


# JUST TRIAL 1 DATA RESULTS
#                 Df Sum Sq Mean Sq F value Pr(>F)    
# F2               4  0.000  0.0000    0.00      1    
# genospecies      5 10.479  2.0957  210.43 <2e-16 ***
# F2:genospecies  20  2.042  0.1021   10.25 <2e-16 ***
# Residuals      150  1.494  0.0100                   
# ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


interaction.plot(data_2genes_envir_con$F2, data_2genes_envir_con$genospecies, data_2genes_envir_con$genospecies_rpob_ra)

plot(mod_rpob_con, which = 1)
plot(mod_rpob_con, which = 2)
shapiro.test(mod_rpob_con$residuals)


# TukeyHSD post-hoc to determine exact differences
TukeyHSD(mod_rpob_con)
plot(TukeyHSD(mod_rpob_con), cex.axis = 0.7)
res <- TukeyHSD(mod_rpob_con)
posthoc <- as.data.frame(res$F2)
posthoc$comparison <- row.names(posthoc)
posthoc$section <- 'F2'

posthoc2 <- as.data.frame(res$genospecies)
posthoc2$comparison <- row.names(posthoc2)
posthoc2$section <- 'genospecies'

posthoc3 <- as.data.frame(res$`F2:genospecies`)
posthoc3$comparison <- row.names(posthoc3)
posthoc3$section <- 'interaction'

posthoc_total <- do.call("rbind", list(posthoc, posthoc2, posthoc3))
posthoc_total <- posthoc_total[c(6,5,1,2,3,4)]


write.csv(posthoc_total, file = "../data/data_output/stats_data/genospecies_differences/ANOVA2way_rpob_results_genospeciesclovergeno_conftotals.csv", row.names = F) 

# must manually add the initial ANOVA result output

rm(posthoc)
rm(posthoc2)
rm(posthoc3)
rm(posthoc_total)
rm(res)

# reca
mod_reca_con <- aov(data = data_2genes_envir_con, genospecies_reca_ra ~ F2 * genospecies)
summary(mod_reca_con)

# TRIAL 1 ONLY
#                  Df Sum Sq Mean Sq F value   Pr(>F)    
# F2               4  0.000   0.000   0.000        1    
# genospecies      5 15.821   3.164 365.597  < 2e-16 ***
# F2:genospecies  20  1.237   0.062   7.144 1.05e-13 ***
# Residuals      150  1.298   0.009                     
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


interaction.plot(data_2genes_envir_con$F2, data_2genes_envir_con$genospecies, data_2genes_envir_con$genospecies_reca_ra)

plot(mod_reca_con, which = 1)
plot(mod_reca_con, which = 2)
shapiro.test(mod_reca_con$residuals)


# TukeyHSD post-hoc to determine exact differences
TukeyHSD(mod_reca_con)
plot(TukeyHSD(mod_reca_con), cex.axis = 0.7)
res2 <- TukeyHSD(mod_reca_con)
posthoc <- as.data.frame(res2$F2)
posthoc$comparison <- row.names(posthoc)
posthoc$section <- 'F2'

posthoc2 <- as.data.frame(res2$genospecies)
posthoc2$comparison <- row.names(posthoc2)
posthoc2$section <- 'genospecies'

posthoc3 <- as.data.frame(res2$`F2:genospecies`)
posthoc3$comparison <- row.names(posthoc3)
posthoc3$section <- 'interaction'

posthoc_total <- do.call("rbind", list(posthoc, posthoc2, posthoc3))
posthoc_total <- posthoc_total[c(6,5,1,2,3,4)]


write.csv(posthoc_total, file = "../data/data_output/stats_data/genospecies_differences/ANOVA2way_reca_results_genospeciesclovergeno_conftotals.csv", row.names = F) 

# must mannually add the initial result output



# PERMANOVA with genospecies for clover genotype differences -----------------

# clear data from global environment again before starting this section.

# read in relative abundance genospecies files for recA and rpob
data_reca_con2 <- read.csv('../data/raw_data/abundance_data/clovergeno_reca_pca_matrix_ra_genospecies.csv')

data_rpob_con2 <- read.csv('../data/raw_data/abundance_data/clovergeno_rpob_pca_matrix_ra_genospecies.csv')


# remove the single sequence frequencies and keep only the genospecies totals
data_reca_con2 <- data_reca_con2[,c(1, (ncol(data_reca_con2) - 5):ncol(data_reca_con2))]
data_rpob_con2 <- data_rpob_con2[,c(1, (ncol(data_rpob_con2) - 5):ncol(data_rpob_con2))]

# remove block 2 plots
data_reca_con2 <- data_reca_con2[1:30, ]
data_rpob_con2 <- data_rpob_con2[1:30, ]

# make sample names row names
row.names(data_reca_con2) <- data_reca_con2$sample
row.names(data_rpob_con2) <- data_rpob_con2$sample
data_reca_con2$sample <- NULL
data_rpob_con2$sample <- NULL


# read in the environmental metadata and remove block 2 plots
envir <- read.csv('../data/raw_data/abundance_data/plot_environment_data_xycoordinates.csv', row.names = 1)
envir <- envir[1:30,]

# make the row names for ra.data2 the same as environment
data_reca_con2 <- data_reca_con2[row.names(envir), ]
data_rpob_con2 <- data_rpob_con2[row.names(envir), ]

# Now we can calculate the distance matrix. the “bray” method calculates the Bray-Curtis distance. 
# they produce dist matrices.
bray_reca = vegdist(data_reca_con2, method = "bray")
bray_rpob = vegdist(data_rpob_con2, method = "bray")


# permanova test
# reca
adonis(bray_reca ~ F2 + F2_plot, data = envir)

# Call:
# adonis(formula = bray_reca ~ F2 + F2_plot, data = envir) 
# 
# Permutation: free
# Number of permutations: 999
# 
# Terms added sequentially (first to last)
# 
#           Df SumsOfSqs  MeanSqs F.Model      R2 Pr(>F)   
# F2         4   0.70346 0.175864  5.3407 0.48065  0.003 **
# F2_plot    5   0.10153 0.020307  0.6167 0.06937  0.713   
# Residuals 20   0.65858 0.032929         0.44998          
# Total     29   1.46357                  1.00000          
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# permanova test
# rpob
adonis(bray_rpob ~ F2 + F2_plot, data = envir)
 
# Call:
#         adonis(formula = bray_rpob ~ F2 + F2_plot, data = envir) 
# 
# Permutation: free
# Number of permutations: 999
# 
# Terms added sequentially (first to last)
# 
# Df SumsOfSqs  MeanSqs F.Model      R2 Pr(>F)    
# F2         4   1.13952 0.284881  8.4000 0.56433  0.001 ***
# F2_plot    5   0.20143 0.040286  1.1879 0.09976  0.325    
# Residuals 20   0.67829 0.033914         0.33591           
# Total     29   2.01924                  1.00000           
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


#POST-HOC TEST for Adonis
#see which plots are significant for adonis?

# reca
pairwise.adonis(bray_reca, envir$F2)
#                  pairs Df   SumsOfSqs   F.Model         R2 p.value p.adjusted sig
# 1  Klondike vs Cross 1  1 0.247814858  3.529372 0.26086738   0.110       1.00    
# 2  Klondike vs Cross 2  1 0.544488333  8.529434 0.46031811   0.013       0.13    
# 3  Klondike vs Cross 3  1 0.425407166  6.578517 0.39680973   0.032       0.32    
# 4  Klondike vs Cross 4  1 0.366221674  5.476045 0.35384008   0.069       0.69    
# 5   Cross 1 vs Cross 2  1 0.082341408 10.746164 0.51798319   0.004       0.04   .
# 6   Cross 1 vs Cross 3  1 0.038791828  4.567976 0.31356286   0.015       0.15    
# 7   Cross 1 vs Cross 4  1 0.021737574  2.030972 0.16881194   0.142       1.00    
# 8   Cross 2 vs Cross 3  1 0.009184038  4.345381 0.30291152   0.034       0.34    
# 9   Cross 2 vs Cross 4  1 0.019531451  4.516534 0.31113033   0.042       0.42    
# 10  Cross 3 vs Cross 4  1 0.003126575  0.606612 0.05719188   0.500       1.00    

# rpob
pairwise.adonis(bray_rpob, envir$F2)
#                  pairs Df  SumsOfSqs    F.Model         R2 p.value p.adjusted sig
# 1  Klondike vs Cross 1  1 0.22012004  3.3783919 0.25252601   0.107       1.00    
# 2  Klondike vs Cross 2  1 0.98798005 16.5987195 0.62404205   0.004       0.04   .
# 3  Klondike vs Cross 3  1 0.53435999  8.2448241 0.45189935   0.023       0.23    
# 4  Klondike vs Cross 4  1 0.40252628  5.8539724 0.36924326   0.047       0.47    
# 5   Cross 1 vs Cross 2  1 0.32780469 29.3775256 0.74604804   0.006       0.06    
# 6   Cross 1 vs Cross 3  1 0.09435745  5.7365531 0.36453682   0.012       0.12    
# 7   Cross 1 vs Cross 4  1 0.04996547  2.4495154 0.19675588   0.130       1.00    
# 8   Cross 2 vs Cross 3  1 0.07591594  7.0197341 0.41244676   0.011       0.11    
# 9   Cross 2 vs Cross 4  1 0.14305799  9.6894562 0.49211396   0.002       0.02   .
# 10  Cross 3 vs Cross 4  1 0.01271854  0.6342021 0.05963796   0.440       1.00    

