# Author: Bryden Fields
# Email: bryden.fields@york.ac.uk

# Initial setup ------------------

library(plyr)
library(tidyverse)
library(reshape2)
library(data.table)
library(devtools)
library(ggbiplot)
library(ggfortify)
library(factoextra)
library(ggpubr)
library(vegan)
library(MASS)
library(labdsv)
library(mpmcorrelogram)
library(pheatmap)
library(RColorBrewer)
library(pairwiseAdonis)
library(Hmisc)
library(viridis)

#set the working directory to the directory this script is in.
#setwd("~/whatever/folder/you/are/working/from")
setwd("/Users/brydenfields/Documents/Publications/2023_Clovergenotype_paper/scripts")



#### First convert raw data to relative abundance and log2 --------------------


# read in data (individual genes and all genes combined)
# The original tab files from the MAUI-seq output have been converted into csv and saved to the directory: 
# data/raw_data/greenhouse_experiment

# For each gene matrix do the following code:
data_reca <- read.csv('../data/raw_data/greenhouse_experiment/recA.csv', header = T)
data_rpob <- read.csv('../data/raw_data/greenhouse_experiment/rpoB.csv', header = T)

# Remove rpoB seq4 and seq5 (two least abundant seqs from the rpoB dataset)
# NOTE FOR RPOB
# 5 rpoB sequences were identified with MAUI-seq.
# All strains used as an inoculant matched one of the top 3 rpoB sequences. This is with the exception of 3331-132_C which was not accounted for by any of the 5 rpoB sequences identified by MAUI-seq.
# The two lowest abundant rpoB sequences (seq4 and seq5) did not match to any of the inoculant rhizobia strains. When blasted against all the 196 rhizobia NCHAIN strain genomes, these seq4 and seq5 also did not match with any of these rhizobia strains either. They only showed ~91% identity to NCHAIN strains.
# When seq4 and seq5 were blasted against NCBI GenBank database, the sequences has 100% identity and 100% coverage to agrobacterium. Therefore it is unlikely that these sequences are rhizobia and I have removed them from the dataset.
data_rpob$seq_4 <- NULL
data_rpob$seq_5 <- NULL

# check in dataframe how many columns.
x_reca = ncol(data_reca)
x_rpob = ncol(data_rpob)

# are any samples all 0's in either reca or rpob dataframes?
# are any all 0 in reca?
data_reca[rowSums(data_reca[ ,2:x_reca]) == 0,]
# answer: samples 58 and 90
# are any all 0 in rpob?
data_rpob[rowSums(data_rpob[ ,2:x_rpob]) == 0,]
# answer: sample 90

# Sample ‘58’ (genotype Riesling_1061) has no recA sequences
# Sample ‘90’ (genotype Rabani_0432) has no recA or rpoB sequences
# Therefore, I have decided to remove these samples and all samples that are of these genotypes. This is to enable unbiased comparisons of data (e.g. when looking at differences in diversity between samples there will then always be the same number of nodules/pots sampled for each genotype).
# This means genotype Rabani_0432 samples (four samples which included sample ‘90’) will be removed. As Rabani has 4 genotypes before this removal, this means there will now only be 3 genotypes.
# This also means that all Riesling genotype samples will be removed. There are 2 riesling genotypes and since all Riesling_1061 samples will be removed, there will be no comparison to Riesling_0951. Therefore, as this defeats the point of the analysis these samples will also be removed. 
# As a result, the final analysis will be of 19 varieties, and 41 genotypes.

# remove the samples specified in the above text
data_reca <- data_reca[!data_reca$sample %in% c('7','8','57','58','143','144','181','182', 
                                                '89','90','125','126'), ]
data_rpob <- data_rpob[!data_rpob$sample %in% c('7','8','57','58','143','144','181','182', 
                                                '89','90','125','126'), ]

# add _reca or _rpob suffix to end of sequence column
names(data_reca)[2:x_reca] <- paste(colnames(data_reca[ ,2:x_reca]), "reca", sep = "_")
names(data_rpob)[2:x_rpob] <- paste(colnames(data_rpob[ ,2:x_rpob]), "rpob", sep = "_")

# make data relative abundance
# end row value is the ncolumns
data_reca[ ,2:x_reca] <- sweep(data_reca[ ,2:x_reca], 1, rowSums(data_reca[ ,2:x_reca]), '/') 
rowSums(data_reca[ ,2:x_reca])

data_rpob[ ,2:x_rpob] <- sweep(data_rpob[ ,2:x_rpob], 1, rowSums(data_rpob[ ,2:x_rpob]), '/') 
rowSums(data_rpob[ ,2:x_rpob])

# read in the plot metadata
# make additional environmental variable for explicit pot nested variable
env_data <- read.csv('../data/raw_data/greenhouse_experiment/sample_overview_BF_v2.csv')

env_data$variety_genotype <- paste(env_data$variety, env_data$genotype, sep = ' ')
env_data$variety_genotype_pot <- paste(env_data$variety_genotype, env_data$pot, sep = ' ')

# merge env_data with the abundance data so we can group samples by plots.
data_reca <- left_join(data_reca, env_data, by = 'sample')

data_rpob <- left_join(data_rpob, env_data, by = 'sample')

# how many unique varieties?
length(unique(data_reca$variety))
# how many unique genotypes?
length(unique(data_reca$clover))

# calculate the mean relative abundances for each pot.
data_reca <- aggregate(data_reca[ ,2:x_reca], list(data_reca$variety_genotype_pot), mean)
data_reca <- left_join(data_reca, unique(env_data[,c("table", "placement", "clover", 
                                              "barcode", "variety", "genotype", 
                                              "pot", "variety_genotype", "variety_genotype_pot")]), 
                       by = c('Group.1' = 'variety_genotype_pot'))
names(data_reca)[1] <- 'variety_genotype_pot'

data_rpob <- aggregate(data_rpob[ ,2:x_rpob], list(data_rpob$variety_genotype_pot), mean)
data_rpob <- left_join(data_rpob, unique(env_data[,c("table", "placement", "clover", 
                                              "barcode", "variety", "genotype", 
                                              "pot", "variety_genotype", "variety_genotype_pot")]), 
                       by = c('Group.1' = 'variety_genotype_pot'))
names(data_rpob)[1] <- 'variety_genotype_pot'

# combine the rpoB and recA data to create bothgenes dataframe
bothgenes <- left_join(data_reca[ ,1:x_reca], data_rpob, by = 'variety_genotype_pot')

# copy data for log transformation relative abundance calculation
data_reca_log <- data_reca
data_rpob_log <- data_rpob

# For the log data, Replace 0 with one decimal place lower number (because for log transformation can't have 0 for pca)
# this number was calculated from the allgenes dataframe (to see what the lowest number was so they all)
# have the same "0" equivilent value #reca = 2.797359e-05, #rpob = 0.000110011.
#test <- data_rpob[, 2:x_rpob]
#min( test[test!=min(test)] )

# lowest decimal for all genes should be (-5 as lowest is -4)
data_reca_log[data_reca_log == 0] <- 0.00001
data_rpob_log[data_rpob_log == 0] <- 0.00001

# log transform data.
# end row value is the ncolumns
data_reca_log[ ,2:x_reca] <- log10(data_reca_log[ ,2:x_reca])
data_rpob_log[ ,2:x_rpob] <- log10(data_rpob_log[ ,2:x_rpob])

# combine to make both genes for log data
bothgenes_log <- left_join(data_reca_log[ ,1:x_reca], data_rpob_log, by = 'variety_genotype_pot')

# save relative abundance file 
# CHANGE DEPENDING ON THE GENE OF INTEREST
write.csv(bothgenes, file = "../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_bothgenes_ra_matrix.csv", row.names = F)
write.csv(data_reca, file = "../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_reca_ra_matrix.csv", row.names = F)
write.csv(data_rpob, file = "../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_rpob_ra_matrix.csv", row.names = F)

#save csv for log transformed data
# CHANGE DEPENDING ON THE GENE OF INTEREST
write.csv(bothgenes_log, file = "../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_bothgenes_ra_matrix_logtrans.csv", row.names = F)
write.csv(data_reca_log, file = "../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_reca_ra_matrix_logtrans.csv", row.names = F)
write.csv(data_rpob_log, file = "../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_rpob_ra_matrix_logtrans.csv", row.names = F)


# remove everything from global environment so that we can start afresh in the following analysis sections, as we do not need all of these files now.

rm(list = ls())



#### initially check: seq4 and seq5 abundances ----------------


# read in rpoB gene matrix:
data_rpob <- read.csv('../data/raw_data/greenhouse_experiment/rpoB.csv', header = T)

#check in dataframe how many columns.
x_rpob = ncol(data_rpob)

# are any samples all 0's in either reca or rpob dataframes?
# are any all 0 in rpob?
data_rpob[rowSums(data_rpob[ ,2:x_rpob]) == 0,]
# answer: sample 90

# •	Sample ‘58’ (genotype Riesling_1061) has no recA sequences
# •	Sample ‘90’ (genotype Rabani_0432) has no recA or rpoB sequences
# •	Therefore, I have decided to remove these samples and all samples that are of these genotypes. This is to enable unbiased comparisons of data (e.g. when looking at differences in diversity between samples there will then always be the same number of nodules/pots sampled for each genotype).
# o	This means genotype Rabani_0432 samples (four samples which included sample ‘90’) will be removed. As Rabani has 4 genotypes before this removal, this means there will now only be 3 genotypes.
# o	This also means that all Riesling genotype samples will be removed. There are 2 riesling genotypes and since all Riesling_1061 samples will be removed, there will be no comparison to Riesling_0951. Therefore, as this defeats the point of the analysis these samples will also be removed. 
# •	As a result, the final analysis will be of 19 varieties, and 41 genotypes.

# remove them
data_rpob <- data_rpob[!data_rpob$sample %in% c('7','8','57','58','143','144','181','182', 
                                                '89','90','125','126'), ]


# add _rpob suffix to end of sequence column
names(data_rpob)[2:x_rpob] <- paste(colnames(data_rpob[ ,2:x_rpob]), "rpob", sep = "_")

# make data relative abundance
# end row value is the ncolumns
data_rpob[ ,2:x_rpob] <- sweep(data_rpob[ ,2:x_rpob], 1, rowSums(data_rpob[ ,2:x_rpob]), '/') 
rowSums(data_rpob[ ,2:x_rpob])

# read in the plot metadata
# make additional environmental variable for explicit pot nested variable
env_data <- read.csv('../data/raw_data/greenhouse_experiment/sample_overview_BF_v2.csv')

env_data$variety_genotype <- paste(env_data$variety, env_data$genotype, sep = ' ')
env_data$variety_genotype_pot <- paste(env_data$variety_genotype, env_data$pot, sep = ' ')

# merge with the data file so we can group samples by plots.
data_rpob <- left_join(data_rpob, env_data, by = 'sample')

# how many unique varieties?
length(unique(data_rpob$variety))
# how many unique genotypes?
length(unique(data_rpob$clover))

# calculate the mean relative abundances for each pot.
data_rpob <- aggregate(data_rpob[ ,2:x_rpob], list(data_rpob$variety_genotype_pot), mean)
data_rpob <- left_join(data_rpob, unique(env_data[,c("table", "placement", "clover", 
                                                     "barcode", "variety", "genotype", 
                                                     "pot", "variety_genotype", "variety_genotype_pot")]), 
                       by = c('Group.1' = 'variety_genotype_pot'))
names(data_rpob)[1] <- 'variety_genotype_pot'

# what is the maximum % relative abundance of seq4 and seq5 in a sample?
max(data_rpob$seq_4_rpob)
# [1] 0.02973397 (2.97%)
max(data_rpob$seq_5_rpob)
# [1] 0.02481995 (2.48%)

# what is the mean % relative abundance of seq4 and seq5 across samples?
mean(data_rpob$seq_4_rpob)
# [1] 0.0022784 (0.23%)
mean(data_rpob$seq_5_rpob)
# [1] 0.001799494 (0.18%)

# total number of pots
nrow(data_rpob)
# [1] 82
# number of pots with seq4 or seq5.
nrow(data_rpob[data_rpob$seq_4_rpob != '0',])
#[1] 53 (64.63%)
nrow(data_rpob[data_rpob$seq_5_rpob != '0',])
#[1] 49 (59.76%)

# filter for samples that have seq4 or seq5 above 1%
high_seq45_samples <- data_rpob[data_rpob$seq_4_rpob > '0.01' | data_rpob$seq_5_rpob > '0.01', ]



# Presence/Absence among genotypes analysis ----------------


# clear all data from the global environment before starting this section afresh. 

# change relative abundance to presence/absence 
# read in ra file rather than ra_logtrans
data <- read.csv('../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_bothgenes_ra_matrix.csv', row.names = 1)

# remove some of environment data so only keep only clover/variety column
data_subset <- subset(data, select=-c(table, placement, barcode, clover, variety, genotype, pot))

# combine data that are same genotype
data_subset2 <- aggregate(. ~ variety_genotype, data = data_subset, sum, na.rm=TRUE)

# save variety_genotype order to a vector
varietygenotypeorder <- data_subset2$variety_genotype

# convert anything >0 to 1. Now its a presence absence matrix
data_subset2[2:11][data_subset2[2:11] > 0] <- 1

# melt the data into long format
data_subset3 <- melt(data_subset2)

# rename columns
names(data_subset3)[2:3] <- c('sequence', 'PA')

# make Presence/Absence a factor
data_subset3$PA <- factor(data_subset3$PA, levels = c("0", "1"),
                          labels = c("Absent", "Present"))

# add new column for gene name (rpob or reca)
data_subset3$gene <- gsub(".*_","",data_subset3$sequence)

# edit gene order/format
data_subset3$gene <- factor(data_subset3$gene, levels = c('rpob', 'reca'),
                            labels = c('rpoB', 'recA'))

# order for the variety_genotypes
data_subset3$variety_genotype <- factor(data_subset3$variety_genotype, levels = rev(varietygenotypeorder))

# Heatmap   
(heatmap <-  ggplot(data_subset3, aes(x = sequence, y = variety_genotype, fill = PA)) + 
    geom_tile() +
    scale_y_discrete(expand=c(0,0)) +
    scale_x_discrete(expand=c(0,0)) +
    scale_fill_manual(values = c('grey50', 'black')) +
    facet_grid(~gene, switch = "x", scales = "free_x", space = "free_x") + 
    labs(x="Gene", y = "Clover variety and genotype", fill = "Allele\nPresence") +
    theme_bw() +
    theme(axis.text.x=element_blank(),
          axis.ticks.x=element_blank(),
          axis.ticks.y=element_blank(),
          axis.title=element_text(size = 25),
          axis.text.y = element_text(size = 15),
          legend.text = element_text(size = 20),
          legend.title = element_text(size = 25),
          strip.text.x = element_text(size = 20),
          strip.text = element_text(face = "italic"),
          legend.key.size = unit(1, "cm"))
)

#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/greenhouse_bothgenes_seqPA_heatmap.pdf', plot = heatmap, width = 19, height = 25, unit = 'cm')



# Relative abundance heatmap -----------------


# clear all data from the global environment before starting this section afresh. 

# # read in relative abundance counts 
data <-  read.csv('../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_bothgenes_ra_matrix_logtrans.csv')

# rename sample column name
names(data)[1] <- "sampleID"

# Sort by columns name [z] then [x]
data <- data[with(data, order(clover, pot)),]

# save the order of these sampleIDs 
sampleID_order <- data$sampleID

# save original dataframe
data_original <- data

# remove the env data at the end
data_ncol = ncol(data) -8 
data <- data[,1:data_ncol]

# melt the data into a long format for graph
data_long <- melt(data, id='sampleID')

# make the ra log value numerical
data_long$value <- as.numeric(data_long$value)

# add new column for gene name (rpob or reca)
data_long$gene <- gsub(".*_","",data_long$variable)

# change labels for gene names
data_long$gene <- factor(data_long$gene, levels = c('rpob', 'reca'),
                       labels = c('rpoB', 'recA'))

# make sampleID factor
data_long$sampleID <- factor(data_long$sampleID, levels = rev(sampleID_order))

# Heatmap   
(heatmap <-  ggplot(data_long, aes(x=variable, y=sampleID, fill=value)) + 
    geom_tile() +
    scale_y_discrete(expand=c(0,0)) +
    scale_x_discrete(expand=c(0,0)) +
    facet_grid(~gene, switch = "x", scales = "free_x", space = "free_x") + 
    labs(x="Gene", y = "Variety, Genotype number, Pot number", fill = 'Allele\nAbundance') +
    scale_fill_viridis() +
    theme_bw() +
    theme(axis.text.x=element_blank(),
          axis.ticks.x=element_blank(),
          axis.ticks.y=element_blank(),
          axis.title=element_text(size = 25),
          axis.text.y = element_text(size = 10),
          legend.text = element_text(size = 20),
          legend.title = element_text(size = 25),
          legend.key.size = unit(1, "cm"),
          strip.text.x = element_text(size = 14),
          strip.text = element_text(face = "italic"),
          plot.margin = margin(1,3,1,5, "cm")) 
)

#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/greenhouse_bothgenes_ra_log10trans_heatmap.pdf', plot = heatmap, width = 24, height = 60, unit = 'cm')



# Bray-curtis Heatmaps / PERMANOVA ---------------


# clear all data from the global environment before starting this section afresh. 

#can upload pca matrix ready version for the beta diversity analysis.
# UPLOAD DIFFERENT INPUT FILE (BOTHGENES, RECA, RPOB) as required.
ra.data <- read.csv("../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_bothgenes_ra_matrix.csv")
# ra.data <- read.csv('../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_reca_ra_matrix.csv')
# ra.data <- read.csv('../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_rpob_ra_matrix.csv')

#create categories to colour for heatmap from envir dataframe
env_data <- ra.data[ ,c("variety", "genotype", "pot", "variety_genotype", "variety_genotype_pot")]
row.names(env_data) <- env_data$variety_genotype_pot
env_data$variety_genotype_pot <- NULL

# remove envdata columns
maxcol = ncol(ra.data) -8
ra.data <- ra.data[,1:maxcol]

# make sample names row names
row.names(ra.data) <- ra.data$variety_genotype_pot
ra.data$variety_genotype_pot <- NULL

# reorder env_data rows. then use this to reorder rows in ra_matrix for distance calculation.
env_data <- env_data[with(env_data, order(variety, genotype, pot)), ]

# make row names in ra.data2 match those in env_data. 
ra.data <- ra.data[c(row.names(env_data)), ]

# to do the vegan permanova will need to make sure I have the distance matrices. 
# make the bray curtis and sorensens dist matrices.
bray_matrix <- vegdist(ra.data, method = "bray")

# betadisperser: FOR BOTH GENES ANALYSIS ONLY (NOT INDIVIDUAL GENES)
# tests homogeneity of dispersion among groups which is an assumption of permanova
# https://rfunctions.blogspot.com/2019/03/betadisper-and-adonis-homogeneity-of.html
mod_var <- betadisper(bray_matrix, env_data$variety)
mod_geno <- betadisper(bray_matrix, env_data$genotype)

anova(mod_var)
# Analysis of Variance Table
# 
# Response: Distances
#           Df Sum Sq  Mean Sq F value  Pr(>F)  
# Groups    18 0.5418 0.030100  1.7234 0.05842
# Residuals 63 1.1003 0.017466                  

anova(mod_geno)
# Analysis of Variance Table
# 
# Response: Distances
#           Df  Sum Sq  Mean Sq F value Pr(>F)
# Groups     2 0.06997 0.034983  1.4469 0.2415
# Residuals 79 1.91009 0.024178 


# permanova test FOR BOTH GENES ANALYSIS ONLY (NOT INDIVIDUAL GENES)
adonis(bray_matrix ~ variety + variety_genotype, data = env_data)


# Call:
# adonis(formula = bray_matrix ~ variety + variety_genotype, data = env_data) 
# 
# Permutation: free
# Number of permutations: 999
# 
# Terms added sequentially (first to last)
# 
#                  Df SumsOfSqs  MeanSqs F.Model      R2 Pr(>F)    
# variety          18    2.3048 0.128042  4.0114 0.37587  0.001 ***
# variety_genotype 22    2.5184 0.114472  3.5863 0.41071  0.001 ***
# Residuals        41    1.3087 0.031919         0.21343           
# Total            81    6.1318                  1.00000           
# ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# So our groups present homogeneity among group dispersions (compositions vary similarly) while having significantly different compositions.



# heatmap colour palette
my_palette <- colorRampPalette(rev(brewer.pal(9,"Reds")))(256)

# when setting colour palettes we must set the seed so they are all the same
set.seed(6)

# number of unique hosts (so know for colour palette)
length(unique(env_data$variety))
# [1] 19
library(Polychrome)
# build-in color palette
varietycol <-  setNames(createPalette(19,  c("#ff0000", "#00ff00", "#0000ff")), 
                        sort(unique(env_data$variety)))

#add plot levels and associate colours
genotypecol <- c("grey10", "grey50", "grey80")
env_data$genotype <- factor(env_data$genotype, labels = c("1", "2", "3"))
names(genotypecol) <- levels(env_data$genotype)
genotypecol

# Add to a list, where names match those in factors dataframe
AnnColour <- list(
  genotype = genotypecol,
  variety = varietycol
)

#check colour associations
AnnColour

# produce heatmap
pheatmap(bray_matrix,
         cluster_rows = F, cluster_cols = F,
         gaps_row = c(4,8,14,20,24,28,32,36,40,44,48,52,56,60,64,68,72,78),
         gaps_col = c(4,8,14,20,24,28,32,36,40,44,48,52,56,60,64,68,72,78),
         col = my_palette,
         annotation_row = env_data[, c('genotype', 'variety'), drop=FALSE],
         annotation_col = env_data[, c('genotype', 'variety'), drop=FALSE],
         annotation_colors = AnnColour,
         #labels_row = envir$sample0,
         #labels_col = envir$sample0,
         breaks = seq(0, 1, by = 0.00390625), # 1 / 256
         cellwidth = 10, cellheight = 10,
         filename = "../data/data_output/figures/Supplementary/greenhouse_braycurtis_bothgenes_heatmap.pdf"
         # filename = "../data/data_output/figures/Supplementary/greenhouse_braycurtis_reca_heatmap.pdf"
         # filename = "../data/data_output/figures/Supplementary/greenhouse_braycurtis_rpob_heatmap.pdf"
)



# NMDS plot: reca ------------


# remove all data in global environment before starting this section - a refresh start. 

#can upload already matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_reca_ra_matrix.csv")

#create categories to colour for heatmap from envir dataframe
env_data <- ra.data[ ,c("variety", "genotype", "pot", "variety_genotype", "variety_genotype_pot")]
row.names(env_data) <- env_data$variety_genotype_pot
env_data$variety_genotype_pot <- NULL

# remove envdata columns
maxcol = ncol(ra.data) -8
ra.data <- ra.data[,1:maxcol]

# make sample names row names
row.names(ra.data) <- ra.data$variety_genotype_pot
ra.data$variety_genotype_pot <- NULL

# reorder env_data rows. then use this to reorder rows in ra_matrix for distance calculation.
env_data <- env_data[with(env_data, order(variety, genotype, pot)), ]

# make row names in ra.data2 match those in env_data. 
ra.data <- ra.data[c(row.names(env_data)), ]

#then produce dist matrices.
d <-  vegdist(ra.data, method = "bray")

# non-metric MDS can also be calculated with metaMDS as part of the vegan package. 
# To calculate a NMDS, use the nmds() function on a dissimilarity/distance matrix.
# print the distance matrix
d

# In this part, we define a function NMDS.scree() that automatically 
# performs a NMDS for 1-10 dimensions and plots the nr of dimensions vs the stress
NMDS.scree <- function(x) { #where x is the name of the data frame variable
  plot(rep(1, 10), replicate(10, metaMDS(x, autotransform = F, k = 1)$stress), xlim = c(1, 10),ylim = c(0, 0.30), xlab = "# of Dimensions", ylab = "Stress", main = "NMDS stress plot")
  for (i in 1:10) {
    points(rep(i + 1,10),replicate(10, metaMDS(x, autotransform = F, k = i + 1)$stress))
  }
}


# A plot of stress (a measure of goodness-of-fit) vs. dimensionality can be used to assess the proper choice of dimensions. The stress values themselves can be used as an indicator. Stress values >0.2 are generally poor and potentially uninterpretable, whereas values <0.1 are good and <0.05 are excellent, leaving little danger of misinterpretation. Stress values between 0.1 and 0.2 are useable but some of the distances will be misleading. Finding the inflexion point can instruct the selection of a minimum number of dimensions
# Use the function that we just defined to choose the optimal nr of dimensions
NMDS.scree(d)

# calculate the NMDS using metaMDS to 2 dimensions
# instead of using random starts for finding the best fit of the data, start with the default
# PCO (classical MDS) configuration, so technically the NMDS can't have a worse result than the NMDS.
d.nmds <- metaMDS(d, k = 2)

# print NMDS
d.nmds

# Call:
# metaMDS(comm = d, k = 2) 
# 
# global Multidimensional Scaling using monoMDS
# 
# Data:     d 
# Distance: bray 
# 
# Dimensions: 2 
# Stress:     0.04242448 
# Stress type 1, weak ties
# Two convergent solutions found after 20 tries
# Scaling: centring, PC rotation 
# Species: scores missing

# produce stress plot of observed dissimilarity vs ordination distance
stressplot(d.nmds)

# plot NMDS data points with labelled samples
plot(d.nmds, type="t")

# assign the point dimensions to x and y variables for the plot. There are upto 2 dimensions calculated which can be plotted. 
nmds_data <- as.data.frame(d.nmds$points)
nmds_data$variety_genotype_pot <- row.names(nmds_data)

# match env_data to nmds_data
env_data$variety_genotype_pot <- row.names(env_data)
nmds_data <- merge(nmds_data, env_data, by = 'variety_genotype_pot', all.x = T)
row.names(nmds_data) <- nmds_data$variety_genotype_pot

# when setting colour palettes we must set the seed so they are all the same
set.seed(6)

# number of unique hosts (so know for colour palette)
length(unique(nmds_data$variety))
# [1] 19
library(Polychrome)
# build-in color palette
varietycol <-  setNames(createPalette(19,  c("#ff0000", "#00ff00", "#0000ff")), 
                      sort(unique(nmds_data$variety)))

# make genotype a factor
nmds_data$genotype <- factor(nmds_data$genotype)

# plot recA NMDS data
(nmdsplot <- ggplot(nmds_data, aes(MDS1, MDS2, color = variety, fill = variety,
                                   group = variety_genotype, shape = genotype)) +
    #coord_fixed() +
    geom_point(size = 5) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover variety", fill="Clover variety", shape = "Genotype") +
    stat_chull(geom = "polygon", alpha = 0.2) +
    scale_color_manual(values = varietycol) +
    scale_fill_manual(values = varietycol) +
    facet_wrap(.~variety) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 20), 
          axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
          axis.text.y = element_text(size = 10),
          axis.title=element_text(size = 20),
          strip.text.x = element_text(size = 20),
          legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/greenhouse_NMDS_recA_k2.pdf', plot = nmdsplot, width = 30, height = 25, unit = 'cm')


# A dataset containing environmental data also needs to be made to look at environmental vectors.
# The envfit function is run using the same method above with metaMDS
# https://www.rpubs.com/RGrieger/545184
# https://oliviarata.wordpress.com/2014/04/17/ordinations-in-ggplot2/
# https://stackoverflow.com/questions/14711470/plotting-envfit-vectors-vegan-package-in-ggplot2

# this fits environmental vectors
d.spp.fit <- envfit(d.nmds, ra.data, permutations = 999)

# print results
d.spp.fit

# ***VECTORS
# 
# NMDS1    NMDS2     r2 Pr(>r)    
# seq_1_reca -0.99995  0.01014 0.9969  0.001 ***
# seq_2_reca  0.46442  0.88561 0.8523  0.001 ***
# seq_3_reca  0.89884  0.43829 0.6928  0.001 ***
# seq_4_reca  0.39226 -0.91986 0.7669  0.001 ***
# seq_5_reca  0.56877 -0.82249 0.8010  0.001 ***
# seq_6_reca  0.47965 -0.87746 0.7653  0.001 ***
# seq_8_reca  0.55376  0.83268 0.0340  0.133    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# Permutation: free
# Number of permutations: 999


#save species intrinsic values into dataframe
spp.scrs <- as.data.frame(scores(d.spp.fit, display = "vectors")) 

#add species names to dataframe
spp.scrs <- cbind(spp.scrs, Species = rownames(spp.scrs)) 

#add pvalues to dataframe so you can select species which are significant
spp.scrs <- cbind(spp.scrs, pval = d.spp.fit$vectors$pvals) 

#subset data to show species significant at 0.05
sig.spp.scrs <- subset(spp.scrs, pval<=0.05) 

# rename NMDS1 and NMDS2 to MDS1 and MDS2 just so it fits with the previous nmds data graph for continuity
names(sig.spp.scrs)[1:2] <- c('MDS1', 'MDS2')

# Adding significant environmental factors to the plot
# which correlate significantly (p<0.05) with NMDS 1 and 2
(nmdsplot2 <- ggplot(data = nmds_data, aes(MDS1, MDS2)) +
    #coord_fixed() +
    geom_point(aes(color = variety, fill = variety, group = variety_genotype, shape = genotype), size = 3) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover variety", fill="Clover variety", shape = "Genotype") +
    stat_chull(aes(color = variety, fill = variety, group = variety_genotype), geom = "polygon", alpha = 0.2) +
    scale_color_manual(values = varietycol) +
    scale_fill_manual(values = varietycol) +
    # add vector arrows of significant species
    geom_segment(data = sig.spp.scrs, aes(x = 0, xend=MDS1, y=0, yend=MDS2),
                 arrow = arrow(length = unit(0.25, "cm")),
                 colour = "grey10", lwd=0.3) +
    # add labels for species, use ggrepel::geom_text_repel so that labels do not overlap
    ggrepel::geom_text_repel(data = sig.spp.scrs,
                             aes(x=MDS1, y=MDS2, label = Species),
                             cex = 6, direction = "both", segment.size = 0.25) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/greenhouse_NMDS_recA_k2_intrinsicspeciesvariables0.05.pdf', plot = nmdsplot2, width = 30, height = 25, unit = 'cm')



# NMDS plots: rpob ------------


# remove all data in global environment before starting this section - a refresh start. 

# can upload already pca matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_rpob_ra_matrix.csv")

# create categories to colour for heatmap from envir dataframe
env_data <- ra.data[ ,c("variety", "genotype", "pot", "variety_genotype", "variety_genotype_pot")]
row.names(env_data) <- env_data$variety_genotype_pot
env_data$variety_genotype_pot <- NULL

# remove envdata columns
maxcol = ncol(ra.data) -8
ra.data <- ra.data[,1:maxcol]

# make sample names row names
row.names(ra.data) <- ra.data$variety_genotype_pot
ra.data$variety_genotype_pot <- NULL

# reorder env_data rows. then use this to reorder rows in ra_matrix for distance calculation.
env_data <- env_data[with(env_data, order(variety, genotype, pot)), ]

# make row names in ra.data2 match those in env_data. 
ra.data <- ra.data[c(row.names(env_data)), ]

#then produce dist matrices.
d <-  vegdist(ra.data, method = "bray")

# non-metric MDS can also be calculated with metaMDS as part of the vegan package. 
# To calculate a NMDS, use the nmds() function on a dissimilarity/distance matrix.
# print the distance matrix
d

# In this part, we define a function NMDS.scree() that automatically 
# performs a NMDS for 1-10 dimensions and plots the nr of dimensions vs the stress
NMDS.scree <- function(x) { #where x is the name of the data frame variable
  plot(rep(1, 10), replicate(10, metaMDS(x, autotransform = F, k = 1)$stress), xlim = c(1, 10),ylim = c(0, 0.30), xlab = "# of Dimensions", ylab = "Stress", main = "NMDS stress plot")
  for (i in 1:10) {
    points(rep(i + 1,10),replicate(10, metaMDS(x, autotransform = F, k = i + 1)$stress))
  }
}


# A plot of stress (a measure of goodness-of-fit) vs. dimensionality can be used to assess the proper choice of dimensions. The stress values themselves can be used as an indicator. Stress values >0.2 are generally poor and potentially uninterpretable, whereas values <0.1 are good and <0.05 are excellent. Stress values between 0.1 and 0.2 are useable but some of the distances will be misleading. Finding the inflexion point can instruct the selection of a minimum number of dimensions
# Use the function that we just defined to choose the optimal nr of dimensions
NMDS.scree(d)

# calculate the NMDS using metaMDS to 2 dimensions
# instead of using random starts for finding the best fit of the data, start with the default
# PCO (classical MDS) configuration, so technically the NMDS can't have a worse result than the NMDS.
d.nmds <- metaMDS(d, k = 2)

# print NMDS
d.nmds

# Call:
# metaMDS(comm = d, k = 2) 
# 
# global Multidimensional Scaling using monoMDS
# 
# Data:     d 
# Distance: bray 
# 
# Dimensions: 2 
# Stress:     0.03245545 
# Stress type 1, weak ties
# Two convergent solutions found after 20 tries
# Scaling: centring, PC rotation 
# Species: scores missing


# produce stress plot of observed dissimilarity vs ordination distance
stressplot(d.nmds)

# plot NMDS data points with labelled samples
plot(d.nmds, type="t")

# assign the point dimensions to x and y variables for the plot. There are upto 2 dimensions calculated which can be plotted. 
nmds_data <- as.data.frame(d.nmds$points)
nmds_data$variety_genotype_pot <- row.names(nmds_data)

# match env_data to nmds_data
env_data$variety_genotype_pot <- row.names(env_data)
nmds_data <- merge(nmds_data, env_data, by = 'variety_genotype_pot', all.x = T)
row.names(nmds_data) <- nmds_data$variety_genotype_pot

# when setting colour palettes we must set the seed so they are all the same
set.seed(6)

# number of unique hosts (so know for colour palette)
length(unique(nmds_data$variety))
# [1] 19
library(Polychrome)
# build-in color palette
varietycol <-  setNames(createPalette(19,  c("#ff0000", "#00ff00", "#0000ff")), 
                        sort(unique(nmds_data$variety)))

# make genotype a factor
nmds_data$genotype <- factor(nmds_data$genotype)

# plot recA NMDS data
(nmdsplot <- ggplot(nmds_data, aes(MDS1, MDS2, color = variety, fill = variety,
                                   group = variety_genotype, shape = genotype)) +
    #coord_fixed() +
    geom_point(size = 5) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover variety", fill="Clover variety",shape = "Genotype") +
    stat_chull(geom = "polygon", alpha = 0.2) +
    scale_color_manual(values = varietycol) +
    scale_fill_manual(values = varietycol) +
    facet_wrap(.~variety) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 20), 
          axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
          axis.text.y = element_text(size = 10),
          axis.title=element_text(size = 20),
          strip.text.x = element_text(size = 20),
          legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/greenhouse_NMDS_rpoB_k2.pdf', plot = nmdsplot, width = 30, height = 25, unit = 'cm')


# A dataset containing environmental data also needs to be made to look at environmental vectors.
# The envfit function is run using the same method above with metaMDS
# https://www.rpubs.com/RGrieger/545184
# https://oliviarata.wordpress.com/2014/04/17/ordinations-in-ggplot2/
# https://stackoverflow.com/questions/14711470/plotting-envfit-vectors-vegan-package-in-ggplot2

# this fits environmental vectors
d.spp.fit <- envfit(d.nmds, ra.data, permutations = 999)

# print results
d.spp.fit

# ***VECTORS
# 
#               NMDS1    NMDS2     r2 Pr(>r)    
# seq_1_rpob  0.99189 -0.12712 0.9986  0.001 ***
# seq_2_rpob -0.36753  0.93001 0.9976  0.001 ***
# seq_3_rpob -0.62824 -0.77802 0.9993  0.001 ***
#   ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# Permutation: free
# Number of permutations: 999

#save species intrinsic values into dataframe
spp.scrs <- as.data.frame(scores(d.spp.fit, display = "vectors")) 

#add species names to dataframe
spp.scrs <- cbind(spp.scrs, Species = rownames(spp.scrs)) 

#add pvalues to dataframe so you can select species which are significant
spp.scrs <- cbind(spp.scrs, pval = d.spp.fit$vectors$pvals) 

#subset data to show species significant at 0.05
sig.spp.scrs <- subset(spp.scrs, pval<=0.05) 

# rename NMDS1 and NMDS2 to MDS1 and MDS2 just so it fits with the previous nmds data graph for continuity
names(sig.spp.scrs)[1:2] <- c('MDS1', 'MDS2')

# Adding significant environmental factors to the plot
# which correlate significantly (p<0.05) with NMDS 1 and 2
(nmdsplot2 <- ggplot(data = nmds_data, aes(MDS1, MDS2)) +
    #coord_fixed() +
    geom_point(aes(color = variety, fill = variety, group = variety_genotype, shape = genotype), size = 3) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover variety", fill="Clover variety", shape = "Genotype") +
    stat_chull(aes(color = variety, fill = variety, group = variety_genotype), geom = "polygon", alpha = 0.2) +
    scale_color_manual(values = varietycol) +
    scale_fill_manual(values = varietycol) +
    # add vector arrows of significant species
    geom_segment(data = sig.spp.scrs, aes(x = 0, xend=MDS1, y=0, yend=MDS2),
                 arrow = arrow(length = unit(0.25, "cm")),
                 colour = "grey10", lwd=0.3) +
    # add labels for species, use ggrepel::geom_text_repel so that labels do not overlap
    ggrepel::geom_text_repel(data = sig.spp.scrs,
                             aes(x=MDS1, y=MDS2, label = Species),
                             cex = 6, direction = "both", segment.size = 0.25) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/greenhouse_NMDS_rpob_k2_intrinsicspeciesvariables0.05.pdf', plot = nmdsplot2, width = 30, height = 25, unit = 'cm')



# NMDS plots: both genes ------------


# remove all data in global environment before starting this section - a refresh start. 

#can upload already pca matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_bothgenes_ra_matrix.csv")

#create categories to colour for heatmap from envir dataframe
env_data <- ra.data[ ,c("variety", "genotype", "pot", "variety_genotype", "variety_genotype_pot")]
row.names(env_data) <- env_data$variety_genotype_pot
env_data$variety_genotype_pot <- NULL

# remove envdata columns
maxcol = ncol(ra.data) -8
ra.data <- ra.data[,1:maxcol]

# make sample names row names
row.names(ra.data) <- ra.data$variety_genotype_pot
ra.data$variety_genotype_pot <- NULL

# reorder env_data rows. then use this to reorder rows in ra_matrix for distance calculation.
env_data <- env_data[with(env_data, order(variety, genotype, pot)), ]

# make row names in ra.data2 match those in env_data. 
ra.data <- ra.data[c(row.names(env_data)), ]

#then produce dist matrices.
d <-  vegdist(ra.data, method = "bray")

# non-metric MDS can also be calculated with metaMDS as part of the vegan package. 
# To calculate a NMDS, use the nmds() function on a dissimilarity/distance matrix.
# print the distance matrix
d

# In this part, we define a function NMDS.scree() that automatically 
# performs a NMDS for 1-10 dimensions and plots the nr of dimensions vs the stress
NMDS.scree <- function(x) { #where x is the name of the data frame variable
  plot(rep(1, 10), replicate(10, metaMDS(x, autotransform = F, k = 1)$stress), xlim = c(1, 10),ylim = c(0, 0.30), xlab = "# of Dimensions", ylab = "Stress", main = "NMDS stress plot")
  for (i in 1:10) {
    points(rep(i + 1,10),replicate(10, metaMDS(x, autotransform = F, k = i + 1)$stress))
  }
}


# A plot of stress (a measure of goodness-of-fit) vs. dimensionality can be used to assess the proper choice of dimensions. The stress values themselves can be used as an indicator. Stress values >0.2 are generally poor and potentially uninterpretable, whereas values <0.1 are good and <0.05 are excellent. Stress values between 0.1 and 0.2 are useable but some of the distances will be misleading. Finding the inflexion point can instruct the selection of a minimum number of dimensions
# Use the function that we just defined to choose the optimal nr of dimensions
NMDS.scree(d)

# calculate the NMDS using metaMDS to 2 dimensions
# instead of using random starts for finding the best fit of the data, start with the default
# PCO (classical MDS) configuration, so technically the NMDS can't have a worse result than the NMDS.
d.nmds <- metaMDS(d, k = 2)

# print NMDS
d.nmds

# Call:
#   metaMDS(comm = d, k = 2) 
# 
# global Multidimensional Scaling using monoMDS
# 
# Data:     d 
# Distance: bray 
# 
# Dimensions: 2 
# Stress:     0.07616258 
# Stress type 1, weak ties
# Two convergent solutions found after 20 tries
# Scaling: centring, PC rotation 
# Species: scores missing

# produce stress plot of observed dissimilarity vs ordination distance
stressplot(d.nmds)

# plot NMDS data points with labelled samples
plot(d.nmds, type="t")

# assign the point dimensions to x and y variables for the plot. There are upto 2 dimensions calculated which can be plotted. 
nmds_data <- as.data.frame(d.nmds$points)
nmds_data$variety_genotype_pot <- row.names(nmds_data)

# match env_data to nmds_data
env_data$variety_genotype_pot <- row.names(env_data)
nmds_data <- merge(nmds_data, env_data, by = 'variety_genotype_pot', all.x = T)
row.names(nmds_data) <- nmds_data$variety_genotype_pot

# when setting colour palettes we must set the seed so they are all the same
set.seed(6)

# number of unique hosts (so know for colour palette)
length(unique(nmds_data$variety))
# [1] 19
library(Polychrome)
# build-in color palette
varietycol <-  setNames(createPalette(19,  c("#ff0000", "#00ff00", "#0000ff")), 
                        sort(unique(nmds_data$variety)))

# make genotype a factor
nmds_data$genotype <- factor(nmds_data$genotype)

# plot bothgenes NMDS data
(nmdsplot <- ggplot(nmds_data, aes(MDS1, MDS2, color = variety, fill = variety,
                                   group = variety_genotype, shape = genotype)) +
    #coord_fixed() +
    geom_point(size = 5) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover variety", fill="Clover variety", shape = "Genotype") +
    stat_chull(geom = "polygon", alpha = 0.2) +
    scale_color_manual(values = varietycol) +
    scale_fill_manual(values = varietycol) +
    facet_wrap(.~variety) +
    guides(colour = guide_legend(order = 1), 
           fill = guide_legend(order = 1),
           shape = guide_legend(order = 2)) +
    theme_bw() +
    theme(legend.title = element_text(size = 20), 
          axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
          axis.text.y = element_text(size = 10),
          axis.title=element_text(size = 20),
          strip.text.x = element_text(size = 20),
          legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Fig6/greenhouse_NMDS_bothgenes_k2.pdf', plot = nmdsplot, width = 30, height = 25, unit = 'cm')


# A dataset containing environmental data also needs to be made to look at environmental vectors.
# The envfit function is run using the same method above with metaMDS
# https://www.rpubs.com/RGrieger/545184
# https://oliviarata.wordpress.com/2014/04/17/ordinations-in-ggplot2/
# https://stackoverflow.com/questions/14711470/plotting-envfit-vectors-vegan-package-in-ggplot2

# this fits environmental vectors
d.spp.fit <- envfit(d.nmds, ra.data, permutations = 999)

# print results
d.spp.fit

# ***VECTORS
# 
# NMDS1    NMDS2     r2 Pr(>r)    
# seq_1_reca -0.96810  0.25057 0.8259  0.001 ***
# seq_2_reca  0.99087  0.13482 0.5829  0.001 ***
# seq_3_reca  0.80405  0.59457 0.6094  0.001 ***
# seq_4_reca  0.55179 -0.83398 0.5808  0.001 ***
# seq_5_reca  0.60436 -0.79671 0.5894  0.001 ***
# seq_6_reca  0.63535 -0.77223 0.4856  0.001 ***
# seq_8_reca  0.73571 -0.67730 0.0724  0.066 .  
# seq_1_rpob -0.97558 -0.21966 0.8921  0.001 ***
# seq_2_rpob  0.32403  0.94605 0.8944  0.001 ***
# seq_3_rpob  0.60914 -0.79306 0.8523  0.001 ***
#   ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# Permutation: free
# Number of permutations: 999


#save species intrinsic values into dataframe
spp.scrs <- as.data.frame(scores(d.spp.fit, display = "vectors")) 

#add species names to dataframe
spp.scrs <- cbind(spp.scrs, Species = rownames(spp.scrs)) 

#add pvalues to dataframe so you can select species which are significant
spp.scrs <- cbind(spp.scrs, pval = d.spp.fit$vectors$pvals) 

#subset data to show species significant at 0.05
sig.spp.scrs <- subset(spp.scrs, pval<=0.05) 

# rename NMDS1 and NMDS2 to MDS1 and MDS2 just so it fits with the previous nmds data graph for continuity
names(sig.spp.scrs)[1:2] <- c('MDS1', 'MDS2')

# Adding significant environmental factors to the plot
# which correlate significantly (p<0.05) with NMDS 1 and 2
(nmdsplot2 <- ggplot(data = nmds_data, aes(MDS1, MDS2)) +
    #coord_fixed() +
    geom_point(aes(color = variety, fill = variety, group = variety_genotype, shape = genotype), size = 3) +
    #must manually apply the percentage variance in this case
    xlab("NMDS Coordinate 1") +
    ylab("NMDS Coordinate 2") + 
    labs(colour="Clover variety", fill="Clover variety", shape = "Genotype") +
    stat_chull(aes(color = variety, fill = variety, group = variety_genotype), geom = "polygon", alpha = 0.2) +
    scale_color_manual(values = varietycol) +
    scale_fill_manual(values = varietycol) +
    # add vector arrows of significant species
    geom_segment(data = sig.spp.scrs, aes(x = 0, xend=MDS1, y=0, yend=MDS2),
                 arrow = arrow(length = unit(0.25, "cm")),
                 colour = "grey10", lwd=0.3) +
    # add labels for species, use ggrepel::geom_text_repel so that labels do not overlap
    ggrepel::geom_text_repel(data = sig.spp.scrs,
                             aes(x=MDS1, y=MDS2, label = Species),
                             cex = 6, direction = "both", segment.size = 0.25) +
    theme_bw() +
    theme(legend.title = element_text(size = 30), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/greenhouse_NMDS_bothgenes_k2_intrinsicspeciesvariables0.05.pdf', plot = nmdsplot2, width = 30, height = 25, unit = 'cm')



# Genospecies differences for confirmed sequence assignment totals ----------


# read in relative abundance genospecies files for recA and rpob
data_reca_con <- read.csv('../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_reca_ra_matrix_genospecies.csv')

data_rpob_con <- read.csv('../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_rpob_ra_matrix_genospecies.csv')

# save environment/metadata as separate dataframe for later
env_data <- data_reca_con[, c("table", "placement", "clover", 
                              "barcode", "variety", "genotype", "pot", "variety_genotype_pot", "variety_genotype")]

# remove the single sequence frequencies and keep only the genospecies totals
data_reca_con <- data_reca_con[,c(1, (ncol(data_reca_con) - 2):ncol(data_reca_con))]
data_rpob_con <- data_rpob_con[,c(1, (ncol(data_rpob_con) - 2):ncol(data_rpob_con))]

# melt dataframe into 3 columns; sample name, genospecies, relative abundance
data_reca_con <- melt(data_reca_con, id.var= "variety_genotype_pot",  value.name = 'genospecies_reca_ra')
names(data_reca_con)[1:2] <- c('variety_genotype_pot', 'genospecies')

data_rpob_con <- melt(data_rpob_con, id.var= "variety_genotype_pot", value.name = 'genospecies_rpob_ra')
names(data_rpob_con)[1:2] <- c('variety_genotype_pot', 'genospecies')

# merge the two dataframes together so we get 4 columns; sample name, genospecies, rpoB ra, recA ra.
data_2genes_con <- merge(data_rpob_con, data_reca_con, by = c('variety_genotype_pot', 'genospecies'), all.x = T)

# genospecies palette with additional grey colour added.
genoPalette <- c("#466EA9","#EA877A", "#4D9A7A")

# create correlation graph of recA genospecies frequency vs rpoB genospecies frequency
(graph1 <- ggplot(data_2genes_con, aes(genospecies_rpob_ra, genospecies_reca_ra, 
                                       color = genospecies, fill = genospecies)) +
    geom_point(size = 5) +
    xlab(~italic("rpoB")~"frequency") +
    ylab(~italic("recA")~"frequency") + 
    labs(colour = "Genospecies", fill = "Genospecies") +
    scale_color_manual(values = genoPalette) +
    scale_fill_manual(values = genoPalette) +
    guides(colour = guide_legend(override.aes = list(size=9))) +
    theme_bw() +
    theme(legend.title = element_text(size = 35), 
          axis.text.x = element_text(size = 30),
          axis.text.y = element_text(size = 30),
          axis.title=element_text(size = 35),
          legend.text = element_text(size = 30))
)
#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/greenhouse_genospecies_reca_rpob_ra_frequencies_conftotals.pdf', plot = graph1, width = 25, height = 20, unit = 'cm')

# calculate pearsons correlation coefficient.
cor.test(data_2genes_con$genospecies_rpob_ra, data_2genes_con$genospecies_reca_ra, method=c("pearson"))
# t = 18.137, df = 244, p-value < 2.2e-16
# 95 percent confidence interval: 0.6988733 0.8063684
# cor = 0.7577145 


# merge metadata with genospecies frequency data
data_2genes_envir_con <- merge(data_2genes_con, env_data, by = "variety_genotype_pot", all.x = T)

# melt data and then combine into one figure
data_2genes_envir_con_melt <- melt(data_2genes_envir_con[c('variety_genotype_pot', 'variety_genotype', 'genospecies', 'pot','genospecies_rpob_ra', 'genospecies_reca_ra')], id.vars = c('variety_genotype_pot', 'variety_genotype', 'genospecies', 'pot'))

# rename variable and value columns
names(data_2genes_envir_con_melt)[5:6] <- c('genospecies_gene_ra', 'ra')

# Add in "Initial Inoculum" columns
nrow(data_2genes_envir_con_melt)
# [1] 492
data_2genes_envir_con_melt[493,] <- c("Initial Inoculum", "Initial Inoculum", "gsA", "1", "genospecies_rpob_ra", "0.6")
data_2genes_envir_con_melt[494,] <- c("Initial Inoculum", "Initial Inoculum", "gsB", "1", "genospecies_rpob_ra", "0.1")
data_2genes_envir_con_melt[495,] <- c("Initial Inoculum", "Initial Inoculum", "gsC", "1", "genospecies_rpob_ra", "0.3")
data_2genes_envir_con_melt[496,] <- c("Initial Inoculum", "Initial Inoculum", "gsA", "1", "genospecies_reca_ra", "0.6")
data_2genes_envir_con_melt[497,] <- c("Initial Inoculum", "Initial Inoculum", "gsB", "1", "genospecies_reca_ra", "0.1")
data_2genes_envir_con_melt[498,] <- c("Initial Inoculum", "Initial Inoculum", "gsC", "1", "genospecies_reca_ra", "0.3")

# make bray curtis value numeric again
data_2genes_envir_con_melt$ra <- as.numeric(data_2genes_envir_con_melt$ra)

# rename genes for figure
data_2genes_envir_con_melt$genospecies_gene_ra <- factor(data_2genes_envir_con_melt$genospecies_gene_ra,
                                                         levels = c('genospecies_rpob_ra', 
                                                                    'genospecies_reca_ra'), 
                                                         labels = c('rpoB', 'recA'))

# reorder the variety names and samples
data_2genes_envir_con_melt$variety_genotype_pot <- factor(data_2genes_envir_con_melt$variety_genotype_pot,
                                              levels = c("Initial Inoculum", 
                                                         unique(data_2genes_envir_con_melt$variety_genotype_pot[!data_2genes_envir_con_melt$variety_genotype_pot %in% "Initial Inoculum"])))

data_2genes_envir_con_melt$variety_genotype <- factor(data_2genes_envir_con_melt$variety_genotype,
                                                          levels = c("Initial Inoculum", 
                                                                     unique(data_2genes_envir_con_melt$variety_genotype[!data_2genes_envir_con_melt$variety_genotype %in% "Initial Inoculum"])))

# make stacked bar charts.
(barplot <- ggplot(data_2genes_envir_con_melt, aes(variety_genotype_pot, ra, fill = genospecies)) +
    geom_bar(position = "stack", stat = 'identity', color = "black") +
    xlab("Samples") +
    ylab("Frequency") + 
    labs(colour = "Genospecies", fill = "Genospecies") +
    scale_color_manual(values = genoPalette) +
    scale_fill_manual(values = genoPalette) +
    facet_grid(genospecies_gene_ra ~ variety_genotype, scales = "free_x") +
    theme_bw() +
    theme(legend.title = element_text(size = 35), 
          legend.text = element_text(size = 30),
          axis.title=element_text(size = 35),
          axis.text.x = element_blank(),
          axis.text.y = element_text(size = 10),
          axis.ticks.x = element_blank(),
          strip.text = element_text(size = 20),
          strip.text.y = element_text(face = "italic"),
          strip.text.x = element_text(angle = 90))
)
#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Fig6/greenhouse_reca_rpob_genospeciesfrequency_stackbar.pdf', plot = barplot, width = 50, height = 15, unit = 'cm')



# 2 way ANOVA for genospecies vs clover genotype differences

# calculate statistical significance of genospecies relative frequency differences between clover genotypes
# rpob
mod_rpob_con <- aov(genospecies_rpob_ra ~ variety * variety_genotype * genospecies, data = data_2genes_envir_con)
summary(mod_rpob_con)


#                               Df Sum Sq Mean Sq F value   Pr(>F)    
# variety                       18  0.000   0.000   0.000        1    
# variety_genotype              22  0.000   0.000   0.000        1    
# genospecies                    2  6.372   3.186  91.735  < 2e-16 ***
# variety:genospecies           36  4.550   0.126   3.639 5.23e-08 ***
# variety_genotype:genospecies  44  5.649   0.128   3.696 6.48e-09 ***
# Residuals                    123  4.272   0.035                     
# ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


interaction.plot(data_2genes_envir_con$variety_genotype, data_2genes_envir_con$genospecies, data_2genes_envir_con$genospecies_rpob_ra)

plot(mod_rpob_con, which = 1)
plot(mod_rpob_con, which = 2)
shapiro.test(mod_rpob_con$residuals)

# Shapiro-Wilk normality test
# 
# data:  mod_rpob_con$residuals
# W = 0.98643, p-value = 0.01969

# TukeyHSD post-hoc to determine exact differences
TukeyHSD(mod_rpob_con)
plot(TukeyHSD(mod_rpob_con), cex.axis = 0.7)
res <- TukeyHSD(mod_rpob_con)

# I did not bring out the post hoc results for variety or variety_genotype because they were not sig.
posthoc <- as.data.frame(res$`variety:genospecies`)
posthoc$comparison <- row.names(posthoc)
posthoc$section <- 'variety_genospecies_interaction'

posthoc2 <- as.data.frame(res$`variety_genotype:genospecies`)
posthoc2$comparison <- row.names(posthoc2)
posthoc2$section <- 'varietygenotype_genospecies_interaction'

posthoc_total <- do.call("rbind", list(posthoc, posthoc2))
posthoc_total <- posthoc_total[c(6,5,1,2,3,4)]

# write post hoc results to csv file
write.csv(posthoc_total, file = "../data/data_output/stats_data/greenhouse_genospecies_differences/ANOVA2way_rpob_results_genospeciesclovergeno_conftotals.csv", row.names = F) 

# must manually add the initial ANOVA result output

rm(posthoc)
rm(posthoc2)
rm(posthoc_total)
rm(res)

# reca
mod_reca_con <- aov(genospecies_reca_ra ~ variety * variety_genotype * genospecies, data = data_2genes_envir_con)
summary(mod_reca_con)

#                               Df Sum Sq Mean Sq  F value Pr(>F)    
# variety                       18  0.000   0.000    0.000      1    
# variety_genotype              22  0.000   0.000    0.000      1    
# genospecies                    2 25.984  12.992 1416.385 <2e-16 ***
# variety:genospecies           36  3.435   0.095   10.402 <2e-16 ***
# variety_genotype:genospecies  44  3.262   0.074    8.081 <2e-16 ***
# Residuals                    123  1.128   0.009                    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


interaction.plot(data_2genes_envir_con$variety_genotype, data_2genes_envir_con$genospecies, data_2genes_envir_con$genospecies_reca_ra)

plot(mod_reca_con, which = 1)
plot(mod_reca_con, which = 2)
shapiro.test(mod_reca_con$residuals)

# Shapiro-Wilk normality test
# 
# data:  mod_reca_con$residuals
# W = 0.93326, p-value = 4.112e-09

# TukeyHSD post-hoc to determine exact differences
TukeyHSD(mod_reca_con)
plot(TukeyHSD(mod_reca_con), cex.axis = 0.7)
res2 <- TukeyHSD(mod_reca_con)

# I did not print post hoc result for variety or variety_genotype because they were not sig. 
posthoc <- as.data.frame(res2$`variety:genospecies`)
posthoc$comparison <- row.names(posthoc)
posthoc$section <- 'variety_genospecies_interaction'

posthoc2 <- as.data.frame(res2$`variety_genotype:genospecies`)
posthoc2$comparison <- row.names(posthoc2)
posthoc2$section <- 'varietygenotype_genospecies_interaction'

posthoc_total <- do.call("rbind", list(posthoc, posthoc2))
posthoc_total <- posthoc_total[c(6,5,1,2,3,4)]

# write post hoc results to csv file
write.csv(posthoc_total, file = "../data/data_output/stats_data/greenhouse_genospecies_differences/ANOVA2way_reca_results_genospeciesclovergeno_conftotals.csv", row.names = F) 

# must mannually add the initial result output



# PERMANOVA with genospecies for clover genotype differences ------------


# clear data from global environment again before starting this section.

# read in relative abundance genospecies files for recA and rpob
data_reca_con2 <- read.csv('../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_reca_ra_matrix_genospecies.csv')

data_rpob_con2 <- read.csv('../data/data_output/greenhouse_abundance_data_pseudorep/greenhouse_rpob_ra_matrix_genospecies.csv')

# check in rows are in right order
env_data$variety_genotype_pot == data_reca_con2$variety_genotype_pot
env_data$variety_genotype_pot == data_rpob_con2$variety_genotype_pot

# remove the single sequence frequencies and keep only the genospecies totals
data_reca_con2 <- data_reca_con2[,c(1, (ncol(data_reca_con2) - 2):ncol(data_reca_con2))]
data_rpob_con2 <- data_rpob_con2[,c(1, (ncol(data_rpob_con2) - 2):ncol(data_rpob_con2))]

# make sample names row names
row.names(data_reca_con2) <- data_reca_con2$variety_genotype_pot
row.names(data_rpob_con2) <- data_rpob_con2$variety_genotype_pot
data_reca_con2$variety_genotype_pot <- NULL
data_rpob_con2$variety_genotype_pot <- NULL

# Now we can calculate the distance matrix. the “bray” method calculates the Bray-Curtis distance. 
# they produce dist matrices.
bray_reca = vegdist(data_reca_con2, method = "bray")
bray_rpob = vegdist(data_rpob_con2, method = "bray")

# permanova test
# reca
adonis(bray_reca ~ variety + variety_genotype, data = env_data)

# Call:
# adonis(formula = bray_reca ~ variety + variety_genotype, data = env_data) 
# 
# Permutation: free
# Number of permutations: 999
# 
# Terms added sequentially (first to last)
# 
#                  Df SumsOfSqs  MeanSqs F.Model      R2 Pr(>F)    
# variety          18    2.1223 0.117908  7.1816 0.44530  0.001 ***
# variety_genotype 22    1.9706 0.089573  5.4557 0.41346  0.001 ***
# Residuals        41    0.6731 0.016418         0.14124           
# Total            81    4.7661                  1.00000           
# ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# permanova test
# rpob
adonis(bray_rpob ~ variety + variety_genotype, data = env_data)

# Call:
# adonis(formula = bray_rpob ~ variety + variety_genotype, data = env_data) 
# 
# Permutation: free
# Number of permutations: 999
# 
# Terms added sequentially (first to last)
# 
#                  Df SumsOfSqs  MeanSqs F.Model      R2 Pr(>F)   
# variety          18    2.7917 0.155096  2.5007 0.31690  0.003 **
# variety_genotype 22    3.4749 0.157949  2.5467 0.39445  0.002 **
# Residuals        41    2.5429 0.062022         0.28865          
# Total            81    8.8095                  1.00000          
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1



