# Author: Bryden Fields
# Email: bryden.fields@york.ac.uk

# Initial set up --------------

library(tidyverse)
library(reshape2)
library(vegan)
library(lme4)
library(agricolae)
library(boot)
library(glmmTMB)
library(betareg)

#set the working directory to the directory this script is in.
#setwd("~/whatever/folder/you/are/working/from")
setwd('/Users/brydenfields/Documents/Publications/2023_Clovergenotype_paper/scripts')



# read in data -----------


# read in data produced in "clovergenotype_greenhouse_plantgrowth_standardisation.R" script (this data has been filtered before producing all the standardisation scores)
rpoB_data <- read.csv("../data/data_output/combined_greenhouse_growth_greenness_genospecies_rpoB.csv")

recA_data <- read.csv("../data/data_output/combined_greenhouse_growth_greenness_genospecies_recA.csv")



# Calculate deviation from initial inoculum (bray-curtis) -------------


# subset genospecies composition for recA and rpoB
rpoB_data_gs <- rpoB_data[c("variety_genotype_pot", "gsA", "gsB", "gsC")]

recA_data_gs <- recA_data[c("variety_genotype_pot", "gsA", "gsB", "gsC")]

# add in new row which is the initial inoculum
# 6 gsA, 1 gsB, and 3 gsC strains (60% gsA, 10% gsB, 30% gsC)
rpoB_data_gs[c(nrow(rpoB_data_gs)+1),1] <- c("inoculum")
rpoB_data_gs[c(nrow(rpoB_data_gs)),2:4] <- c(0.6, 0.1, 0.3)

recA_data_gs[c(nrow(recA_data_gs)+1),1] <- c("inoculum")
recA_data_gs[c(nrow(recA_data_gs)),2:4] <- c(0.6, 0.1, 0.3)

# make variety_genotype_pot the row names
row.names(rpoB_data_gs) <- rpoB_data_gs$variety_genotype_pot
rpoB_data_gs$variety_genotype_pot <- NULL

row.names(recA_data_gs) <- recA_data_gs$variety_genotype_pot
recA_data_gs$variety_genotype_pot <- NULL

# calculate bray-curtis dissimilarity
bray_dist_rpoB <- vegdist(rpoB_data_gs, method = "bray", diag = TRUE)

bray_dist_recA <- vegdist(recA_data_gs, method = "bray", diag = TRUE)

# convert dist into a dataframe
bray_dist_rpoB <- as.data.frame(as.matrix(bray_dist_rpoB))
bray_dist_rpoB$variety_genotype_pot <- row.names(bray_dist_rpoB)

bray_dist_recA <- as.data.frame(as.matrix(bray_dist_recA))
bray_dist_recA$variety_genotype_pot <- row.names(bray_dist_recA)

# add the distance compared to the inoculum as a new column in the original data
rpoB_data <- left_join(rpoB_data, bray_dist_rpoB[c("inoculum", "variety_genotype_pot")], by = "variety_genotype_pot")
names(rpoB_data)[ncol(rpoB_data)] <- "bray_from_inoculum"

recA_data <- left_join(recA_data, bray_dist_recA[c("inoculum", "variety_genotype_pot")], by = "variety_genotype_pot")
names(recA_data)[ncol(recA_data)] <- "bray_from_inoculum"



# GLMM analyses ------------


# check the genospecies distributions
qqnorm(rpoB_data$gsA)
qqline(rpoB_data$gsA, col = "red")
qqnorm(recA_data$gsA)
qqline(recA_data$gsA, col = "red")

qqnorm(rpoB_data$gsB)
qqline(rpoB_data$gsB, col = "red")
qqnorm(recA_data$gsB)
qqline(recA_data$gsB, col = "red")

qqnorm(rpoB_data$gsC)
qqline(rpoB_data$gsC, col = "red")
qqnorm(recA_data$gsC)
qqline(recA_data$gsC, col = "red")

qqnorm(rpoB_data$bray_from_inoculum)
qqline(rpoB_data$bray_from_inoculum, col = "red")
qqnorm(recA_data$bray_from_inoculum)
qqline(recA_data$bray_from_inoculum, col = "red")


# NOTE: we cannot fit any models with variety_genotype as a random effect - there are only 2 (max 3) observations
# per variety_genotype - not great regression stats with 2 data points!

# proportional data should be fit with either a beta regression or a binomial/logistical regression
# because we have 0s (you can't do beta if data has 0s or 1s) then we must use binomial family with logit link.
# However, for the bray-curtis distance from inoculum measures we can use beta regression.

# I have kept random effect of variety in the model. This is due to support from Ben Bolkers GLMM FAQ:
# https://bbolker.github.io/mixedmodels-misc/glmmFAQ.html#testing-significance-of-random-effects
# Consider not testing the significance of random effects. If the random effect is part of the experimental design, this procedure may be considered ‘sacrificial pseudoreplication’ (Hurlbert 1984). Using stepwise approaches to eliminate non-significant terms in order to squeeze more significance out of the remaining terms is dangerous in any case
# I have however calculated these models without variety as a random effect also, in order to demonstrate how
# much difference it makes.



# fit_gsA_rpoB -----------


# run full model
fit_gsA_rpoB <- glmer(cbind(gsA,1-gsA) ~ gpdiSizeCor + HueRateCor + (1|variety), 
                      family = binomial,
                      data = rpoB_data)


summary(fit_gsA_rpoB)


# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
# Family: binomial  ( logit )
# Formula: cbind(gsA, 1 - gsA) ~ gpdiSizeCor + HueRateCor + (1 | variety)
# Data: rpoB_data
# 
# AIC      BIC   logLik deviance df.resid 
# 59.9     68.6    -25.9     51.9       62 
# 
# Scaled residuals: 
#   Min       1Q   Median       3Q      Max 
# -0.49306 -0.26216 -0.02793  0.70174  2.18701 
# 
# Random effects:
# Groups  Name        Variance Std.Dev.
# variety (Intercept) 0        0       
# Number of obs: 66, groups:  variety, 19
# 
# Fixed effects:
#               Estimate Std. Error z value Pr(>|z|)    
# (Intercept)   -1.839      0.486  -3.784 0.000154 ***
# gpdiSizeCor    1.261      5.310   0.238 0.812217    
# HueRateCor    -4.820      2.492  -1.934 0.053055 .  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) gpdSzC
# gpdiSizeCor  0.569       
# HueRateCor   0.350 -0.044
# optimizer (Nelder_Mead) convergence code: 0 (OK)
# boundary (singular) fit: see help('isSingular')


# test as glm without random effect of variety
fit_gsA_rpoB_glm <- glm(cbind(gsA,1-gsA) ~ gpdiSizeCor + HueRateCor, 
                        family = binomial,
                        data = rpoB_data)

summary(fit_gsA_rpoB_glm)

# Call:
#   glm(formula = cbind(gsA, 1 - gsA) ~ gpdiSizeCor + HueRateCor, 
#       family = binomial, data = rpoB_data)
#
# Deviance Residuals: 
#   Min       1Q   Median       3Q      Max  
# -0.7646  -0.4959  -0.2589   0.3690   1.1832  
# 
# Coefficients:
#             Estimate Std. Error z value Pr(>|z|)    
# (Intercept) -1.29411    0.39282  -3.294 0.000986 ***
# gpdiSizeCor -0.08686    4.26507  -0.020 0.983751    
# HueRateCor  -2.88916    1.98846  -1.453 0.146234    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# (Dispersion parameter for binomial family taken to be 1)
# 
# Null deviance: 20.180  on 65  degrees of freedom
# Residual deviance: 17.956  on 63  degrees of freedom
# AIC: 60.901
# 
# Number of Fisher Scoring iterations: 4


# compare models with and without random effect
anova(fit_gsA_rpoB, fit_gsA_rpoB_glm)

# Data: rpoB_data
# Models:
# fit_gsA_rpoB_glm: cbind(gsA, 1 - gsA) ~ gpdiSizeCor + HueRateCor
# fit_gsA_rpoB: cbind(gsA, 1 - gsA) ~ gpdiSizeCor + HueRateCor + (1 | variety)
#                  npar    AIC   BIC  logLik deviance  Chisq Df Pr(>Chisq)  
# fit_gsA_rpoB_glm    3 60.901 67.47 -27.451   54.901                       
# fit_gsA_rpoB        4 59.881 68.64 -25.941   51.881 3.0202  1    0.08223 .
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1



# fit_gsB_rpoB ------------


# run full model
fit_gsB_rpoB <- glmer(cbind(gsB,1-gsB) ~ gpdiSizeCor + HueRateCor + (1|variety), 
                      family = binomial,
                      data = rpoB_data)


summary(fit_gsB_rpoB)

# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
# Family: binomial  ( logit )
# Formula: cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor + (1 | variety)
# Data: rpoB_data
# 
# AIC      BIC   logLik deviance df.resid 
# 91.3    100.1    -41.7     83.3       62 
# 
# Scaled residuals: 
#   Min      1Q  Median      3Q     Max 
# -1.5302 -0.4066  0.1293  0.5026  1.2958 
# 
# Random effects:
# Groups  Name        Variance Std.Dev.
# variety (Intercept) 0        0       
# Number of obs: 66, groups:  variety, 19
# 
# Fixed effects:
#             Estimate Std. Error z value Pr(>|z|)   
# (Intercept)  0.04776    0.33117   0.144  0.88533   
# gpdiSizeCor -1.58494    3.62336  -0.437  0.66180   
# HueRateCor   4.75666    1.82238   2.610  0.00905 **
#   ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) gpdSzC
# gpdiSizeCor  0.610       
# HueRateCor  -0.001 -0.059
# optimizer (Nelder_Mead) convergence code: 0 (OK)
# boundary (singular) fit: see help('isSingular')

# test as glm without random effect of variety
fit_gsB_rpoB_glm <- glm(cbind(gsB,1-gsB) ~ gpdiSizeCor + HueRateCor, 
                      family = binomial,
                      data = rpoB_data)

summary(fit_gsB_rpoB_glm)

# Call:
#   glm(formula = cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor, 
#       family = binomial, data = rpoB_data)
# 
# Deviance Residuals: 
#   Min        1Q    Median        3Q       Max  
# -1.20249  -0.47407   0.00276   0.54282   1.06953  
# 
# Coefficients:
#             Estimate Std. Error z value Pr(>|z|)
# (Intercept)   0.2935     0.3229   0.909    0.363
# gpdiSizeCor   1.0640     3.5008   0.304    0.761
# HueRateCor    2.4541     1.6585   1.480    0.139
# 
# (Dispersion parameter for binomial family taken to be 1)
# 
# Null deviance: 29.649  on 65  degrees of freedom
# Residual deviance: 27.245  on 63  degrees of freedom
# AIC: 91.705
# 
# Number of Fisher Scoring iterations: 3



# compare models with and without random effect
anova(fit_gsB_rpoB, fit_gsB_rpoB_glm)

# Data: rpoB_data
# Models:
# fit_gsB_rpoB_glm: cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor
# fit_gsB_rpoB: cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor + (1 | variety)
#                  npar    AIC     BIC  logLik deviance  Chisq Df Pr(>Chisq)
# fit_gsB_rpoB_glm    3 91.705  98.274 -42.852   85.705                     
# fit_gsB_rpoB        4 91.327 100.086 -41.664   83.327 2.3777  1     0.1231



# fit_gsC_rpoB -------------


# run full model
fit_gsC_rpoB <- glmer(cbind(gsC,1-gsC) ~ gpdiSizeCor + HueRateCor + (1|variety), 
                      family = binomial,
                      data = rpoB_data)


summary(fit_gsC_rpoB)


# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
# Family: binomial  ( logit )
# Formula: cbind(gsC, 1 - gsC) ~ gpdiSizeCor + HueRateCor + (1 | variety)
# Data: rpoB_data
# 
# AIC      BIC   logLik deviance df.resid 
# 35.5     44.3    -13.8     27.5       62 
# 
# Scaled residuals: 
#   Min      1Q  Median      3Q     Max 
# -0.4638  0.0546  0.5884  1.6863  4.7509 
# 
# Random effects:
# Groups  Name        Variance  Std.Dev. 
# variety (Intercept) 1.148e-09 3.389e-05
# Number of obs: 66, groups:  variety, 19
# 
# Fixed effects:
#             Estimate Std. Error z value Pr(>|z|)    
# (Intercept)  -3.3287     0.8518  -3.908 9.31e-05 ***
# gpdiSizeCor  -4.3484     6.6631  -0.653    0.514    
# HueRateCor    5.5248     3.8723   1.427    0.154    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) gpdSzC
# gpdiSizeCor  0.630       
# HueRateCor  -0.529 -0.100
# optimizer (Nelder_Mead) convergence code: 0 (OK)
# boundary (singular) fit: see help('isSingular')


# test as glm without random effect of variety
fit_gsC_rpoB_glm <- glm(cbind(gsC,1-gsC) ~ gpdiSizeCor + HueRateCor, 
                        family = binomial,
                        data = rpoB_data)

summary(fit_gsC_rpoB_glm)


# Call:
#   glm(formula = cbind(gsC, 1 - gsC) ~ gpdiSizeCor + HueRateCor, 
#       family = binomial, data = rpoB_data)
# 
# Deviance Residuals: 
#   Min       1Q   Median       3Q      Max  
# -0.6837  -0.3879  -0.1083   0.2701   0.9225  
# 
# Coefficients:
#             Estimate Std. Error z value Pr(>|z|)    
# (Intercept)  -1.3601     0.3897  -3.490 0.000484 ***
# gpdiSizeCor  -1.4380     4.1196  -0.349 0.727044    
# HueRateCor   -0.5956     1.9206  -0.310 0.756476    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# (Dispersion parameter for binomial family taken to be 1)
# 
# Null deviance: 12.754  on 65  degrees of freedom
# Residual deviance: 12.530  on 63  degrees of freedom
# AIC: 49.169
# 
# Number of Fisher Scoring iterations: 4



# compare models with and without random effect
anova(fit_gsC_rpoB, fit_gsC_rpoB_glm)

# Data: rpoB_data
# Models:
# fit_gsC_rpoB_glm: cbind(gsC, 1 - gsC) ~ gpdiSizeCor + HueRateCor
# fit_gsC_rpoB: cbind(gsC, 1 - gsC) ~ gpdiSizeCor + HueRateCor + (1 | variety)
#                  npar    AIC    BIC  logLik deviance Chisq Df Pr(>Chisq)    
# fit_gsC_rpoB_glm    3 49.169 55.738 -21.584   43.169                        
# fit_gsC_rpoB        4 35.509 44.267 -13.754   27.509 15.66  1   7.58e-05 ***
#   ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1



# fit_inoc_rpoB ----------


# there are no 0s or 1s so we can just use a beta dispersion model for data between 0 and 1
# https://stats.stackexchange.com/questions/233366/how-to-fit-a-mixed-model-with-response-variable-between-0-and-1

# run full model
fit_inoc_rpoB <- glmmTMB(bray_from_inoculum ~ gpdiSizeCor + HueRateCor + (1|variety), 
                 data = rpoB_data,
                 family = beta_family()
                 )


summary(fit_inoc_rpoB)

# Family: beta  ( logit )
# Formula:          bray_from_inoculum ~ gpdiSizeCor + HueRateCor + (1 | variety)
# Data: rpoB_data
# 
# AIC      BIC   logLik deviance df.resid 
# -9.1      1.9      9.5    -19.1       61 
# 
# Random effects:
#   
# Conditional model:
# Groups  Name        Variance Std.Dev.
# variety (Intercept) 0.02089  0.1445  
# Number of obs: 66, groups:  variety, 19
# 
# Dispersion parameter for beta family (): 4.02 
# 
# Conditional model:
#             Estimate Std. Error z value Pr(>|z|)   
# (Intercept)   0.1042     0.1444   0.722   0.4706   
# gpdiSizeCor   0.8802     1.5413   0.571   0.5679   
# HueRateCor    1.9746     0.7113   2.776   0.0055 **
#   ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# betareg package for nonmixed beta regressions
fit_inoc_rpoB_glm <- betareg(bray_from_inoculum ~ gpdiSizeCor + HueRateCor, data = rpoB_data)

summary(fit_inoc_rpoB_glm)

# Call:
#   betareg(formula = bray_from_inoculum ~ gpdiSizeCor + HueRateCor, data = rpoB_data)
# 
# Standardized weighted residuals 2:
#   Min      1Q  Median      3Q     Max 
# -2.2569 -0.7012  0.0615  0.7199  1.8755 
# 
# Coefficients (mean model with logit link):
#   Estimate Std. Error z value Pr(>|z|)   
# (Intercept)   0.1015     0.1397   0.727  0.46753   
# gpdiSizeCor   0.8683     1.5219   0.570  0.56835   
# HueRateCor    1.9716     0.7147   2.759  0.00581 **
#   
#   Phi coefficients (precision model with identity link):
#   Estimate Std. Error z value Pr(>|z|)    
# (phi)   3.9149     0.6144   6.372 1.86e-10 ***
#   ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 
# 
# Type of estimator: ML (maximum likelihood)
# Log-likelihood: 9.504 on 4 Df
# Pseudo R-squared: 0.1184
# Number of iterations: 15 (BFGS) + 2 (Fisher scoring) 



# fit_gsA_recA ------------


# run full model
fit_gsA_recA <- glmer(cbind(gsA,1-gsA) ~ gpdiSizeCor + HueRateCor + (1|variety), 
                      family = binomial,
                      data = recA_data)


summary(fit_gsA_recA)


# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
# Family: binomial  ( logit )
# Formula: cbind(gsA, 1 - gsA) ~ gpdiSizeCor + HueRateCor + (1 | variety)
# Data: recA_data
# 
# AIC      BIC   logLik deviance df.resid 
# 31.2     40.0    -11.6     23.2       62 
# 
# Scaled residuals: 
#   Min      1Q  Median      3Q     Max 
# -0.6140 -0.0641  0.2531  1.2933 14.0150 
# 
# Random effects:
# Groups  Name        Variance Std.Dev.
# variety (Intercept) 0        0       
# Number of obs: 66, groups:  variety, 19
# 
# Fixed effects:
#             Estimate Std. Error z value Pr(>|z|)   
# (Intercept)   -4.427      1.432  -3.093  0.00198 **
# gpdiSizeCor   -9.518      9.079  -1.048  0.29445   
# HueRateCor   -10.534      5.183  -2.033  0.04210 * 
#   ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) gpdSzC
# gpdiSizeCor 0.750        
# HueRateCor  0.771  0.361 
# optimizer (Nelder_Mead) convergence code: 0 (OK)
# boundary (singular) fit: see help('isSingular')


# test as glm without random effect of variety
fit_gsA_recA_glm <- glm(cbind(gsA,1-gsA) ~ gpdiSizeCor + HueRateCor, 
                        family = binomial,
                        data = recA_data)

summary(fit_gsA_recA_glm)

# Call:
#   glm(formula = cbind(gsA, 1 - gsA) ~ gpdiSizeCor + HueRateCor, 
#       family = binomial, data = recA_data)
# 
# Deviance Residuals: 
#   Min       1Q   Median       3Q      Max  
# -0.6229  -0.4117  -0.2025   0.1790   1.2658  
# 
# Coefficients:
#             Estimate Std. Error z value Pr(>|z|)    
# (Intercept)  -1.7746     0.4612  -3.848 0.000119 ***
# gpdiSizeCor   1.3194     5.1903   0.254 0.799335    
# HueRateCor   -3.2936     2.3641  -1.393 0.163570    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# (Dispersion parameter for binomial family taken to be 1)
# 
# Null deviance: 15.868  on 65  degrees of freedom
# Residual deviance: 13.768  on 63  degrees of freedom
# AIC: 37.953
# 
# Number of Fisher Scoring iterations: 5


# compare models with and without random effect
anova(fit_gsA_recA, fit_gsA_recA_glm)

# Data: recA_data
# Models:
# fit_gsA_recA_glm: cbind(gsA, 1 - gsA) ~ gpdiSizeCor + HueRateCor
# fit_gsA_recA: cbind(gsA, 1 - gsA) ~ gpdiSizeCor + HueRateCor + (1 | variety)
#                  npar    AIC    BIC  logLik deviance  Chisq Df Pr(>Chisq)   
# fit_gsA_recA_glm    3 37.953 44.522 -15.977   31.953                        
# fit_gsA_recA        4 31.242 40.000 -11.621   23.242 8.7113  1   0.003162 **
#   ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1



# fit_gsB_recA ------------


# run full model
fit_gsB_recA <- glmer(cbind(gsB,1-gsB) ~ gpdiSizeCor + HueRateCor + (1|variety), 
                      family = binomial,
                      data = recA_data)


summary(fit_gsB_recA)

# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
# Family: binomial  ( logit )
# Formula: cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor + (1 | variety)
# Data: recA_data
# 
# AIC      BIC   logLik deviance df.resid 
# 53.0     61.7    -22.5     45.0       62 
# 
# Scaled residuals: 
#   Min      1Q  Median      3Q     Max 
# -3.3585 -0.5645 -0.0167  0.2027  0.5028 
# 
# Random effects:
# Groups  Name        Variance  Std.Dev.
# variety (Intercept) 1.077e-05 0.003282
# Number of obs: 66, groups:  variety, 19
# 
# Fixed effects:
#             Estimate Std. Error z value Pr(>|z|)    
# (Intercept)   1.8689     0.4811   3.885 0.000102 ***
# gpdiSizeCor  -6.0421     6.2810  -0.962 0.336067    
# HueRateCor    4.4558     2.6945   1.654 0.098193 .  
# ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) gpdSzC
# gpdiSizeCor  0.434       
# HueRateCor   0.327 -0.155
# optimizer (Nelder_Mead) convergence code: 0 (OK)
# unable to evaluate scaled gradient
# Model failed to converge: degenerate  Hessian with 1 negative eigenvalues

library(dfoptim)
library(optimx)
# model does not converge therefore use allFit (part of lme4 package) which will
# attempt to re-fit the model with a range of optimisers. 
# see if the optimise models all come to the same conclusion. If they all come to the same conclusion
# then the model warnings are likely to not be a problem. The model developers have also suggested 
# increasing the threshold to convergence to 0.01.
# see which optimised model, and the original model, has the best fit and pick that (assuming they all
# come to the same conclusion).
allfit <- allFit(fit_gsB_recA)
summary(allfit)

# The easiest way to interpret this is that these log-likelihoods should all be within thousandths of a decimal point from each other. Here, we can be assured that the model’s parameters we report do not depend on the optimizer we chose.
# $llik
# bobyqa                   Nelder_Mead                    nlminbwrap 
# -22.48315                     -22.48325                     -22.48325 
# nmkbw               optimx.L-BFGS-B nloptwrap.NLOPT_LN_NELDERMEAD 
# -22.48325                     -22.48325                     -22.48325 
# nloptwrap.NLOPT_LN_BOBYQA 
# -22.48315  

# all models come to  approximately the same log-likelihood result. Therefore the optimiser doesn't influence result

# we can also see if the model will converge if we restart the fit from the apparent optimum, 
# or from a point perturbed slightly away from the optimum 
# (getME(model,c("theta","beta")) 
# should retrieve the parameters in a form suitable to be used as the start parameter)
# https://rstudio-pubs-static.s3.amazonaws.com/33653_57fc7b8e5d484c909b615d8633c01d51.html
ss <- getME(fit_gsB_recA, c("theta", "fixef"))
m2 <- update(fit_gsB_recA, start=ss)
summary(m2)

# We get no convergent warnings so the model is also good this way!
# Clearly just needed a few more iterations

# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
# Family: binomial  ( logit )
# Formula: cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor + (1 | variety)
# Data: recA_data
# 
# AIC      BIC   logLik deviance df.resid 
# 53.0     61.7    -22.5     45.0       62 
# 
# Scaled residuals: 
#   Min      1Q  Median      3Q     Max 
# -3.3353 -0.5646 -0.0182  0.2011  0.5015 
# 
# Random effects:
#   Groups  Name        Variance Std.Dev.
# variety (Intercept) 0.009833 0.09916 
# Number of obs: 66, groups:  variety, 19
# 
# Fixed effects:
#              Estimate Std. Error z value Pr(>|z|)    
# (Intercept)   1.8718     0.5238   3.573 0.000353 ***
# gpdiSizeCor  -6.0608     6.4278  -0.943 0.345735    
# HueRateCor    4.4573     2.6984   1.652 0.098571 .  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Correlation of Fixed Effects:
#             (Intr) gpdSzC
# gpdiSizeCor  0.311       
# HueRateCor   0.315 -0.160



# we can check if the newly converged model is significantly different fit
anova(m2, fit_gsB_recA)

# Data: recA_data
# Models:
#   m2: cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor + (1 | variety)
# fit_gsB_recA: cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor + (1 | variety)
#              npar    AIC    BIC  logLik deviance Chisq Df Pr(>Chisq)
# m2              4 52.966 61.725 -22.483   44.966                    
# fit_gsB_recA    4 52.967 61.725 -22.483   44.967     0  0 

# models are not significantly different still. Think I can stick with the false pos. non-converged model.


# test as glm without random effect of variety
fit_gsB_recA_glm <- glm(cbind(gsB,1-gsB) ~ gpdiSizeCor + HueRateCor, 
                        family = binomial,
                        data = recA_data)

summary(fit_gsB_recA_glm)

# Call:
#   glm(formula = cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor, 
#       family = binomial, data = recA_data)
# 
# Deviance Residuals: 
#   Min       1Q   Median       3Q      Max  
# -1.7490  -0.2097   0.2653   0.4346   0.6882  
# 
# Coefficients:
#             Estimate Std. Error z value Pr(>|z|)    
# (Intercept)   1.3730     0.4033   3.404 0.000663 ***
# gpdiSizeCor  -0.6900     4.4581  -0.155 0.877006    
# HueRateCor    3.1475     2.0664   1.523 0.127722    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# (Dispersion parameter for binomial family taken to be 1)
# 
# Null deviance: 21.918  on 65  degrees of freedom
# Residual deviance: 19.448  on 63  degrees of freedom
# AIC: 55.387
# 
# Number of Fisher Scoring iterations: 4


# compare models with and without random effect
anova(fit_gsB_recA, fit_gsB_recA_glm)

# Data: recA_data
# Models:
# fit_gsB_recA_glm: cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor
# fit_gsB_recA: cbind(gsB, 1 - gsB) ~ gpdiSizeCor + HueRateCor + (1 | variety)
# npar    AIC    BIC  logLik deviance  Chisq Df Pr(>Chisq)  
# fit_gsB_recA_glm    3 55.387 61.956 -24.694   49.387                       
# fit_gsB_recA        4 52.967 61.725 -22.483   44.967 4.4208  1     0.0355 *
#   ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1



# fit_gsC_recA ------------


# run full model
fit_gsC_recA <- glmer(cbind(gsC,1-gsC) ~ gpdiSizeCor + HueRateCor + (1|variety), 
                      family = binomial,
                      data = recA_data)


summary(fit_gsC_recA)

# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
# Family: binomial  ( logit )
# Formula: cbind(gsC, 1 - gsC) ~ gpdiSizeCor + HueRateCor + (1 | variety)
# Data: recA_data
# 
# AIC      BIC   logLik deviance df.resid 
# 8.0     16.8      0.0      0.0       62 
# 
# Scaled residuals: 
#   Min       1Q   Median       3Q      Max 
# 0   592675  2147198  5560802 22951456 
# 
# Random effects:
# Groups  Name        Variance Std.Dev.
# variety (Intercept) 0        0       
# Number of obs: 66, groups:  variety, 19
# 
# Fixed effects:
#               Estimate Std. Error z value Pr(>|z|)
# (Intercept)     -1730   10489043       0        1
# gpdiSizeCor     18105  114424886       0        1
# HueRateCor      -6763   53031535       0        1
# 
# Correlation of Fixed Effects:
#             (Intr) gpdSzC
# gpdiSizeCor  0.616       
# HueRateCor  -0.024 -0.039
# optimizer (Nelder_Mead) convergence code: 0 (OK)
# boundary (singular) fit: see help('isSingular')
# 
# Warning messages:
#   1: In vcov.merMod(object, use.hessian = use.hessian) :
#   variance-covariance matrix computed from finite-difference Hessian is
# not positive definite or contains NA values: falling back to var-cov estimated from RX
# 2: In vcov.merMod(object, correlation = correlation, sigm = sig) :
#   variance-covariance matrix computed from finite-difference Hessian is
# not positive definite or contains NA values: falling back to var-cov estimated from RX


library(dfoptim)
library(optimx)
# model does not converge therefore use allFit (part of lme4 package) which will
# attempt to re-fit the model with a range of optimisers. 
# see if the optimise models all come to the same conclusion. If they all come to the same conclusion
# then the model warnings are likely to not be a problem. The model developers have also suggested 
# increasing the threshold to convergence to 0.01.
# see which optimised model, and the original model, has the best fit and pick that (assuming they all
# come to the same conclusion).
allfit_gsC <- allFit(fit_gsC_recA)
summary(allfit_gsC)

# The easiest way to interpret this is that these log-likelihoods should all be within thousandths of a decimal point from each other. Here, we can be assured that the model’s parameters we report do not depend on the optimizer we chose.
# $llik
# bobyqa                   Nelder_Mead                    nlminbwrap 
# -1.465494e-14                 -1.465494e-14                 -1.465494e-14 
# nmkbw               optimx.L-BFGS-B nloptwrap.NLOPT_LN_NELDERMEAD 
# -1.465494e-14                 -7.399668e-10                 -1.465494e-14 
# nloptwrap.NLOPT_LN_BOBYQA 
# -2.123280e-07

# most models come to  approximately the same log-likelihood results, but some such as optimx.L-BFGS-B and nloptwrap.NLOPT_LN_BOBYQA are a but different. This could suggest that changing the optimiser will help.

# we can also see if the model will converge if we restart the fit from the apparent optimum, 
# or from a point perturbed slightly away from the optimum 
# (getME(model,c("theta","beta")) 
# should retrieve the parameters in a form suitable to be used as the start parameter)
# https://rstudio-pubs-static.s3.amazonaws.com/33653_57fc7b8e5d484c909b615d8633c01d51.html
ss_gsC <- getME(fit_gsC_recA, c("theta", "fixef"))
m2_gsC <- update(fit_gsC_recA, start=ss_gsC)
summary(m2_gsC)

# We do still get convergent warnings so likely best option is to change the optimiser.

# rerun model with different optimiser

fit_gsC_recA_nlop <- glmer(cbind(gsC,1-gsC) ~ gpdiSizeCor + HueRateCor + (1|variety), 
                      family = binomial,
                      control = glmerControl(optimizer = "nloptwrap"),
                      data = recA_data)


summary(fit_gsC_recA_nlop)

# Generalized linear mixed model fit by maximum likelihood (Laplace Approximation) ['glmerMod']
# Family: binomial  ( logit )
# Formula: cbind(gsC, 1 - gsC) ~ gpdiSizeCor + HueRateCor + (1 | variety)
# Data: recA_data
# Control: glmerControl(optimizer = "nloptwrap")
# 
# AIC      BIC   logLik deviance df.resid 
# 8.0     16.8      0.0      0.0       62 
# 
# Scaled residuals: 
#   Min     1Q Median     3Q    Max 
# 0.0  215.9  798.6 1544.0 7988.9 
# 
# Random effects:
#   Groups  Name        Variance  Std.Dev. 
# variety (Intercept) 9.794e-29 9.897e-15
# Number of obs: 66, groups:  variety, 19
# 
# Fixed effects:
#               Estimate Std. Error z value Pr(>|z|)
# (Intercept)   -19.9222  3594.1235  -0.006    0.996
# gpdiSizeCor     0.9201 36297.7902   0.000    1.000
# HueRateCor     -6.0004 15724.6195   0.000    1.000
# 
# Correlation of Fixed Effects:
#   (Intr) gpdSzC
# gpdiSizeCor  0.540       
# HueRateCor   0.584 -0.004
# optimizer (nloptwrap) convergence code: 0 (OK)
# boundary (singular) fit: see help('isSingular')

# There are no convergence warnings any more! Use this model. 





# test as glm without random effect of variety
fit_gsC_recA_glm <- glm(cbind(gsC,1-gsC) ~ gpdiSizeCor + HueRateCor, 
                        family = binomial,
                        data = recA_data)

summary(fit_gsC_recA_glm)

# Call:
#   glm(formula = cbind(gsC, 1 - gsC) ~ gpdiSizeCor + HueRateCor, 
#       family = binomial, data = recA_data)
# 
# Deviance Residuals: 
#   Min       1Q   Median       3Q      Max  
# -0.3711  -0.2559  -0.1082   0.1054   0.8087  
# 
# Coefficients:
#             Estimate Std. Error z value Pr(>|z|)    
# (Intercept)  -2.8389     0.6977  -4.069 4.73e-05 ***
# gpdiSizeCor  -0.8413     7.3695  -0.114    0.909    
# HueRateCor   -1.7971     3.3879  -0.530    0.596    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# (Dispersion parameter for binomial family taken to be 1)
# 
# Null deviance: 5.0218  on 65  degrees of freedom
# Residual deviance: 4.7204  on 63  degrees of freedom
# AIC: 14.159
# 
# Number of Fisher Scoring iterations: 6



# compare models with and without random effect
anova(fit_gsC_recA, fit_gsC_recA_glm)

# Data: recA_data
# Models:
# fit_gsC_recA_glm: cbind(gsC, 1 - gsC) ~ gpdiSizeCor + HueRateCor
# fit_gsC_recA: cbind(gsC, 1 - gsC) ~ gpdiSizeCor + HueRateCor + (1 | variety)
#                  npar    AIC    BIC  logLik deviance  Chisq Df Pr(>Chisq)   
# fit_gsC_recA_glm    3 14.159 20.728 -4.0797   8.1594                        
# fit_gsC_recA        4  8.000 16.759  0.0000   0.0000 8.1594  1   0.004284 **
#   ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1



# fit_inoc_recA -------------


# there are no 0s or 1s so we can just use a beta dispersion model for data between 0 and 1
# https://stats.stackexchange.com/questions/233366/how-to-fit-a-mixed-model-with-response-variable-between-0-and-1

# run full model
fit_inoc_recA <- glmmTMB(bray_from_inoculum ~ gpdiSizeCor + HueRateCor + (1|variety), 
                         data = recA_data,
                         family = beta_family()
)


summary(fit_inoc_recA)

# Family: beta  ( logit )
# Formula:          bray_from_inoculum ~ gpdiSizeCor + HueRateCor + (1 | variety)
# Data: recA_data
# 
# AIC      BIC   logLik deviance df.resid 
# -46.6    -35.7     28.3    -56.6       61 
# 
# Random effects:
#   
# Conditional model:
# Groups  Name        Variance Std.Dev.
# variety (Intercept) 0.2764   0.5258  
# Number of obs: 66, groups:  variety, 19
# 
# Dispersion parameter for beta family (): 8.26 
# 
# Conditional model:
#             Estimate Std. Error z value Pr(>|z|)    
# (Intercept)   0.8643     0.1774   4.872 1.11e-06 ***
# gpdiSizeCor  -0.1795     1.4674  -0.122  0.90264    
# HueRateCor    1.7758     0.6577   2.700  0.00693 ** 
#   ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1



# betareg package for nonmixed beta regressions
fit_inoc_recA_glm <- betareg(bray_from_inoculum ~ gpdiSizeCor + HueRateCor, data = recA_data)

summary(fit_inoc_recA_glm)

# Call:
#   betareg(formula = bray_from_inoculum ~ gpdiSizeCor + HueRateCor, data = recA_data)
# 
# Standardized weighted residuals 2:
#   Min      1Q  Median      3Q     Max 
# -2.9535 -0.5812  0.2952  0.6613  1.2979 
# 
# Coefficients (mean model with logit link):
#             Estimate Std. Error z value Pr(>|z|)    
# (Intercept)   0.7834     0.1337   5.858 4.67e-09 ***
# gpdiSizeCor  -0.2037     1.4337  -0.142   0.8870    
# HueRateCor    1.8825     0.6675   2.820   0.0048 ** 
#   
# Phi coefficients (precision model with identity link):
# Estimate Std. Error z value Pr(>|z|)    
# (phi)   5.1544     0.8424   6.119 9.44e-10 ***
#   ---
# Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 
# 
# Type of estimator: ML (maximum likelihood)
# Log-likelihood: 23.87 on 4 Df
# Pseudo R-squared: 0.1141
# Number of iterations: 15 (BFGS) + 3 (Fisher scoring)



### greenness vs braycurtis_dist_from_inoc plot --------------


# when setting colour palettes we must set the seed so they are all the same as the previous figures
set.seed(6)

# number of unique varieties (so know for colour palette)
length(unique(rpoB_data$variety))
# [1] 19
library(Polychrome)
# build variety color palette
varietycol <-  setNames(createPalette(19,  c("#ff0000", "#00ff00", "#0000ff")), 
                        sort(unique(rpoB_data$variety)))


# rpoB data (variety) not corrected HueRate
(rpoBplot <- ggplot(data = rpoB_data, aes(x = bray_from_inoculum, y = HueRate)) +
  geom_point(aes(col = variety), size = 5) +
  geom_smooth(col = "black", method = "lm", se = F, size = 2) +
  #geom_smooth(aes(group = variety), method = "lm", se = F, size = 2) +
  scale_color_manual(values = varietycol) +
  labs(x = "Bray-Curtis distance from inoculum rpoB gs frequency",
       y = "Rate of Hue (rate of greenness over time)") +
  theme_bw() +
  theme(legend.title = element_text(size = 20), 
      axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
      axis.text.y = element_text(size = 10),
      axis.title=element_text(size = 20),
      strip.text.x = element_text(size = 20),
      legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/braycurtis_v_greenness_rpoB.pdf', plot = rpoBplot, width = 25, height = 20, unit = 'cm')

# rpoB data (variety) corrected HueRate
(rpoBplotCor <- ggplot(data = rpoB_data, aes(x = bray_from_inoculum, y = HueRateCor, col = variety)) +
    geom_point(size = 5) +
    geom_smooth(col = "black", method = "lm", se = F, size = 2) +
    #geom_smooth(aes(group = variety), method = "lm", se = F, size = 2) +
    scale_color_manual(values = varietycol) +
    labs(x = "Bray-Curtis distance from inoculum rpoB gs frequency",
         y = "Rate of Hue (rate of greenness over time)") +
    theme_bw() +
    theme(legend.title = element_text(size = 20), 
          axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
          axis.text.y = element_text(size = 10),
          axis.title=element_text(size = 20),
          strip.text.x = element_text(size = 20),
          legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/braycurtis_v_greenness_rpoB_Cor.pdf', plot = rpoBplotCor, width = 25, height = 20, unit = 'cm')



# recA data (variety) not corrected HueRate
(recAplot <- ggplot(data = recA_data, aes(x = bray_from_inoculum, y = HueRate, col = variety)) +
  geom_point(size = 5) +
  geom_smooth(col = "black", method = "lm", se = F, size = 2) +
  #geom_smooth(aes(group = variety), method = "lm", se = F, size = 2) +
  scale_color_manual(values = varietycol) +
  labs(x = "Bray-Curtis distance from inoculum recA gs frequency",
       y = "Rate of Hue (rate of greenness over time)") +
  theme_bw() +
  theme(legend.title = element_text(size = 20), 
        axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
        axis.text.y = element_text(size = 10),
        axis.title=element_text(size = 20),
        strip.text.x = element_text(size = 20),
        legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/braycurtis_v_greenness_recA.pdf', plot = recAplot, width = 25, height = 20, unit = 'cm')

# recA data (variety) corrected HueRate
(recAplotCor <- ggplot(data = recA_data, aes(x = bray_from_inoculum, y = HueRateCor, col = variety)) +
    geom_point(size = 5) +
    geom_smooth(col = "black", method = "lm", se = F, size = 2) +
    #geom_smooth(aes(group = variety), method = "lm", se = F, size = 2) +
    scale_color_manual(values = varietycol) +
    labs(x = "Bray-Curtis distance from inoculum recA gs frequency",
         y = "Rate of Hue (rate of greenness over time)") +
    theme_bw() +
    theme(legend.title = element_text(size = 20), 
          axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
          axis.text.y = element_text(size = 10),
          axis.title=element_text(size = 20),
          strip.text.x = element_text(size = 20),
          legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/braycurtis_v_greenness_recA_Cor.pdf', plot = recAplotCor, width = 25, height = 20, unit = 'cm')



# rpoB data (genotype) not corrected HueRate
(rpoBplot2 <- ggplot(data = rpoB_data, aes(x = bray_from_inoculum, y = HueRate, col = variety_genotype)) +
    geom_point(size = 5) +
    geom_smooth(col = "black", method = "lm", se = F, size = 2) +
    #geom_smooth(aes(group = variety_genotype), method = "lm", se = F, size = 2) +
    #scale_color_manual(values = varietycol) +
    labs(x = "Bray-Curtis distance from inoculum rpoB gs frequency",
         y = "Rate of Hue (rate of greenness over time)") +
    theme_bw() +
    theme(legend.title = element_text(size = 20), 
          axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
          axis.text.y = element_text(size = 10),
          axis.title=element_text(size = 20),
          strip.text.x = element_text(size = 20),
          legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/braycurtis_v_greenness_rpoB_genotype.pdf', plot = rpoBplot2, width = 30, height = 25, unit = 'cm')

# rpoB data (genotype) corrected HueRate
(rpoBplot2Cor <- ggplot(data = rpoB_data, aes(x = bray_from_inoculum, y = HueRateCor, col = variety_genotype)) +
    geom_point(size = 5) +
    geom_smooth(col = "black", method = "lm", se = F, size = 2) +
    #geom_smooth(aes(group = variety_genotype), method = "lm", se = F, size = 2) +
    #scale_color_manual(values = varietycol) +
    labs(x = "Bray-Curtis distance from inoculum rpoB gs frequency",
         y = "Rate of Hue (rate of greenness over time)") +
    theme_bw() +
    theme(legend.title = element_text(size = 20), 
          axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
          axis.text.y = element_text(size = 10),
          axis.title=element_text(size = 20),
          strip.text.x = element_text(size = 20),
          legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/braycurtis_v_greenness_rpoB_genotype_Cor.pdf', plot = rpoBplot2Cor, width = 30, height = 25, unit = 'cm')


# recA data (genotype) not corrected HueRate
(recAplot2 <- ggplot(data = recA_data, aes(x = bray_from_inoculum, y = HueRate, col = variety_genotype)) +
    geom_point(size = 5) +
    geom_smooth(col = "black", method = "lm", se = F, size = 2) +
    #geom_smooth(aes(group = variety_genotype), method = "lm", se = F, size = 2) +
    #scale_color_manual(values = varietycol) +
    labs(x = "Bray-Curtis distance from inoculum recA gs frequency",
         y = "Rate of Hue (rate of greenness over time)") +
    theme_bw() +
    theme(legend.title = element_text(size = 20), 
          axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
          axis.text.y = element_text(size = 10),
          axis.title=element_text(size = 20),
          strip.text.x = element_text(size = 20),
          legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/braycurtis_v_greenness_recA_genotype.pdf', plot = recAplot2, width = 30, height = 25, unit = 'cm')

# recA data (genotype) corrected HueRate
(recAplot2Cor <- ggplot(data = recA_data, aes(x = bray_from_inoculum, y = HueRateCor, col = variety_genotype)) +
    geom_point(size = 5) +
    geom_smooth(col = "black", method = "lm", se = F, size = 2) +
    #geom_smooth(aes(group = variety_genotype), method = "lm", se = F, size = 2) +
    #scale_color_manual(values = varietycol) +
    labs(x = "Bray-Curtis distance from inoculum recA gs frequency",
         y = "Rate of Hue (rate of greenness over time)") +
    theme_bw() +
    theme(legend.title = element_text(size = 20), 
          axis.text.x = element_text(size = 10, angle = 90, h = 1, v = 1),
          axis.text.y = element_text(size = 10),
          axis.title=element_text(size = 20),
          strip.text.x = element_text(size = 20),
          legend.text = element_text(size = 18))
)
# function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Supplementary/braycurtis_v_greenness_recA_genotype_Cor.pdf', plot = recAplot2Cor, width = 30, height = 25, unit = 'cm')



# plot bray-curtis score -------------------


# clear objects from work space and start again to make this figure.

# make new dataframe for rpoB and recA bray_from_inoculum values

# read in data 
rpoB_data <- read.csv("../data/raw_data/greenhouse_experiment_plantinfo/greenhouse_rpob_ra_matrix_genospecies.csv")

recA_data <- read.csv("../data/raw_data/greenhouse_experiment_plantinfo/greenhouse_reca_ra_matrix_genospecies.csv")

# subset genospecies composition for recA and rpoB
rpoB_data_gs <- rpoB_data[c("variety_genotype_pot", "gsA", "gsB", "gsC")]

recA_data_gs <- recA_data[c("variety_genotype_pot", "gsA", "gsB", "gsC")]

# number of rows
nrow(rpoB_data_gs)
# [1] 82

# add in new row which is the initial inoculum
# 6 gsA, 1 gsB, and 3 gsC strains (60% gsA, 10% gsB, 30% gsC)
rpoB_data_gs[c(nrow(rpoB_data_gs)+1),1] <- c("inoculum")
rpoB_data_gs[c(nrow(rpoB_data_gs)),2:4] <- c(0.6, 0.1, 0.3)

recA_data_gs[c(nrow(recA_data_gs)+1),1] <- c("inoculum")
recA_data_gs[c(nrow(recA_data_gs)),2:4] <- c(0.6, 0.1, 0.3)

# make variety_genotype_pot the row names
row.names(rpoB_data_gs) <- rpoB_data_gs$variety_genotype_pot
rpoB_data_gs$variety_genotype_pot <- NULL

row.names(recA_data_gs) <- recA_data_gs$variety_genotype_pot
recA_data_gs$variety_genotype_pot <- NULL

# calculate bray-curtis dissimilarity
bray_dist_rpoB <- vegdist(rpoB_data_gs, method = "bray", diag = TRUE)

bray_dist_recA <- vegdist(recA_data_gs, method = "bray", diag = TRUE)

# convert dist into a dataframe
bray_dist_rpoB <- as.data.frame(as.matrix(bray_dist_rpoB))
bray_dist_rpoB$variety_genotype_pot <- row.names(bray_dist_rpoB)

bray_dist_recA <- as.data.frame(as.matrix(bray_dist_recA))
bray_dist_recA$variety_genotype_pot <- row.names(bray_dist_recA)

# add the distance compared to the inoculum as a new column in the original data
rpoB_data <- left_join(rpoB_data, bray_dist_rpoB[c("inoculum", "variety_genotype_pot")], by = "variety_genotype_pot")
names(rpoB_data)[ncol(rpoB_data)] <- "bray_from_inoculum"

recA_data <- left_join(recA_data, bray_dist_recA[c("inoculum", "variety_genotype_pot")], by = "variety_genotype_pot")
names(recA_data)[ncol(recA_data)] <- "bray_from_inoculum"

# merge metadata with genospecies frequency data
bray_data <- merge(rpoB_data[c("variety_genotype_pot", "variety_genotype", "bray_from_inoculum")], recA_data[c("variety_genotype_pot", "bray_from_inoculum")], by = "variety_genotype_pot", all.x = T)

# rename bray_from_inoculum
names(bray_data)[3:4] <- c("rpoB", "recA")

# melt data
bray_data_melt <- melt(bray_data, id.vars = c('variety_genotype_pot', 'variety_genotype'))

# rename variable and value columns
names(bray_data_melt)[3:4] <- c('gene', 'bray_from_inoculum')

# add in new rows for initial inoculum
nrow(bray_data_melt)
# [1] 164
bray_data_melt[165,] <- c("Initial Inoculum", "Initial Inoculum", "rpoB", "0")
bray_data_melt[166,] <- c("Initial Inoculum", "Initial Inoculum", "recA", "0")

# make bray curtis value numeric again
bray_data_melt$bray_from_inoculum <- as.numeric(bray_data_melt$bray_from_inoculum)

# reorder the variety names and samples
bray_data_melt$variety_genotype_pot <- factor(bray_data_melt$variety_genotype_pot,
                              levels = c("Initial Inoculum", 
                                         unique(bray_data_melt$variety_genotype_pot[!bray_data_melt$variety_genotype_pot %in% "Initial Inoculum"])))


# make bray-curtis dot plot charts.
(brayplot <- ggplot(bray_data_melt, aes(x = variety_genotype_pot, y = bray_from_inoculum, col = gene)) +
   geom_point(size = 3) +
   #geom_line(aes(group = gene)) +
   xlab("Samples") +
   ylab("Dissimilarity\nfrom inoculum") + 
   labs(colour = "Gene") +
   scale_color_manual(values = c("black", "red")) +
   theme_bw() +
   theme(legend.title = element_text(size = 35), 
         legend.text = element_text(size = 30),
         axis.title=element_text(size = 35),
         axis.text.x = element_blank(), # make sure to check the order is correct before blanking
         axis.text.y = element_text(size = 10),
         axis.ticks.x = element_blank(),
         strip.text = element_text(size = 20),
         strip.text.y = element_text(face = "italic"),
         strip.text.x = element_text(angle = 90))
)
#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Fig6/braycurtis_dotplot.pdf', plot = brayplot, width = 43, height = 10, unit = 'cm')



