# Author: Bryden Fields
# Email: bryden.fields@york.ac.uk

# Initial set-up ---------------

library(agricolae)
library(tidyr)
library(ggplot2)
library(reshape2)
library(plyr)
library(dplyr)
library(lme4)

#set the working directory to the directory this script is in.
#setwd("~/whatever/folder/you/are/working/from")
setwd('/Users/brydenfields/Documents/Publications/2023_Clovergenotype_paper/scripts')



# read in and format data ----------


# read in greenhouse growth data (from Sara's paper)
data.greenhouse = read.csv2("../data/raw_data/greenhouse_experiment_plantinfo/122_2021_3955_MOESM3_ESM.csv", row.names = NULL, sep = ",")

# read in genospecies frequency data
data.recA = read.csv2("../data/raw_data/greenhouse_experiment_plantinfo/greenhouse_reca_ra_matrix_genospecies.csv", sep = ",")
data.rpoB = read.csv2("../data/raw_data/greenhouse_experiment_plantinfo/greenhouse_rpob_ra_matrix_genospecies.csv", sep = ",")

# include greenness data (from Marni's paper) into data.greenhouse
greenness_data <- read.csv("../data/raw_data/greenhouse_experiment_plantinfo/growth_data.csv")

# keep only the greenness data that also has growth data
data.greenhouse <- left_join(data.greenhouse,
                             greenness_data[,!(names(greenness_data) %in% c("Round", "Replicate", "Clover",
                                                "Rhizobium", "NS", "EW"))],
                             by = c("Barcode"))



# standardisation for gpd with iSize ---------------


# filter the data first (only the barcodes in the rpob/reca datasets) and then do the standardisation
data.greenhouse_filt <- data.greenhouse[data.greenhouse$Barcode %in% data.recA$barcode,]
data.greenhouse_filt <- data.greenhouse_filt[complete.cases(data.greenhouse_filt),]

# get the fixed effect of isize via linear model
fit <- lm(as.numeric(gpd) ~ as.numeric(iSize), data=data.greenhouse_filt)

# # how many unique barcodes:
length(unique(data.greenhouse_filt$Barcode))
# [1] 66

# how many unique iSizes
length(unique(data.greenhouse_filt$iSize))
# [1] 66

# then get the correction by taking original gpd value and taking away fixed effect of iSize (the intercept of lm minus the estimate of your isize fixed effect)
ycorr <- as.numeric(data.greenhouse_filt$gpd) - model.matrix( ~ as.numeric(iSize), data=data.greenhouse_filt) %*% fit$coefficients
data.greenhouse_filt$gpdiSizeCor <- ycorr #this is the new corrected dry weight



# standardisation for HueRate with StartHue -----------


# get the fixed effect of StartHue via linear model
fit <- lm(as.numeric(HueRate) ~ as.numeric(StartHue), data=data.greenhouse_filt)

# # how many unique barcodes:
length(unique(data.greenhouse_filt$Barcode))
# [1] 66

# how many unique StartHue
length(unique(data.greenhouse_filt$StartHue))
# [1] 66

# then get the correction by taking original HueRate value and taking away fixed effect of StartHue (the intercept of lm minus the estimate of your StartHue fixed effect)
ycorr <- as.numeric(data.greenhouse_filt$HueRate) - model.matrix( ~ as.numeric(StartHue), data=data.greenhouse_filt) %*% fit$coefficients
data.greenhouse_filt$HueRateCor <- ycorr #this is the new corrected greeness rate


# combine with the recA and rpoB genospecies datasets 
data.greenhouse_filt_recA <- inner_join(data.recA, data.greenhouse_filt, by = c("barcode" = "Barcode"))
data.greenhouse_filt_rpoB <- inner_join(data.rpoB, data.greenhouse_filt, by = c("barcode" = "Barcode"))
# there should be 66 rows

# save file for use in the 'clovergenotype_greenhouse_plantgrowth_gsfrequencies_vs_plantgrowth_analyses.R" script
write.csv(data.greenhouse_filt_recA , "../data/data_output/greenhouse_experiment_plantinfo/combined_greenhouse_growth_greenness_genospecies_recA.csv", row.names = F)
write.csv(data.greenhouse_filt_rpoB , "../data/data_output/greenhouse_experiment_plantinfo/combined_greenhouse_growth_greenness_genospecies_rpoB.csv", row.names = F)



