# Author: Bryden Fields
# Email: bryden.fields@york.ac.uk

# Initial setup --------------------

library(plyr)
library(tidyverse)
library(reshape2)
library(data.table)
library(devtools)
library(ggbiplot)
library(ggfortify)
library(factoextra)
library(ggpubr)
library(vegan)
library(MASS)
library(labdsv)
library(mpmcorrelogram)
library(pheatmap)
library(RColorBrewer)
library(pairwiseAdonis)


#set the working directory to the directory this script is in.
#setwd("~/whatever/folder/you/are/working/from")
setwd("/Users/brydenfields/Documents/Publications/2023_Clovergenotype_paper/scripts")



# Spatial analysis klondike only: all genes ----------------


# euclidean distance between x and y sample plot coordinates and
# bray-curtis similarity between allelic relative abundances. 

# read in relative abundance matrix for all genes combined made previously (NOT log transformed)
ra_matrix <- read.csv('../data/data_output/abundance_data/clovergeno_allgenes_pca_matrix_withingene_ra.csv')
names(ra_matrix)[1] <- 'sample'

# read in environment data and combine with the x and y coordinates for each sample
# location is the x and y coordinates for each plot
location <- read.csv('../data/raw_data/abundance_data/plot_environment_data_xycoordinates.csv')
# merge together for filtering the matrix later
ra_matrix <- merge(ra_matrix, location[,c("sample", "x", "y")], by = 'sample', all.x = T)

# filter for klondike only in environment data and then just keep the coordinate info
location <- location %>%
  filter(F2_plot %in% c('Klondike (plot 1)', 
                        'Klondike (plot 2)', 
                        'Klondike (plot 3)')
  )
rownames(location) <- location[,1]
location[,1:6] <- NULL

# filter for klondike only in the ra_matrix
ra_matrix <- ra_matrix %>%
  filter(F2_plot %in% c('Klondike (plot 1)', 
                        'Klondike (plot 2)', 
                        'Klondike (plot 3)')
  )
rownames(ra_matrix) <- ra_matrix[,1]

#check in dataframe how many columns and then remove categorical plot variables
x2 = ncol(ra_matrix) - 7 

# create environment dataframe
envir <- ra_matrix[,c(1, (x2 + 1):ncol(ra_matrix))]

# keep original relative abundance matrix
ra_matrix_original <- ra_matrix

# keep relative abundance matrix but without the environment data
ra_matrix <- ra_matrix[,1:x2]

# make row names sample names
rownames(ra_matrix) <- ra_matrix[,1]
ra_matrix[,1] <- NULL

# remove columns if they are all 0 abundance (These would have only been alleles in specific trial)
ra_matrix <- ra_matrix[, colSums(ra_matrix != 0) > 0]

# spatial distance matrix
# calculate spatial distance
spat.dist <- vegdist(location, "euclid", upper=FALSE)

# calculate bray curtis distance (default for vegdist)
ra.bray.dist <- vegdist(ra_matrix, "bray", upper=FALSE) 

# calculate mantel test statistic between geographic distance and allelic dissimilarity
mantel(spat.dist, ra.bray.dist, method="pearson") 

# Mantel statistic based on Pearson's product-moment correlation 
# Call:
# mantel(xdis = spat.dist, ydis = ra.bray.dist, method = "pearson") 
# Mantel statistic r: 0.3137 
#       Significance: 0.05 
# Upper quantiles of permutations (null model):
#   90%   95% 97.5%   99% 
# 0.191 0.311 0.432 0.517 
# Permutation: free
# Number of permutations: 999


#plot correlation
plot(spat.dist, ra.bray.dist, pch=16, cex=0.5, col="black", bty="l",
     xlab="Euclidean distance between sample points",ylab="Bray-Curtis allelic similarity between samples",
     cex.axis = 1.5, cex.lab = 1.5)

#Mantel correlogram 
mpmcorrelogram(spat.dist, ra.bray.dist, zdis = NULL, method = "pearson",
               alfa = 0.05, nclass = NULL, breaks = NULL,
               permutations = 1000, simil = FALSE,
               plot = TRUE, print = TRUE)

# melt distance matrices and add together
ra.bray.dist <- melt(as.matrix(ra.bray.dist), varnames = c("row", "col"), value.name = 'bray_dist')
spat.dist <- melt(as.matrix(spat.dist), varnames = c("row", "col"), value.name = 'spat_dist')
dists_mantel <- merge(ra.bray.dist, spat.dist, by = c("row", "col"), all.x = T)

# remove rows that are comparing each point with itself (will give value of 0 in bray_dist column)
dists_mantel <- as.data.frame(dists_mantel[!dists_mantel$row == dists_mantel$col,])

# remake graph
(geoplot <- ggplot(dists_mantel, aes(spat_dist, bray_dist)) +
    geom_point(size = 3) +
    geom_smooth(method = lm, se = F, colour = 'grey60', size = 4) +
    xlab("Euclidean geographic distance between samples") +
    ylab("Bray-Curtis allelic dissimilarity between samples") + 
    theme_bw() +
    theme(legend.title = element_text(size = 25), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Fig5/braycurtis_geodist_manteltest_klondikeonly_allgenes.pdf', plot = geoplot, width = 27, height = 27, unit = 'cm')



# Spatial analysis Block 1: all genes / individual genes----------------


# clear all data from the global environment before starting this section afresh. 

# euclidean distance between x and y sample plot coordinates and
# bray-curtis similarity between allelic relative abundances. 

# read in relative abundance matrix made previously (NOT log transformed)
# can do this for all genes combined and also for each gene individually.
# ra_matrix <- read.csv('../data/data_output/abundance_data/clovergeno_allgenes_pca_matrix_withingene_ra.csv')
# ra_matrix <- read.csv('../data/data_output/abundance_data/clovergeno_noda_pca_matrix_ra.csv')
# ra_matrix <- read.csv('../data/data_output/abundance_data/clovergeno_nodd_pca_matrix_ra.csv')
# ra_matrix <- read.csv('../data/data_output/abundance_data/clovergeno_reca_pca_matrix_ra.csv')
ra_matrix <- read.csv('../data/data_output/abundance_data/clovergeno_rpob_pca_matrix_ra.csv')
names(ra_matrix)[1] <- 'sample'

# read in environment data and combine with the x and y coordinates for each sample
# location is the x and y coordinates for each plot
location <- read.csv('../data/raw_data/abundance_data/plot_environment_data_xycoordinates.csv')

# merge together for filtering the matrix later
ra_matrix <- merge(ra_matrix, location[,c("sample", "x", "y")], by = 'sample', all.x = T)

# filter for block 1 plots only in environment data and then just keep the coordinate info
location <- location %>%
  filter(Block %in% c('1'))
rownames(location) <- location[,1]
location[,1:6] <- NULL

# filter for block 1 plots only in the ra_matrix
ra_matrix <- ra_matrix %>%
  filter(Block %in% c('1'))
rownames(ra_matrix) <- ra_matrix[,1]

#check in dataframe how many columns and then remove categorical plot variables
x2 = ncol(ra_matrix) - 7 

# create an environment dataframe
envir <- ra_matrix[,c(1, (x2 + 1):ncol(ra_matrix))]

# keep the original relative abundance matrix
ra_matrix_original <- ra_matrix

# remove environment data from the relative abundance matrix
ra_matrix <- ra_matrix[,1:x2]

# make row names sample names
rownames(ra_matrix) <- ra_matrix[,1]
ra_matrix[,1] <- NULL

# remove columns if they are all 0 abundance (These would have only been alleles in specific trial)
ra_matrix <- ra_matrix[, colSums(ra_matrix != 0) > 0]

# spatial distance matrix
# calculate spatial distance
spat.dist <- vegdist(location, "euclid", upper=FALSE)

# calculate bray curtis distance (default for vegdist)
ra.bray.dist <- vegdist(ra_matrix, "bray", upper=FALSE) 

# calculate mantel test statistic between geographic distance and allelic dissimilarity
mantel(spat.dist, ra.bray.dist, method="pearson") 

# Block 1 mantel results (999 permutations)
# all genes: Mantel statistic r: -0.03147 Significance: 0.645 
# noda: Mantel statistic r: -0.002407 Significance: 0.482 
# nodd: Mantel statistic r: -0.009155 Significance: 0.558
# reca: Mantel statistic r: -0.04829 Significance: 0.712
# rpob: Mantel statistic r: -0.03802 Significance: 0.708 


#plot correlation
plot(spat.dist, ra.bray.dist, pch=16, cex=0.5, col="black", bty="l",
     xlab="Euclidean distance between sample points",ylab="Bray-Curtis allelic similarity between samples",
     cex.axis = 1.5, cex.lab = 1.5)

# Mantel correlogram 
mpmcorrelogram(spat.dist, ra.bray.dist, zdis = NULL, method = "pearson",
               alfa = 0.05, nclass = NULL, breaks = NULL,
               permutations = 1000, simil = FALSE,
               plot = TRUE, print = TRUE)

# melt distance matrices and add together
ra.bray.dist <- melt(as.matrix(ra.bray.dist), varnames = c("row", "col"), value.name = 'bray_dist')
spat.dist <- melt(as.matrix(spat.dist), varnames = c("row", "col"), value.name = 'spat_dist')
dists_mantel <- merge(ra.bray.dist, spat.dist, by = c("row", "col"), all.x = T)

# remove rows that are comparing each point with itself (will give value of 0)
dists_mantel <- as.data.frame(dists_mantel[!dists_mantel$row == dists_mantel$col,])

# remake graph
(geoplot <- ggplot(dists_mantel, aes(spat_dist, bray_dist)) +
    geom_point(size = 3) +
    xlab("Euclidean geographic distance between samples") +
    ylab("Bray-Curtis allelic dissimilarity between samples") + 
    geom_smooth(method = lm, se = F, colour = 'grey60', size = 4) +
    ylim(0, 1) +
    theme_bw() +
    theme(legend.title = element_text(size = 25), 
          axis.text.x = element_text(size = 25),
          axis.text.y = element_text(size = 25),
          axis.title=element_text(size = 30),
          legend.text = element_text(size = 25))
)
#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
# all genes save
# ggsave('../data/data_output/figures/Supplementary/braycurtis_geodist_manteltest_block1_allgenes.pdf', plot = geoplot, width = 27, height = 27, unit = 'cm')
# noda save
# ggsave('../data/data_output/figures/Supplementary/braycurtis_geodist_manteltest_klondikeonly_noda.pdf', plot = geoplot, width = 27, height = 27, unit = 'cm')
# nodd save
# ggsave('../data/data_output/figures/Supplementary/braycurtis_geodist_manteltest_klondikeonly_nodd.pdf', plot = geoplot, width = 27, height = 27, unit = 'cm')
# reca save
# ggsave('../data/data_output/figures/Supplementary/braycurtis_geodist_manteltest_klondikeonly_reca.pdf', plot = geoplot, width = 27, height = 27, unit = 'cm')
# rpob save
# ggsave('../data/data_output/figures/Supplementary/braycurtis_geodist_manteltest_klondikeonly_rpob.pdf', plot = geoplot, width = 27, height = 27, unit = 'cm')



# Bray-curtis heatmaps with Klondike plots -------------


# clear all data from the global environment before starting this section afresh. 

#can upload pca matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/abundance_data/clovergeno_allgenes_pca_matrix_withingene_ra.csv")
names(ra.data)[1] <- 'sample'

# keep Klondike plot data.
ra.data <- ra.data %>%
  filter(F2 %in% 'Klondike')

# add environmental data to separate metadata file
env_data <- ra.data[ ,c("sample", "plot", "F2_plot", "F2", "plot_rep", "Block")]

# remove five end columns to remove metadata
x2 = ncol(ra.data) -5
ra.data2 <- ra.data[,1:x2]

# remove columns if they are all 0 abundance (These would have only been alleles in trial 2)
ra.data2 <- ra.data2[, colSums(ra.data2 != 0) > 0]
# there shouldn't be any to remove

# make sample names row names
row.names(ra.data2) <- ra.data2$sample
ra.data2$sample <- NULL

# make my_palette
my_palette <- colorRampPalette(rev(brewer.pal(9,"Reds")))(256)

# create categories to colour for heatmap from envir dataframe
envir2 <- env_data[,c(2,4)]

# then produce dist matrices.
bray_klondike <-  vegdist(ra.data2, method = "bray")

# make klondikeplotpalette grey colours
klondikeplotcol <- gray.colors(3, start = 0.0, end = 0.8, gamma = 2.2)

# make environment row names the same as the ra.data
row.names(envir2) <- ra.data$sample

# add klondike plot into the envir2 variables
envir2$Plot <- c('a (Block 1)','a (Block 1)','a (Block 1)', 
                 'b (Block 1)', 'b (Block 1)', 'b (Block 1)',
                 'c (Block 2)', 'c (Block 2)', 'c (Block 2)')

# rename genotype column with Variety for the plot to look nice
names(envir2)[2] <- 'Variety'

# make plot levels for the klondike palette
envir2$Plot <- factor(envir2$Plot)
names(klondikeplotcol) <- levels(envir2$Plot)

# klondike colour palette (pink)
f2col <- c('#CC79A7')
envir2$Variety <- factor(envir2$Variety)
names(f2col) <- levels(envir2$Variety)

# change colour association list for plot
AnnColour <- list(
  Plot = klondikeplotcol,
  Variety = f2col)
#check colour associations
AnnColour

# with plots this time
pheatmap(bray_klondike,
         cluster_rows = F, cluster_cols = F,
         col = my_palette,
         annotation_row = envir2[2:3],
         annotation_col = envir2[2:3],
         annotation_colors = AnnColour,
         breaks = seq(0, 1, by = 0.00390625), # 1 / 256
         cellwidth = 10, cellheight = 10,
         width = 5, height = 5,
         filename = "../data/data_output/figures/Fig5/braycurtis_allgenes_klondikeonly_heatmap.pdf"
)



# Bray-curtis Heatmaps of Trial 1 plot only bray-curtis / PERMANOVA ---------------


# clear all data from the global environment before starting this section afresh. 

#can upload pca matrix ready version for the beta diversity analysis. 
ra.data <- read.csv("../data/data_output/abundance_data/clovergeno_allgenes_pca_matrix_withingene_ra.csv")
# ra.data <- read.csv('../data/data_output/abundance_data/clovergeno_noda_pca_matrix_ra.csv')
# ra.data <- read.csv('../data/data_output/abundance_data/clovergeno_nodd_pca_matrix_ra.csv')
# ra.data <- read.csv('../data/data_output/abundance_data/clovergeno_reca_pca_matrix_ra.csv')
# ra.data <- read.csv('../data/data_output/abundance_data/clovergeno_rpob_pca_matrix_ra.csv')
names(ra.data)[1] <- 'sample'

# remove Block 2 plots
ra.data <- ra.data %>%
  filter(Block %in% '1')

# add environmental data to separate metadata file
env_data <- ra.data[ ,c("sample", "plot", "F2_plot", "F2", "plot_rep", "Block")]

# remove five end columns to remove metadata
x2 = ncol(ra.data) -5
ra.data2 <- ra.data[,1:x2]

# remove columns if they are all 0 abundance (These would have only been alleles in trial 2)
ra.data2 <- ra.data2[, colSums(ra.data2 != 0) > 0]
# there shouldn't be any to remove

# make sample names row names
row.names(ra.data2) <- ra.data2$sample
ra.data2$sample <- NULL

#create categories to colour for heatmap from envir dataframe
envir2 <- env_data[,c(1,2,4)]
row.names(envir2) <- envir2$sample
envir2$sample <- NULL

# reorder rows by F2 and plot in envir2. then use this to reorder rows in ra_matrix for distance calculation.
envir2
envir2 <- envir2[order(envir2$plot), ]
envir2 <- envir2[order(envir2$F2), ]
# add another row for plot
envir2$plotrep <- rep(c(1,1,1,2,2,2), 5)

# make row names in ra.data2 match those in envir2. 
ra.data2 <- ra.data2[c(row.names(envir2)), ]

# to do the vegan permanova will need to make sure I have the distance matrices. 
# make the bray curtis and sorensens dist matrices.
bray_matrix <- vegdist(ra.data2, method = "bray")

# betadisperser: tests homogeneity of dispersion among groups which is an assumption of permanova
# https://rfunctions.blogspot.com/2019/03/betadisper-and-adonis-homogeneity-of.html
mod_f2 <- betadisper(bray_matrix, envir2$F2)
mod_plot <- betadisper(bray_matrix, envir2$plot)

anova(mod_f2)

# all genes result
# Analysis of Variance Table
# Response: Distances
#            Df  Sum Sq   Mean Sq F value  Pr(>F)  
# Groups     4 0.10313 0.0257820  3.2518 0.02808 *
# Residuals 25 0.19821 0.0079285                  

# nodA result
# Analysis of Variance Table
# Response: Distances
#           Df  Sum Sq   Mean Sq F value Pr(>F)
# Groups     4 0.01354 0.0033861  0.1293 0.9703
# Residuals 25 0.65463 0.0261851

# nodd result
# Analysis of Variance Table
# Response: Distances
#           Df  Sum Sq  Mean Sq F value Pr(>F)
# Groups     4 0.08863 0.022157  1.4474 0.2479
# Residuals 25 0.38270 0.01530

# reca result
# Analysis of Variance Table
# Response: Distances
#           Df  Sum Sq  Mean Sq F value    Pr(>F)    
# Groups     4 0.34446 0.086116   25.62 1.583e-08 ***
# Residuals 25 0.08403 0.003361

# rpob result
# Analysis of Variance Table
# Response: Distances
#           Df  Sum Sq  Mean Sq F value  Pr(>F)  
# Groups     4 0.12834 0.032085  2.5895 0.06119
# Residuals 25 0.30976 0.012390

anova(mod_plot)

# all genes result
# Analysis of Variance Table
# Response: Distances
#           Df  Sum Sq  Mean Sq F value Pr(>F)
# Groups     9 0.16063 0.017848  1.0414 0.4432
# Residuals 20 0.34276 0.017138

# noda results
# Analysis of Variance Table
# Response: Distances
#           Df Sum Sq  Mean Sq F value Pr(>F)
# Groups     9 0.1333 0.014811  0.2751 0.9743
# Residuals 20 1.0768 0.053839

# nodd result
# Analysis of Variance Table
# Response: Distances
#           Df  Sum Sq  Mean Sq F value Pr(>F)
# Groups     9 0.25463 0.028292  1.2359 0.3287
# Residuals 20 0.45784 0.022892

# reca result
# Analysis of Variance Table
# Response: Distances
#           Df  Sum Sq  Mean Sq F value Pr(>F)
# Groups     9 0.21449 0.023832  1.2493 0.3219
# Residuals 20 0.38154 0.019077

# rpob result
# Analysis of Variance Table
# Response: Distances
#           Df  Sum Sq  Mean Sq F value Pr(>F)
# Groups     9 0.13663 0.015181  0.5511 0.8201
# Residuals 20 0.55099 0.027550

TukeyHSD(mod_f2)

# all genes result
# Tukey multiple comparisons of means
# 95% family-wise confidence level
# Fit: aov(formula = distances ~ group, data = df)
# $group
#                           diff         lwr       upr     p adj
# Cross 2-Cross 1  -2.670466e-02 -0.17768462 0.1242753 0.9845666
# Cross 3-Cross 1   4.913502e-03 -0.14606646 0.1558935 0.9999797
# Cross 4-Cross 1   5.469542e-05 -0.15092527 0.1510347 1.0000000
# Klondike-Cross 1  1.384793e-01 -0.01250070 0.2894592 0.0834729
# Cross 3-Cross 2   3.161816e-02 -0.11936180 0.1825981 0.9713320
# Cross 4-Cross 2   2.675935e-02 -0.12422061 0.1777393 0.9844488
# Klondike-Cross 2  1.651839e-01  0.01420396 0.3161639 0.0270406 *
# Cross 4-Cross 3  -4.858807e-03 -0.15583877 0.1461212 0.9999806
# Klondike-Cross 3  1.335658e-01 -0.01741420 0.2845457 0.1012304
# Klondike-Cross 4  1.384246e-01 -0.01255539 0.2894045 0.0836546

# reca result
# Tukey multiple comparisons of means
# 95% family-wise confidence level
# Fit: aov(formula = distances ~ group, data = df)
# $group
#                          diff         lwr        upr     p adj
# Cross 2-Cross 1  -0.057782663 -0.15608837 0.04052304 0.4368898
# Cross 3-Cross 1  -0.042134194 -0.14043990 0.05617151 0.7178291
# Cross 4-Cross 1  -0.006669473 -0.10497518 0.09163623 0.9996225
# Klondike-Cross 1  0.235774707  0.13746900 0.33408041 0.0000021 *
# Cross 3-Cross 2   0.015648470 -0.08265724 0.11395418 0.9895996
# Cross 4-Cross 2   0.051113190 -0.04719252 0.14941890 0.5554069
# Klondike-Cross 2  0.293557370  0.19525166 0.39186308 0.0000000 *
# Cross 4-Cross 3   0.035464721 -0.06284099 0.13377043 0.8250411
# Klondike-Cross 3  0.277908900  0.17960319 0.37621461 0.0000001 *
# Klondike-Cross 4  0.242444179  0.14413847 0.34074989 0.0000013 *


## Within-group dispersion that PERMDISP is testing
boxplot(mod_f2)
boxplot(mod_plot)

# set seed for permanova
set.seed(6)

# permanova test
adonis(bray_matrix ~ F2 + plot, data = envir2)

# all genes result
# Call:
# adonis(formula = bray_matrix ~ F2 + plot, data = envir2) 
# Permutation: free
# Number of permutations: 999
# Terms added sequentially (first to last)
# 
#           Df SumsOfSqs  MeanSqs F.Model      R2 Pr(>F)    
# F2         4   0.93701 0.234254  3.7036 0.37429  0.001 ***
# plot       5   0.30141 0.060283  0.9531 0.12040  0.469    
# Residuals 20   1.26501 0.063250         0.50531           
# Total     29   2.50343                  1.00000             

# noda result
# Call:
# adonis(formula = bray_matrix ~ F2 + plot, data = envir2) 
# Permutation: free
# Number of permutations: 999
# Terms added sequentially (first to last)
# 
#           Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)  
# F2         4    1.1594 0.28986  2.6780 0.29114  0.022 *
# plot       5    0.6582 0.13164  1.2162 0.16527  0.255  
# Residuals 20    2.1648 0.10824         0.54359         
# Total     29    3.9824                 1.00000

# nodd result
# Call:
# adonis(formula = bray_matrix ~ F2 + plot, data = envir2) 
# Permutation: free
# Number of permutations: 999
# Terms added sequentially (first to last)
#           Df SumsOfSqs  MeanSqs F.Model      R2 Pr(>F)  
# F2         4   0.79647 0.199118 2.12257 0.25796  0.037 *
# plot       5   0.41490 0.082979 0.88455 0.13438  0.568  
# Residuals 20   1.87620 0.093810         0.60766         
# Total     29   3.08756                  1.00000

# reca result
# Call:
# adonis(formula = bray_matrix ~ F2 + plot, data = envir2) 
# Permutation: free
# Number of permutations: 999
# Terms added sequentially (first to last)
#           Df SumsOfSqs  MeanSqs F.Model      R2 Pr(>F)   
# F2         4   0.70817 0.177043  5.2474 0.47824  0.006 **
# plot       5   0.09784 0.019568  0.5800 0.06607  0.739   
# Residuals 20   0.67478 0.033739         0.45569          
# Total     29   1.48079                  1.00000


# rpob result
# Call:
# adonis(formula = bray_matrix ~ F2 + plot, data = envir2) 
# Permutation: free
# Number of permutations: 999
# Terms added sequentially (first to last)
#           Df SumsOfSqs MeanSqs F.Model      R2 Pr(>F)    
# F2         4   1.30291 0.32573   5.375 0.46206  0.001 ***
# plot       5   0.30483 0.06097   1.006 0.10811  0.429    
# Residuals 20   1.21201 0.06060         0.42983           
# Total     29   2.81975                 1.00000

# set seed for posthoc
set.seed(6)

#POST-HOC TEST for Adonis
#see which plots are significant for adonis?
pairwise.adonis(ra.data2, envir2$F2)

# all genes result
#                  pairs Df  SumsOfSqs   F.Model         R2 p.value p.adjusted sig
# 1   Cross 1 vs Cross 2  1 0.18808366 4.5863548 0.31442775   0.008       0.08    
# 2   Cross 1 vs Cross 3  1 0.10956841 2.2422964 0.18315978   0.092       0.92    
# 3   Cross 1 vs Cross 4  1 0.18008096 3.8663636 0.27883039   0.003       0.03   .
# 4  Cross 1 vs Klondike  1 0.37058055 3.9833648 0.28486454   0.019       0.19    
# 5   Cross 2 vs Cross 3  1 0.04444798 1.0758658 0.09713605   0.358       1.00    
# 6   Cross 2 vs Cross 4  1 0.11176818 2.8639695 0.22263498   0.024       0.24    
# 7  Cross 2 vs Klondike  1 0.58903988 6.8908590 0.40796380   0.005       0.05   .
# 8   Cross 3 vs Cross 4  1 0.03627865 0.7738522 0.07182688   0.526       1.00    
# 9  Cross 3 vs Klondike  1 0.38356485 4.1094919 0.29125726   0.035       0.35    
# 10 Cross 4 vs Klondike  1 0.32912275 3.6148167 0.26550609   0.050       0.50      

# noda result
#                  pairs Df  SumsOfSqs   F.Model         R2 p.value p.adjusted sig
# 1   Cross 1 vs Cross 2  1 0.27967083 2.7526372 0.21584847   0.068       0.68    
# 2   Cross 1 vs Cross 3  1 0.25658258 2.3265208 0.18874108   0.133       1.00    
# 3   Cross 1 vs Cross 4  1 0.51743753 4.8671755 0.32737728   0.011       0.11    
# 4  Cross 1 vs Klondike  1 0.58810482 4.4013444 0.30562038   0.022       0.22    
# 5   Cross 2 vs Cross 3  1 0.04536802 0.4588615 0.04387298   0.625       1.00    
# 6   Cross 2 vs Cross 4  1 0.10042606 1.0582688 0.09569932   0.367       1.00    
# 7  Cross 2 vs Klondike  1 0.44923896 3.6761322 0.26879911   0.045       0.45    
# 8   Cross 3 vs Cross 4  1 0.06761846 0.6528047 0.06128008   0.636       1.00    
# 9  Cross 3 vs Klondike  1 0.29229611 2.2331576 0.18254956   0.129       1.00    
# 10 Cross 4 vs Klondike  1 0.30181752 2.3781101 0.19212223   0.077       0.77   

# nodd result
#                  pairs Df  SumsOfSqs   F.Model         R2 p.value p.adjusted sig
# 1   Cross 1 vs Cross 2  1 0.16132059 2.4852632 0.19905573   0.101       1.00    
# 2   Cross 1 vs Cross 3  1 0.18362280 2.2079412 0.18086106   0.100       1.00    
# 3   Cross 1 vs Cross 4  1 0.28652903 4.3583573 0.30354150   0.022       0.22    
# 4  Cross 1 vs Klondike  1 0.33480459 3.0586522 0.23422419   0.048       0.48    
# 5   Cross 2 vs Cross 3  1 0.06167327 0.7230552 0.06742996   0.561       1.00    
# 6   Cross 2 vs Cross 4  1 0.13741916 2.0246482 0.16837484   0.095       0.95    
# 7  Cross 2 vs Klondike  1 0.33826203 3.0312351 0.23261303   0.052       0.52    
# 8   Cross 3 vs Cross 4  1 0.02832288 0.3288504 0.03183804   0.824       1.00    
# 9  Cross 3 vs Klondike  1 0.22025707 1.6962947 0.14502838   0.164       1.00    
# 10 Cross 4 vs Klondike  1 0.23896652 2.1255881 0.17529773   0.103       1.00    

# reca result
#             pairs Df   SumsOfSqs   F.Model         R2 p.value p.adjusted sig
# 1   Cross 1 vs Cross 2  1 0.082775455 10.752037 0.51811959   0.004       0.04   .
# 2   Cross 1 vs Cross 3  1 0.038777719  4.549915 0.31271076   0.022       0.22    
# 3   Cross 1 vs Cross 4  1 0.024052231  2.225966 0.18206871   0.133       1.00    
# 4  Cross 1 vs Klondike  1 0.249866274  3.500179 0.25926908   0.095       0.95    
# 5   Cross 2 vs Cross 3  1 0.009166663  4.322699 0.30180759   0.033       0.33    
# 6   Cross 2 vs Cross 4  1 0.020443098  4.642830 0.31707192   0.016       0.16    
# 7  Cross 2 vs Klondike  1 0.546457656  8.409038 0.45678855   0.010       0.10    
# 8   Cross 3 vs Cross 4  1 0.003113561  0.595634 0.05621504   0.473       1.00    
# 9  Cross 3 vs Klondike  1 0.421541819  6.405562 0.39045063   0.038       0.38    
# 10 Cross 4 vs Klondike  1 0.374232056  5.496035 0.35467362   0.054       0.54

# rpob result
#                  pairs Df  SumsOfSqs   F.Model        R2 p.value p.adjusted sig
# 1   Cross 1 vs Cross 2  1 0.29319962  7.971038 0.4435491   0.004       0.04   .
# 2   Cross 1 vs Cross 3  1 0.09212730  2.024576 0.1683698   0.097       0.97    
# 3   Cross 1 vs Cross 4  1 0.13568590  3.060125 0.2343106   0.026       0.26    
# 4  Cross 1 vs Klondike  1 0.33232320  3.476788 0.2579834   0.037       0.37    
# 5   Cross 2 vs Cross 3  1 0.07368254  2.089118 0.1728098   0.131       1.00    
# 6   Cross 2 vs Cross 4  1 0.25099037  7.359303 0.4239400   0.002       0.02   .
# 7  Cross 2 vs Klondike  1 1.02522130 12.012163 0.5457057   0.005       0.05   .
# 8   Cross 3 vs Cross 4  1 0.08174012  1.908632 0.1602730   0.142       1.00    
# 9  Cross 3 vs Klondike  1 0.57197230  6.080286 0.3781205   0.018       0.18    
# 10 Cross 4 vs Klondike  1 0.40032363  4.308935 0.3011360   0.036       0.36    


# heatmap colour palette
my_palette <- colorRampPalette(rev(brewer.pal(9,"Reds")))(256)

# make clover genotype/cross colour palette
f2col <- c('#E69F00', '#56B4E9', '#009E73',  '#D55E00', '#CC79A7')
envir2$F2 <- factor(envir2$F2, levels = c("Cross 1", "Cross 2", "Cross 3", "Cross 4", "Klondike"))
names(f2col) <- levels(envir2$F2)
f2col

# rename F2 to genotype
names(envir2)[2] <- 'genotype'

#add plot levels and associate colours
plotcol <- c("grey20", "grey80")
envir2$plotrep <- factor(envir2$plotrep, labels = c("1", "2"))
names(plotcol) <- levels(envir2$plotrep)

# Add to a list, where names match those in factors dataframe
AnnColour <- list(
  plotrep = plotcol,
  genotype = f2col)
#check colour associations
AnnColour

# make heatmap
pheatmap(bray_matrix,
         cluster_rows = F, cluster_cols = F,
         gaps_row = c(6,12,18,24),
         gaps_col = c(6,12,18,24),
         col = my_palette,
         annotation_row = envir2[, c('plotrep', 'genotype'), drop=FALSE],
         annotation_col = envir2[, c('plotrep', 'genotype'), drop=FALSE],
         annotation_colors = AnnColour,
         #labels_row = envir$sample0,
         #labels_col = envir$sample0,
         breaks = seq(0, 1, by = 0.00390625), # 1 / 256
         cellwidth = 10, cellheight = 10,
         # filename = "../data/data_output/figures/Fig4/braycurtis_allgenes_block1_heatmap.pdf"
         # filename = "../data/data_output/figures/Supplementary/braycurtis_noda_block1_heatmap_v2.pdf"
         # filename = "../data/data_output/figures/Supplementary/braycurtis_nodd_block1_heatmap.pdf"
         # filename = "../data/data_output/figures/Supplementary/braycurtis_reca_block1_heatmap.pdf"
         # filename = "../data/data_output/figures/Supplementary/braycurtis_rpob_block1_heatmap.pdf"
)


