# Author: Bryden Fields
# Email: bryden.fields@york.ac.uk

# Initial setup -----------------

library(plyr)
library(tidyverse)
library(reshape2)
library(FSA)
library(ggpubr)
library(rstatix)
library(broom)

#set the working directory to the directory this script is in.
#setwd("~/whatever/folder/you/are/working/from")
setwd("/Users/brydenfields/Documents/Publications/2023_Clovergenotype_paper/scripts")



# Strain growth and biofilm data --------------------


# read in 100% TY growth and biofilm data. The TY data is 96h 100% TY 28°C and (as far as I know blanked against background media). 
growth_data <- read.csv("../data/raw_data/strain_phenotype_data/strain_100TY28Cgrowth_phenotype_data.csv")

biofilm_data <- read.csv("../data/raw_data/strain_phenotype_data/strain_biofilm_phenotype_data copy.csv")

# change level order of inoculant_strain column
growth_data$Inoculant_strain <- factor(growth_data$Inoculant_strain, levels = c("Inoculant strain", "Cavassim et al. strain"))

biofilm_data$Inoculant_strain <- factor(biofilm_data$Inoculant_strain, levels = c("Inoculant strain", "Cavassim et al. strain"))


# Create summary stats

# make a blank data frame with the columns to keep with a row for each unique combination
Rmax_data<-unique(growth_data[,c("Strain", "Genospecies", "Inoculant_strain", "Country_origin")])

# calculate summary metrics - taken from Rosanna Wright's code and some explanation of code by Ellie Harrison.

# this uses a loop. Each interation of the loop will make a subset of the data for 1 curve, then calculates the different metrics from it.

for(i in 1:NROW(Rmax_data)){
  #subset of data and make a mini dataframe called asub. 
  asub <- growth_data[growth_data$Strain == Rmax_data[i,'Strain'], ] 
  #growth rates = change in absorbance per hour. this is a litle tricky as you cant just do it across the curve (because the growth slows down). So you need to calculate rate for a bunch of time windows through the growth cycle and then you can pick the highest (i.e. maximum growth rate)
  # data frame containing growth rates through time for each curve
  # just makes a data frame of time - by hours
  alltimes<-c(16,24,40,48,64,72,88,96)
  # ensures it is in order
  alltimes<-alltimes[order(alltimes)]
  #make a new little dataframe to collect the rate info
  rates <- data.frame(Rate=as.numeric(), Time=as.numeric(), Abs=as.numeric()) 
  # note that j starts at 2 (24h) and ends 1 time points before the end (88h)
  for(j in c(2:7)){
      a0<-asub[asub$Time == alltimes[j-1], 'OD600'] # takes the OD at time point j-previous time point
      a1<-asub[asub$Time == alltimes[j], 'OD600'] # takes the OD at time point j
      a2<-asub[asub$Time == alltimes[j+1], 'OD600'] # takes the OD at time point j+next time point 
      rates[NROW(rates)+1, 'Rate']<-(a2-a0)/24 # calculate the rate around point J (the demonimator is 24 because its across 24 hours)
      rates[NROW(rates),'Abs']<-a1 #  add the OD for row j
      rates[NROW(rates), 'Time']<-alltimes[j] # add the time for row j
  }
  
  #maximum growth rate just taken as the highest value in the list of rates
  max <-rates[rates$Rate == max(rates$Rate),] #make a tiny dataframe containing the maximum values
  Rmax_data[i,'MaxGrowthRate']<-max$Rate[1] #if more than 1 row, we want the first time this occurs
  Rmax_data[i,'TimeMaxGrowthRate']<-max$Time[1]
  Rmax_data[i,'AbsMaxGrowthRate']<-max$Abs[1]
}



# stats --------------------------------


# maximum growth rate. Anova to compare across genospecies.

# first we can test homogeneity of variance with bartlett.test.
bartlett.test(Rmax_data$MaxGrowthRate, Rmax_data$Genospecies)

# Bartlett test of homogeneity of variances
# data:  Rmax_data$MaxGrowthRate and Rmax_data$Genospecies
# Bartlett's K-squared = 18.956, df = 4, p-value = 0.0008019

# we can also test normality of the MaxGrowthRate result distribution within each of the genospecies groups.
tapply(Rmax_data$MaxGrowthRate, Rmax_data$Genospecies, shapiro.test)

# $A
# Shapiro-Wilk normality test
# data:  X[[i]]
# W = 0.86357, p-value = 0.0008279 # significant
# 
# 
# $B
# Shapiro-Wilk normality test
# data:  X[[i]]
# W = 0.91923, p-value = 0.01981 # significant
# 
# $C
# Shapiro-Wilk normality test
# data:  X[[i]]
# W = 0.9844, p-value = 0.2342
# 
# $D
# Shapiro-Wilk normality test
# data:  X[[i]]
# W = 0.95532, p-value = 0.7751
# 
# $E
# Shapiro-Wilk normality test
# data:  X[[i]]
# W = 0.90241, p-value = 0.1978

# because we have heteroscedastity and because data is not normally distributed within all of our genospecies groups we must use a different anova test. 
kruskal.test(MaxGrowthRate ~ Genospecies,
             data = Rmax_data)

# Kruskal-Wallis rank sum test
# data:  MaxGrowthRate by Genospecies
# Kruskal-Wallis chi-squared = 88.831, df = 4, p-value < 2.2e-16

# then carry out Dunns test for multiple comparisons with pvalue correction as post hoc.
dunnTest(MaxGrowthRate ~ Genospecies,
         data = Rmax_data,
         method = "bonferroni")

# Dunn (1964) Kruskal-Wallis multiple comparison
# p-values adjusted with the Bonferroni method.
# 
#    Comparison          Z      P.unadj        P.adj
# 1       A - B -1.3504583 1.768690e-01 1.000000e+00
# 2       A - C  6.4068928 1.485152e-10 1.485152e-09 # significant
# 3       B - C  8.0860829 6.161424e-16 6.161424e-15 # significant
# 4       A - D  0.6292494 5.291858e-01 1.000000e+00
# 5       B - D  1.3313193 1.830840e-01 1.000000e+00
# 6       C - D -2.1549101 3.116887e-02 3.116887e-01
# 7       A - E  2.6982490 6.970529e-03 6.970529e-02
# 8       B - E  3.6642071 2.481060e-04 2.481060e-03 # significant
# 9       C - E -1.0907991 2.753613e-01 1.000000e+00
# 10      D - E  1.1874739 2.350407e-01 1.000000e+00



# biofilm formation: one way anova for genospecies (or ancova with covariate of bacterial density (OD600nm) at 96h to adjust for the differences in OD of bacterial cells). 

# Linearity between the covariate and the outcome variable at each level of the grouping variable. This can be checked by creating a grouped scatter plot of the covariate and the outcome variable.
ggscatter(biofilm_data, x = "OD_96h", y = "Biofilm_100TY_28C_96h",
          color = "Genospecies", add = "reg.line")+
          stat_regline_equation(aes(label =  paste(..eq.label.., ..rr.label.., sep = "~~~~"), 
                                    color = Genospecies)
  )

# also check other time points
growth_data2 <- dcast(growth_data, Strain + Genospecies ~ Time)
names(growth_data2)[3:10] <- c("16h", "24h", "40h", "48h", "64h", "72h", "88h", "96h")
growth_data2 <- left_join(growth_data2, biofilm_data[c("Strain", "Biofilm_100TY_28C_96h")], by = c("Strain"))

ggscatter(growth_data2, x = "16h", y = "Biofilm_100TY_28C_96h",
          color = "Genospecies", add = "reg.line")+
  stat_regline_equation(aes(label =  paste(..eq.label.., ..rr.label.., sep = "~~~~"), 
                            color = Genospecies)
  )

# as there is no correlation between OD_96h and Biofilm OD at 96h it should be fine to just do normal anova

# first we can test homogeneity of variance with bartlett.test (I prefer levene's test though).
bartlett.test(biofilm_data$Biofilm_100TY_28C_96h, biofilm_data$Genospecies)

# Bartlett test of homogeneity of variances
# data:  biofilm_data$Biofilm_100TY_28C_96h and biofilm_data$Genospecies
# Bartlett's K-squared = 16.729, df = 4, p-value = 0.002181

# we can also test normality of the myoglobin result distribution within each of the species groups in the 'species' variable. 
tapply(biofilm_data$Biofilm_100TY_28C_96h, biofilm_data$Genospecies, shapiro.test)

# $A
# Shapiro-Wilk normality test
# data:  X[[i]]
# W = 0.57913, p-value = 2.074e-08
# 
# $B
# Shapiro-Wilk normality test
# data:  X[[i]]
# W = 0.9777, p-value = 0.7304
# 
# $C
# Shapiro-Wilk normality test
# data:  X[[i]]
# W = 0.86473, p-value = 1.52e-08
# 
# $D
# Shapiro-Wilk normality test
# data:  X[[i]]
# W = 0.96031, p-value = 0.8102
# 
# $E
# Shapiro-Wilk normality test
# data:  X[[i]]
# W = 0.85612, p-value = 0.05128

# because we have heteroscedastity and because data is not normally distributed within all of our genospecies groups we must use a different anova test. 
kruskal.test(Biofilm_100TY_28C_96h ~ Genospecies,
             data = biofilm_data)

# Kruskal-Wallis rank sum test
# data:  Biofilm_100TY_28C_96h by Genospecies
# Kruskal-Wallis chi-squared = 51.346, df = 4, p-value = 1.89e-10

# then carry out Dunns test for multiple comparisons with pvalue correction as post hoc.
dunnTest(Biofilm_100TY_28C_96h ~ Genospecies,
         data = biofilm_data,
         method = "bonferroni")

# Dunn (1964) Kruskal-Wallis multiple comparison
# p-values adjusted with the Bonferroni method.
# 
# Comparison           Z      P.unadj        P.adj
# 1       A - B -5.62118710 1.896497e-08 1.896497e-07 # significant
# 2       A - C -5.36261254 8.202683e-08 8.202683e-07 # significant
# 3       B - C  1.62689747 1.037589e-01 1.000000e+00
# 4       A - D  0.09717295 9.225891e-01 1.000000e+00
# 5       B - D  3.01948897 2.532015e-03 2.532015e-02 # significant
# 6       C - D  2.45962786 1.390811e-02 1.390811e-01
# 7       A - E  0.10802189 9.139783e-01 1.000000e+00
# 8       B - E  4.12875414 3.647342e-05 3.647342e-04 # significant
# 9       C - E  3.52747643 4.195411e-04 4.195411e-03 # significant
# 10      D - E -0.01663816 9.867253e-01 1.000000e+00


# also do anova where Biofilm OD is divided by the OD at 96h to normalise the data that way and see if it
# makes any difference?

biofilm_data$Biofilm_normalised <- biofilm_data$Biofilm_100TY_28C_96h / biofilm_data$OD_96h

# because we have heteroscedastity and because data is not normally distributed within all of our genospecies groups we must use a different anova test. 
kruskal.test(Biofilm_normalised ~ Genospecies,
             data = biofilm_data)

# Kruskal-Wallis rank sum test
# data:  Biofilm_normalised by Genospecies
# Kruskal-Wallis chi-squared = 47.513, df = 4, p-value = 1.192e-09


# then carry out Dunns test for multiple comparisons with pvalue correction as post hoc.
dunnTest(Biofilm_normalised ~ Genospecies,
         data = biofilm_data,
         method = "bonferroni")

# Dunn (1964) Kruskal-Wallis multiple comparison
# p-values adjusted with the Bonferroni method.
# 
# Comparison           Z      P.unadj        P.adj
# 1       A - B -5.40182370 6.596677e-08 6.596677e-07 # significant
# 2       A - C -5.24731977 1.543279e-07 1.543279e-06 # significant
# 3       B - C  1.46942887 1.417165e-01 1.000000e+00
# 4       A - D -0.09693536 9.227777e-01 1.000000e+00
# 5       B - D  2.71133906 6.701206e-03 6.701206e-02
# 6       C - D  2.20484978 2.746464e-02 2.746464e-01
# 7       A - E  0.09866098 9.214074e-01 1.000000e+00
# 8       B - E  3.96248661 7.417317e-05 7.417317e-04 # significant
# 9       C - E  3.44386182 5.734687e-04 5.734687e-03 # significant
# 10      D - E  0.15035969 8.804808e-01 1.000000e+00



# Figures -------------------------------


# figure Rmax (maximum growth rate)
(graph_Rmax <- ggplot(data = Rmax_data, aes(x = Genospecies, y = MaxGrowthRate)) +
  geom_boxplot(width = 0.5) +
  geom_point(aes(colour = Inoculant_strain, alpha = 0.5), 
             position = position_jitter(seed = 42, width = 0.1)) +
  geom_point(data = Rmax_data[Rmax_data$Inoculant_strain == "Inoculant strain", ], 
             aes(x = Genospecies, y = MaxGrowthRate, colour = Inoculant_strain, alpha = 0.5), 
             position = position_jitter(seed = 42, width = 0.1)) +
  scale_colour_manual(name = "Inoculant strain", values = c("red","black")) +
  labs(x = "Genospecies",
       y = "Maximum Growth Rate in TY broth (Rmax)") +
  guides(alpha = "none") +
  theme_bw() +
  theme(axis.title = element_text(size = 14),
        axis.text = element_text(size = 12),
        legend.title = element_text(size = 14),
        legend.text = element_text(size = 12))
)
ggsave("../data/data_output/figures/Supplementary/strain_phenotype_TYgrowth.pdf", plot = graph_Rmax, width = 15, height = 15, units = "cm")


# figure biofilm
(graph_biofilm <- ggplot(data = biofilm_data, aes(x = Genospecies, y = Biofilm_100TY_28C_96h)) +
    geom_boxplot(width = 0.5) +
    geom_point(aes(colour = Inoculant_strain, alpha = 0.5), 
               position = position_jitter(seed = 42, width = 0.1)) +
    geom_point(data = biofilm_data[biofilm_data$Inoculant_strain == "Inoculant strain", ], 
               aes(x = Genospecies, y = Biofilm_100TY_28C_96h, colour = Inoculant_strain, alpha = 0.5), 
               position = position_jitter(seed = 42, width = 0.1)) +
    scale_colour_manual(name = "Inoculant strain", values = c("red","black")) +
    labs(x = "Genospecies",
         y = "Biofilm formation in TY broth (OD600nm)") +
    guides(alpha = "none") +
    theme_bw() +
    theme(axis.title = element_text(size = 14),
          axis.text = element_text(size = 12),
          legend.title = element_text(size = 14),
          legend.text = element_text(size = 12))
)
ggsave("../data/data_output/figures/Supplementary/strain_phenotype_TYbiofilm.pdf", plot = graph_biofilm, width = 15, height = 15, units = "cm")


# figure biofilm NORMALISED
(graph_biofilmnorm <- ggplot(data = biofilm_data, aes(x = Genospecies, y = Biofilm_normalised)) +
    geom_boxplot(width = 0.5) +
    geom_point(aes(colour = Inoculant_strain, alpha = 0.5), 
               position = position_jitter(seed = 42, width = 0.1)) +
    geom_point(data = biofilm_data[biofilm_data$Inoculant_strain == "Inoculant strain", ], 
               aes(x = Genospecies, y = Biofilm_normalised, colour = Inoculant_strain, alpha = 0.5), 
               position = position_jitter(seed = 42, width = 0.1)) +
    scale_colour_manual(name = "Inoculant strain", values = c("red","black")) +
    labs(x = "Genospecies",
         y = "Biofilm formation in TY broth") +
    guides(alpha = "none") +
    theme_bw() +
    theme(axis.title = element_text(size = 14),
          axis.text = element_text(size = 12),
          legend.title = element_text(size = 14),
          legend.text = element_text(size = 12))
)
ggsave("../data/data_output/figures/Supplementary/strain_phenotype_TYbiofilm_normalised.pdf", plot = graph_biofilmnorm, width = 15, height = 15, units = "cm")


