# Author: Bryden Fields
# Email: bryden.fields@york.ac.uk

# Initial setup --------------------

library(Hmisc)
library(labdsv)
library(MASS)
library(vegan)
library(ggplot2)

#set the working directory to the directory this script is in.
#setwd("~/whatever/folder/you/are/working/from")
setwd("/Users/brydenfields/Documents/Publications/2023_Clovergenotype_paper/scripts")

# Analysis for variance partitioning followed from https://github.com/QCBSRworkshops/workshop10
# and
# http://www.hiercourse.com/docs/variationPartitioning.html



# Load in data and format -------------------


# load in species relative abundance data
spe <- read.csv("../data/data_output/abundance_data/clovergeno_allgenes_pca_matrix_withingene_ra.csv", row.names = 1)

# remove block 2 data from the analysis
spe <- spe[spe$Block %in% "1", ]

# take the F2 column and add to a separate env dataframe
x <- ncol(spe) - 4
env <- spe[, x:ncol(spe)]

# only need the F2 column for variance partitioning so remove other columns
env[,c("plot", "F2_plot","plot_rep", "Block")] <- NULL

# remove the metadata from the spe dataframe
spe[, x:ncol(spe)] <- NULL

# read in the spatial distribution data
spatial_data <- read.csv("/Users/brydenfields/Documents/Publications/2021_Clovergenotype_paper/data/raw_data/abundance_data/plot_environment_data_xycoordinates.csv", row.names = 1)

# remove block 2 data from the analysis
spatial_data <- spatial_data[spatial_data$Block %in% "1", ]

# take only x and y coordinates and reorder rows the same as the species data matrix
spatial_data <- spatial_data[row.names(spe) ,c("x","y")]

# Count number of species frequencies in each abundance class
ab <- table(unlist(spe))

# Plot distribution of species frequencies
barplot(ab, las = 1, # make axis labels perpendicular to axis
        xlab = "Abundance class", ylab = "Frequency", # label axes
        col = grey(5:0/5)) # 5-colour gradient for the bars

# How many 0s are in the dataset?
sum(spe == 0)
# [1] 990

# What proportion of the dataset does that represent?
sum(spe==0)/(nrow(spe)*ncol(spe))
# [1] 0.4852941
# 48.52% of the dataset consists of 0s

# We don't want these common absences to artificially increase the similarity between sites.
# To avoid this, we can use Hellinger transformation on the community data.
spe.hel <- decostand(spe, method = "hellinger")



# extra formatting of the spatial data to consider non-linear gradients ----------------


# look at the spatial distribution of samples in two dimentions
plot(spatial_data)

# represent spatial patterns through PCNMs
spatial_data.pcnm <- pcnm(dist(spatial_data))

# loadings for each PCNM axis can be extracted using scores()
str(scores(spatial_data.pcnm))

# num [1:30, 1:18] 0.154 0.154 0.154 0.23 0.223 ...
# - attr(*, "dimnames")=List of 2
# ..$ : chr [1:30] "6-10A" "6-10B" "6-10C" "6-12A" ...
# ..$ : chr [1:18] "PCNM1" "PCNM2" "PCNM3" "PCNM4" ...

# plot the first six PCNM axes to visualise the patterns that they represent.
# ordisurf() fits a smooth surface model to the data, but the output is suppressed here
# as a biproduct, ordisurf returns the plot that we want
par(mfrow=c(3, 2))
ordisurf(spatial_data,scores(spatial_data.pcnm,choi=1),bubble=4,
         main='PCNM 1')
ordisurf(spatial_data,scores(spatial_data.pcnm,choi=2),bubble=4,
         main='PCNM 2')
ordisurf(spatial_data,scores(spatial_data.pcnm,choi=3),bubble=4,
         main='PCNM 3')
ordisurf(spatial_data,scores(spatial_data.pcnm,choi=4),bubble=4,
         main='PCNM 4')
ordisurf(spatial_data,scores(spatial_data.pcnm,choi=5),bubble=4,
         main='PCNM 5')
ordisurf(spatial_data,scores(spatial_data.pcnm,choi=6),bubble=4,
         main='PCNM 6')

# spatial matrix as predictor
cap.pcnm <- capscale(spe.hel ~ ., 
                     data=as.data.frame(scores(spatial_data.pcnm)), 
                     distance='bray')
cap.pcnm

# Call: capscale(formula = spe.hel ~ PCNM1 + PCNM2 + PCNM3 + PCNM4 + PCNM5 + PCNM6 + PCNM7 + PCNM8 +
#                        PCNM9 + PCNM10 + PCNM11 + PCNM12 + PCNM13 + PCNM14 + PCNM15 + PCNM16 + PCNM17 + PCNM18, data =
#                        as.data.frame(scores(spatial_data.pcnm)), distance = "bray")
# 
# Inertia Proportion Rank
# Total          1.90180    1.00000     
# Constrained    1.37970    0.72547   18
# Unconstrained  0.62427    0.32825   11
# Imaginary     -0.10217   -0.05372    8
# Inertia is squared Bray distance 
# Species scores projected from ‘spe.hel’ 
# 
# Eigenvalues for constrained axes:
#         CAP1   CAP2   CAP3   CAP4   CAP5   CAP6   CAP7   CAP8   CAP9  CAP10  CAP11  CAP12  CAP13  CAP14  CAP15  CAP16 
# 0.5345 0.2377 0.1408 0.1023 0.0796 0.0621 0.0449 0.0391 0.0357 0.0292 0.0255 0.0144 0.0125 0.0097 0.0047 0.0040 
# CAP17  CAP18 
# 0.0024 0.0006 
# 
# Eigenvalues for unconstrained axes:
#         MDS1    MDS2    MDS3    MDS4    MDS5    MDS6    MDS7    MDS8    MDS9   MDS10   MDS11 
# 0.25120 0.14125 0.07031 0.04607 0.03993 0.02184 0.01494 0.01294 0.01202 0.00827 0.00550 


# select variables to proceed with (here we use both forward and backward selection)

# set up  null cases with no predictors
mod0.pcnm <- capscale(spe.hel ~ 1, data=as.data.frame(scores(spatial_data.pcnm)), distance='bray')

# select variables in each predictor table
step.pcnm <- ordistep(mod0.pcnm, scope=formula(cap.pcnm))

# Start: spe.hel ~ 1 
# 
# Df    AIC      F Pr(>F)   
# + PCNM3   1 19.061 4.8317  0.005 **
# + PCNM14  1 21.938 1.8293  0.110   
# + PCNM9   1 22.097 1.6719  0.120   
# + PCNM4   1 22.358 1.4152  0.165   
# + PCNM7   1 22.547 1.2298  0.240   
# + PCNM2   1 22.433 1.3416  0.245   
# + PCNM13  1 22.797 0.9876  0.370   
# + PCNM6   1 22.801 0.9837  0.460   
# + PCNM10  1 22.973 0.8183  0.565   
# + PCNM1   1 23.007 0.7855  0.575   
# + PCNM11  1 23.000 0.7918  0.610   
# + PCNM17  1 23.109 0.6878  0.695   
# + PCNM18  1 23.126 0.6712  0.735   
# + PCNM16  1 23.230 0.5716  0.790   
# + PCNM5   1 23.206 0.5953  0.840   
# + PCNM8   1 23.270 0.5345  0.845   
# + PCNM15  1 23.273 0.5316  0.870   
# + PCNM12  1 23.506 0.3106  0.985   
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Step: spe.hel ~ PCNM3 
# 
# Df    AIC      F Pr(>F)   
# - PCNM3  1 21.837 4.8317  0.005 **
#         ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Df    AIC      F Pr(>F)  
# + PCNM14  1 18.823 2.0919  0.050 *
# + PCNM9   1 19.011 1.9101  0.075 .
# + PCNM2   1 19.408 1.5296  0.120  
# + PCNM4   1 19.319 1.6142  0.135  
# + PCNM7   1 19.543 1.4011  0.210  
# + PCNM6   1 19.843 1.1191  0.280  
# + PCNM13  1 19.838 1.1235  0.330  
# + PCNM10  1 20.045 0.9299  0.435  
# + PCNM11  1 20.078 0.8997  0.475  
# + PCNM1   1 20.085 0.8925  0.505  
# + PCNM17  1 20.206 0.7810  0.640  
# + PCNM18  1 20.226 0.7621  0.700  
# + PCNM5   1 20.320 0.6756  0.755  
# + PCNM8   1 20.395 0.6063  0.775  
# + PCNM16  1 20.349 0.6486  0.820  
# + PCNM15  1 20.398 0.6031  0.820  
# + PCNM12  1 20.673 0.3519  0.970  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Step: spe.hel ~ PCNM3 + PCNM14 
# 
# Df    AIC      F Pr(>F)   
# - PCNM14  1 19.061 2.0919  0.060 . 
# - PCNM3   1 21.938 5.0201  0.005 **
#         ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Df    AIC      F Pr(>F)  
# + PCNM9   1 18.607 1.9927  0.035 *
# + PCNM4   1 18.941 1.6826  0.115  
# + PCNM2   1 19.037 1.5941  0.115  
# + PCNM7   1 19.184 1.4596  0.150  
# + PCNM13  1 19.503 1.1695  0.305  
# + PCNM6   1 19.508 1.1648  0.310  
# + PCNM10  1 19.727 0.9674  0.400  
# + PCNM11  1 19.762 0.9359  0.480  
# + PCNM1   1 19.770 0.9284  0.495  
# + PCNM18  1 19.922 0.7925  0.605  
# + PCNM17  1 19.900 0.8121  0.660  
# + PCNM5   1 20.023 0.7023  0.690  
# + PCNM16  1 20.054 0.6743  0.730  
# + PCNM15  1 20.108 0.6268  0.735  
# + PCNM8   1 20.104 0.6302  0.750  
# + PCNM12  1 20.404 0.3655  0.985  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Step: spe.hel ~ PCNM3 + PCNM14 + PCNM9 
# 
# Df    AIC      F Pr(>F)   
# - PCNM14  1 19.011 2.1688  0.065 . 
# - PCNM9   1 18.823 1.9927  0.040 * 
#         - PCNM3   1 22.081 5.2047  0.005 **
#         ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Df    AIC      F Pr(>F)  
# + PCNM2   1 18.681 1.6580  0.085 .
# + PCNM4   1 18.577 1.7506  0.090 .
# + PCNM7   1 18.839 1.5176  0.130  
# + PCNM6   1 19.189 1.2100  0.240  
# + PCNM13  1 19.183 1.2149  0.265  
# + PCNM10  1 19.425 1.0044  0.360  
# + PCNM11  1 19.463 0.9715  0.405  
# + PCNM1   1 19.472 0.9637  0.430  
# + PCNM18  1 19.636 0.8223  0.565  
# + PCNM17  1 19.612 0.8428  0.620  
# + PCNM5   1 19.745 0.7286  0.690  
# + PCNM16  1 19.779 0.6994  0.720  
# + PCNM8   1 19.833 0.6536  0.790  
# + PCNM15  1 19.837 0.6501  0.810  
# + PCNM12  1 20.156 0.3788  0.990  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1



# only three of the PCNM axes appear to predict variation in community composition
step.pcnm

# Call: capscale(formula = spe.hel ~ PCNM3 + PCNM14 + PCNM9, data =
#                        as.data.frame(scores(spatial_data.pcnm)), distance = "bray")
# 
# Inertia Proportion Rank
# Total          1.90180    1.00000     
# Constrained    0.53072    0.27906    3
# Unconstrained  1.47325    0.77466   21
# Imaginary     -0.10217   -0.05372    8
# Inertia is squared Bray distance 
# Species scores projected from ‘spe.hel’ 
# 
# Eigenvalues for constrained axes:
#         CAP1   CAP2   CAP3 
#       0.3884 0.1210 0.0213 
# 
# Eigenvalues for unconstrained axes:
#         MDS1   MDS2   MDS3   MDS4   MDS5   MDS6   MDS7   MDS8 
#       0.4106 0.2745 0.1467 0.1135 0.0930 0.0863 0.0652 0.0503 
# (Showing 8 of 21 unconstrained eigenvalues)



# presents results in an ANOVA-like table
step.pcnm$anova  

#          Df    AIC      F Pr(>F)   
# + PCNM3   1 19.061 4.8317  0.005 **
# + PCNM14  1 18.823 2.0919  0.050 * 
# + PCNM9   1 18.607 1.9927  0.035 * 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# create pcnm table with only significant axes
spatial_data.pcnm.sub <- scores(spatial_data.pcnm, 
                        choices=c(3, 9, 14))


# Now we can do the variance partitioning analysis but only including the spatial distribution variables that appeared to be important for explaining variation



# also making rlt allele matrix for individual genes --------------


# We don't want these common absences to artificially increase the similarity between sites.
# To avoid this, we can use Hellinger transformation on the community data.

# reca columns only
spe.hel.reca <- decostand(spe[, c(45:52)], method = "hellinger")

# rpob columns only
spe.hel.rpob <- decostand(spe[, c(53:68)], method = "hellinger")

# noda columns only
spe.hel.noda <- decostand(spe[, c(1:21)], method = "hellinger")

# nodd columns only
spe.hel.nodd <- decostand(spe[, c(22:44)], method = "hellinger")



# Variance partitioning: all genes --------------


# partition variation among two predictor tables:
#   1) clover genotype/cross (e.g. cross 1, cross 2...)
#   2) spatial gradients


# partition the variation of ralstonia allele compositions between clover genotype and spatial distribution.
spe.part.all <- varpart(spe.hel, env, spatial_data.pcnm.sub)

# print results
spe.part.all$part

# No. of explanatory tables: 2 
# Total variation (SS): 5.2649 
# Variance: 0.18155 
# No. of observations: 30 
# 
# Partition table:
#         Df R.squared Adj.R.squared Testable
# [a+b] = X1            4   0.32354       0.21531     TRUE
# [b+c] = X2            3   0.29883       0.21792     TRUE
# [a+b+c] = X1+X2       7   0.44044       0.26240     TRUE
# Individual fractions                                    
# [a] = X1|X2           4                 0.04447     TRUE
# [b]                   0                 0.17083    FALSE
# [c] = X2|X1           3                 0.04709     TRUE
# [d] = Residuals                         0.73760    FALSE
# ---
#         Use function ‘rda’ to test significance of fractions of interest


# We find that 4.4% of the variance is explained by clover genotype
# We find that 4.7% of the variance is explained by spatial distribution


# make venn diagram of the variance partitioning results
plot(spe.part.all,
     Xnames = c("Clover genotype", "Spatial distribution"), # name the partitions
     bg = c("seagreen3", "mediumpurple"), alpha = 80, # colour the circles
     digits = 2, # only show 2 digits
     cex = 1.5)


# The shared fraction [b] cannot be tested for significance.
# But, we can test the significance of the remaining fractions.
# Use function ‘rda’ to test significance of fractions of interest

# [a+b] Clover genotype without controlling for spatial distribution
anova.cca(rda(spe.hel, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env)
#          Df Variance      F Pr(>F)    
# Model     4 0.058738 2.9893  0.001 ***
# Residual 25 0.122810                  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [b+c] Spatial distribution without controlling for clover genotype
anova.cca(rda(spe.hel, spatial_data.pcnm.sub))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data.pcnm.sub)
# Df Variance      F Pr(>F)    
# Model     3 0.054251 3.6935  0.001 ***
#         Residual 26 0.127297                  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [a] Clover genotype alone
anova.cca(rda(spe.hel, env, spatial_data.pcnm.sub))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env, Z = spatial_data.pcnm.sub)
# Df Variance      F Pr(>F)  
# Model     4 0.025709 1.3919  0.075 .
# Residual 22 0.101587                
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [c] Spatial distribution alone
anova.cca(rda(spe.hel, spatial_data.pcnm.sub, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data.pcnm.sub, Z = env)
# Df Variance     F Pr(>F)  
# Model     3 0.021222 1.532   0.05 *
#         Residual 22 0.101587               
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# Individual variable fractions that are significant (p < 0.05) are:
# [a+b] Clover genotype without controlling for spatial distribution
# [b+c] Spatial distribution without controlling for clover genotype
# [c] Spatial distribution alone (p = 0.05 so only just!!)

# Variables that are not significant (but only just!!)
# [a] Clover genotype alone (p = 0.075)

# Clover genotype explains a small proportion of the variation in species abundances with 4.4% (not sig. p = 0.075) of the variation is explained by clover genotype alone, and 17.1% is jointly explained by clover genotype and spatial distribution. Spatial distribution on it's own also explains only a small proportion 4.7% of the variation in community composition across Block 1 samples (p = 0.05).
# Additionally, 73.8% of the variation is not explained by the variables we included in the model. Perhaps other variables we have not included such as soil physiochemical properties and rhizosphere rhizobial community composition could improve model fit.



# Variance partitioning: reca --------------


# partition variation among two predictor tables:
#   1) clover genotype/cross (e.g. cross 1, cross 2...)
#   2) spatial gradients


# partition the variation of ralstonia allele compositions between clover genotype and spatial distribution.
spe.part.all <- varpart(spe.hel.reca, env, spatial_data.pcnm.sub)

# print results
spe.part.all$part

# No. of explanatory tables: 2 
# Total variation (SS): 2.6726 
# Variance: 0.092158 
# No. of observations: 30 
# 
# Partition table:
#                      Df R.squared Adj.R.squared Testable
# [a+b] = X1            4   0.40295       0.30742     TRUE
# [b+c] = X2            3   0.44207       0.37770     TRUE
# [a+b+c] = X1+X2       7   0.57870       0.44465     TRUE
# Individual fractions                                    
# [a] = X1|X2           4                 0.06696     TRUE
# [b]                   0                 0.24046    FALSE
# [c] = X2|X1           3                 0.13724     TRUE
# [d] = Residuals                         0.55535    FALSE
# ---
#         Use function ‘rda’ to test significance of fractions of interest

# We find that 6.7% of the variance is explained by clover genotype
# We find that 13.7% of the variance is explained by spatial distribution


# make venn diagram of the variance partitioning results
plot(spe.part.all,
     Xnames = c("Clover genotype", "Spatial distribution"), # name the partitions
     bg = c("seagreen3", "mediumpurple"), alpha = 80, # colour the circles
     digits = 2, # only show 2 digits
     cex = 1.5)


# The shared fraction [b] cannot be tested for significance.
# But, we can test the significance of the remaining fractions.
# Use function ‘rda’ to test significance of fractions of interest

# [a+b] Clover genotype without controlling for spatial distribution
anova.cca(rda(spe.hel, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env)
# Df Variance      F Pr(>F)    
# Model     4 0.058738 2.9893  0.001 ***
#         Residual 25 0.122810                  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [b+c] Spatial distribution without controlling for clover genotype
anova.cca(rda(spe.hel, spatial_data.pcnm.sub))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data.pcnm.sub)
# Df Variance      F Pr(>F)    
# Model     3 0.054251 3.6935  0.001 ***
#         Residual 26 0.127297                  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [a] Clover genotype alone
anova.cca(rda(spe.hel, env, spatial_data.pcnm.sub))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env, Z = spatial_data.pcnm.sub)
# Df Variance      F Pr(>F)
# Model     4 0.025709 1.3919  0.106
# Residual 22 0.101587            


# [c] Spatial distribution alone
anova.cca(rda(spe.hel, spatial_data.pcnm.sub, env))
# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data.pcnm.sub, Z = env)
# Df Variance     F Pr(>F)  
# Model     3 0.021222 1.532  0.069 .
# Residual 22 0.101587               
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1




# Variance partitioning: rpob --------------

# partition variation among two predictor tables:
#   1) clover genotype (e.g. cross 1, cross 2...)
#   2) spatial gradients


# partition the variation of ralstonia allele compositions between clover genotype and spatial distribution.
spe.part.all <- varpart(spe.hel.rpob, env, spatial_data.pcnm.sub)

# print results
spe.part.all$part

# No. of explanatory tables: 2 
# Total variation (SS): 5.1991 
# Variance: 0.17928 
# No. of observations: 30 
# 
# Partition table:
#                      Df R.squared Adj.R.squared Testable
# [a+b] = X1            4   0.39329       0.29622     TRUE
# [b+c] = X2            3   0.30041       0.21969     TRUE
# [a+b+c] = X1+X2       7   0.50212       0.34370     TRUE
# Individual fractions                                    
# [a] = X1|X2           4                 0.12402     TRUE
# [b]                   0                 0.17220    FALSE
# [c] = X2|X1           3                 0.04749     TRUE
# [d] = Residuals                         0.65630    FALSE
# ---
#         Use function ‘rda’ to test significance of fractions of interest


# We find that 12.4% of the variance is explained by clover genotype
# We find that 4.7% of the variance is explained by spatial distribution


# make venn diagram of the variance partitioning results
plot(spe.part.all,
     Xnames = c("Clover genotype", "Spatial distribution"), # name the partitions
     bg = c("seagreen3", "mediumpurple"), alpha = 80, # colour the circles
     digits = 2, # only show 2 digits
     cex = 1.5)


# The shared fraction [b] cannot be tested for significance.
# But, we can test the significance of the remaining fractions.
# Use function ‘rda’ to test significance of fractions of interest

# [a+b] Clover genotype without controlling for spatial distribution
anova.cca(rda(spe.hel, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env)
# Df Variance      F Pr(>F)    
# Model     4 0.058738 2.9893  0.001 ***
#         Residual 25 0.122810                  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [b+c] Spatial distribution without controlling for clover genotype
anova.cca(rda(spe.hel, spatial_data.pcnm.sub))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data.pcnm.sub)
# Df Variance      F Pr(>F)    
# Model     3 0.054251 3.6935  0.001 ***
# Residual 26 0.127297                  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# [a] Clover genotype alone
anova.cca(rda(spe.hel, env, spatial_data.pcnm.sub))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env, Z = spatial_data.pcnm.sub)
# Df Variance      F Pr(>F)  
# Model     4 0.025709 1.3919  0.093 .
# Residual 22 0.101587                
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# [c] Spatial distribution alone
anova.cca(rda(spe.hel, spatial_data.pcnm.sub, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data.pcnm.sub, Z = env)
# Df Variance     F Pr(>F)  
# Model     3 0.021222 1.532  0.073 .
# Residual 22 0.101587               
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# Individual variable fractions that are significant (p < 0.05) are:



# Variance partitioning: noda --------------


# partition variation among two predictor tables:
#   1) clover genotype (e.g. cross 1, cross 2...)
#   2) spatial gradients


# partition the variation of ralstonia allele compositions between clover genotype and spatial distribution.
spe.part.all <- varpart(spe.hel.noda, env, spatial_data.pcnm.sub)

# print results
spe.part.all$part

# No. of explanatory tables: 2 
# Total variation (SS): 7.0094 
# Variance: 0.2417 
# No. of observations: 30 
# 
# Partition table:
#         Df R.squared Adj.R.squared Testable
# [a+b] = X1            4   0.28485       0.17043     TRUE
# [b+c] = X2            3   0.29956       0.21874     TRUE
# [a+b+c] = X1+X2       7   0.40444       0.21495     TRUE
# Individual fractions                                    
# [a] = X1|X2           4                -0.00379     TRUE
# [b]                   0                 0.17422    FALSE
# [c] = X2|X1           3                 0.04452     TRUE
# [d] = Residuals                         0.78505    FALSE
# ---
#         Use function ‘rda’ to test significance of fractions of interest


# We find that -0.3% of the variance is explained by clover genotype
# We find that 4.4% of the variance is explained by spatial distribution


# make venn diagram of the variance partitioning results
plot(spe.part.all,
     Xnames = c("Clover genotype", "Spatial distribution"), # name the partitions
     bg = c("seagreen3", "mediumpurple"), alpha = 80, # colour the circles
     digits = 2, # only show 2 digits
     cex = 1.5)


# The shared fraction [b] cannot be tested for significance.
# But, we can test the significance of the remaining fractions.
# Use function ‘rda’ to test significance of fractions of interest

# [a+b] Clover genotype without controlling for spatial distribution
anova.cca(rda(spe.hel, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env)
# Df Variance      F Pr(>F)    
# Model     4 0.058738 2.9893  0.001 ***
#         Residual 25 0.122810                  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

# [b+c] Spatial distribution without controlling for clover genotype
anova.cca(rda(spe.hel, spatial_data.pcnm.sub))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data.pcnm.sub)
# Df Variance      F Pr(>F)   
# Model     3 0.054251 3.6935  0.002 **
#         Residual 26 0.127297                 
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [a] Clover genotype alone
anova.cca(rda(spe.hel, env, spatial_data.pcnm.sub))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env, Z = spatial_data.pcnm.sub)
# Df Variance      F Pr(>F)  
# Model     4 0.025709 1.3919  0.095 .
# Residual 22 0.101587                
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [c] Spatial distribution alone
anova.cca(rda(spe.hel, spatial_data.pcnm.sub, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data.pcnm.sub, Z = env)
# Df Variance     F Pr(>F)  
# Model     3 0.021222 1.532  0.066 .
# Residual 22 0.101587               
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1



# Variance partitioning: nodd --------------

# partition variation among two predictor tables:
#   1) clover genotype (e.g. cross 1, cross 2...)
#   2) spatial gradients


# partition the variation of ralstonia allele compositions between clover genotype and spatial distribution.
spe.part.all <- varpart(spe.hel.nodd, env, spatial_data.pcnm.sub)

# print results
spe.part.all$part

# No. of explanatory tables: 2 
# Total variation (SS): 6.1784 
# Variance: 0.21305 
# No. of observations: 30 
# 
# Partition table:
#                      Df R.squared Adj.R.squared Testable
# [a+b] = X1            4   0.27439       0.15829     TRUE
# [b+c] = X2            3   0.23470       0.14640     TRUE
# [a+b+c] = X1+X2       7   0.36956       0.16896     TRUE
# Individual fractions                                    
# [a] = X1|X2           4                 0.02257     TRUE
# [b]                   0                 0.13572    FALSE
# [c] = X2|X1           3                 0.01067     TRUE
# [d] = Residuals                         0.83104    FALSE
# ---
#         Use function ‘rda’ to test significance of fractions of interest


# We find that 2.2% of the variance is explained by clover genotype
# We find that 1.1% of the variance is explained by spatial distribution


# make venn diagram of the variance partitioning results
plot(spe.part.all,
     Xnames = c("Clover genotype", "Spatial distribution"), # name the partitions
     bg = c("seagreen3", "mediumpurple"), alpha = 80, # colour the circles
     digits = 2, # only show 2 digits
     cex = 1.5)


# The shared fraction [b] cannot be tested for significance.
# But, we can test the significance of the remaining fractions.
# Use function ‘rda’ to test significance of fractions of interest

# [a+b] Clover genotype without controlling for spatial distribution
anova.cca(rda(spe.hel, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env)
# Df Variance      F Pr(>F)    
# Model     4 0.058738 2.9893  0.001 ***
#         Residual 25 0.122810                  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [b+c] Spatial distribution without controlling for clover genotype
anova.cca(rda(spe.hel, spatial_data.pcnm.sub))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data.pcnm.sub)
# Df Variance      F Pr(>F)    
# Model     3 0.054251 3.6935  0.001 ***
#         Residual 26 0.127297                  
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [a] Clover genotype alone
anova.cca(rda(spe.hel, env, spatial_data.pcnm.sub))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env, Z = spatial_data.pcnm.sub)
# Df Variance      F Pr(>F)  
# Model     4 0.025709 1.3919  0.089 .
# Residual 22 0.101587                
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [c] Spatial distribution alone
anova.cca(rda(spe.hel, spatial_data.pcnm.sub, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data.pcnm.sub, Z = env)
# Df Variance     F Pr(>F)  
# Model     3 0.021222 1.532  0.067 .
# Residual 22 0.101587               
# ---
#         Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1



# Variance partitioning (without the spatial gradients: just xy coordinates) --------------

# partition variation among two predictor tables:
#   1) clover genotype (e.g. cross 1, cross 2...)
#   2) xy coordinates as spatial data


# partition the variation of ralstonia allele compositions between clover genotype and spatial distribution.
spe.part.all <- varpart(spe.hel, env, spatial_data)

# print results
spe.part.all$part

# No. of explanatory tables: 2 
# Total variation (SS): 5.2649 
# Variance: 0.18155 
# No. of observations: 30 
# 
# Partition table:
#                      Df R.squared Adj.R.squared Testable
# [a+b] = X1            4   0.32354       0.21531     TRUE
# [b+c] = X2            2   0.10294       0.03649     TRUE
# [a+b+c] = X1+X2       6   0.38790       0.22822     TRUE
# Individual fractions                                    
# [a] = X1|X2           4                 0.19173     TRUE
# [b]                   0                 0.02357    FALSE
# [c] = X2|X1           2                 0.01292     TRUE
# [d] = Residuals                         0.77178    FALSE
# ---
#   Use function ‘rda’ to test significance of fractions of interest

# We find that 19.2% of the variance is explained by clover genotype
# We find that 1.3% of the variance is explained by spatial distribution


# make venn diagram of the variance partitioning results
plot(spe.part.all,
     Xnames = c("Clover genotype", "Spatial distribution"), # name the partitions
     bg = c("seagreen3", "mediumpurple"), alpha = 80, # colour the circles
     digits = 2, # only show 2 digits
     cex = 1.5)


# The shared fraction [b] cannot be tested for significance.
# But, we can test the significance of the remaining fractions.
# Use function ‘rda’ to test significance of fractions of interest

# [a+b] Clover genotype without controlling for spatial distribution
anova.cca(rda(spe.hel, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env)
#          Df Variance      F Pr(>F)    
# Model     4 0.058738 2.9893  0.001 ***
#   Residual 25 0.122810                  
# ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [b+c] Spatial distribution without controlling for clover genotype
anova.cca(rda(spe.hel, spatial_data))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data)
#          Df Variance      F Pr(>F)
# Model     2 0.018689 1.5492   0.11
# Residual 27 0.162859 


# [a] Clover genotype alone
anova.cca(rda(spe.hel, env, spatial_data))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = env, Z = spatial_data)
#          Df Variance      F Pr(>F)   
# Model     4 0.051734 2.6769  0.003 **
#   Residual 23 0.111125                 
# ---
#   Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1


# [c] Spatial distribution alone
anova.cca(rda(spe.hel, spatial_data, env))

# Permutation test for rda under reduced model
# Permutation: free
# Number of permutations: 999
# 
# Model: rda(X = spe.hel, Y = spatial_data, Z = env)
#          Df Variance      F Pr(>F)
# Model     2 0.011685 1.2092  0.242
# Residual 23 0.111125    



