# Author: Bryden Fields
# Email: bryden.fields@york.ac.uk

# Initial setup ----------------

library(tidyverse)
library(reshape2)
library(plyr)
library(dplyr)
library(data.table)
library(devtools)
#install_github("vqv/ggbiplot")
library(ggbiplot)
library(ggfortify)
library(factoextra)
library(ggpubr)
library(vegan)
library(UpSetR)
library(ComplexUpset)
library(MASS)
library(labdsv)
library(viridis)

#set the working directory to the directory this script is in.
#setwd("~/whatever/folder/you/are/working/from")
setwd("/Users/brydenfields/Documents/Publications/2023_Clovergenotype_paper/scripts")


# First convert raw data to relative abundance and log2 --------------------


# read in data (individual genes and all genes combined)
# The original tab files for this data can be found in the following data directories:
# data/raw_data/MAUIcount_output_noda
# data/raw_data/MAUIcount_output_nodd
# data/raw_data/MAUIcount_output_reca
# data/raw_data/MAUIcount_output_rpob
# I converted the original files into csv and saved it to the directory: data/raw_data/abundance_data/

# For each gene matrix do the following code:
# data <- read.csv('../data/raw_data/abundance_data/accepted_sequences_noda.csv', header = T)
# data <- read.csv('../data/raw_data/abundance_data/accepted_sequences_nodd.csv', header = T)
# data <- read.csv('../data/raw_data/abundance_data/accepted_sequences_reca.csv', header = T)
data <- read.csv('../data/raw_data/abundance_data/accepted_sequences_rpob.csv', header = T)

# remove the gene tag for the sample names
data$X <- sub("_.*", "", data$X)

# split data into different experiments
data_clovergeno <- data %>% 
  filter(X %in% c("6-10A", "6-10B", "6-10C", "6-12A", "6-12B", "6-12C", "6-16A", 
                  "6-16B", "6-16C", "6-18A", "6-18B", "6-18C", "6-21A", "6-21B", 
                  "6-21C", "6-23A", "6-23B", "6-23C", "6-24A", "6-24B", "6-24C", 
                  "6-26A", "6-26B", "6-26C", "6-2A",  "6-2B", "6-2C",  "6-31A", 
                  "6-31B", "6-31C",
                  "7-18A", "7-18B", "7-18C", "7-23A", "7-23B", "7-23C", "7-31A", "7-31B", "7-31C"))


# label sample column
names(data_clovergeno)[1] <- "sample"

# covert data to new dataframe for pca formatting
p1.data_clover <- data_clovergeno 

# check in dataframe how many columns.
x = ncol(p1.data_clover)

# make data relative abundance
# end row value is the ncolumns
p1.data_clover[ ,2:x] <- sweep(p1.data_clover[ ,2:x], 1, rowSums(p1.data_clover[ ,2:x]), '/') 
rowSums(p1.data_clover[ ,2:x])

# copy data for log transformation relative abundance calculation
p1.log.data_clover <- p1.data_clover

# Replace 0 with one decimal place lower number (because for log transformation can't have 0 for pca)
# this number was calculated from the allgenes dataframe (to see what the lowest number was so they all)
# have the same "0" equivilent value #noda = 0.001381215, #nodd = 0.001242236, #reca = 0.0003615329, #rpob = 0.000437254.
# test <- p1.log.data_clover[, 2:x]
# min( test[test!=min(test)] )

# lowest decimal for all genes should be
p1.log.data_clover[p1.log.data_clover == 0] <- 0.00001

# check in dataframe how many columns.
x = ncol(p1.log.data_clover)

# log transform data.
# end row value is the ncolumns
p1.log.data_clover[ ,2:x] <- log10(p1.log.data_clover[ ,2:x])

# read in the plot metadata
env_data <- read.csv('../data/raw_data/abundance_data/plot_environment_data_v3.csv')

# merge env_data with the data file so we can group samples by plots.
p1.data_clover <- merge(p1.data_clover, env_data, by = 'sample', all.x = T)
p1.log.data_clover <- merge(p1.log.data_clover, env_data, by = 'sample', all.x = T)

# make sample names a factor so that we can group them. Also make plot and F2 factors.
p1.log.data_clover$sample <- factor(p1.log.data_clover$sample)
p1.log.data_clover$plot <- factor(p1.log.data_clover$plot)
p1.log.data_clover$F2 <- factor(p1.log.data_clover$F2)

# save relative abundance file 
# CHANGE DEPENDING ON THE GENE OF INTEREST
# write.csv(p1.data_clover, file = "../data/data_output/abundance_data/clovergeno_noda_pca_matrix_ra.csv", row.names = F)
# write.csv(p1.data_clover, file = "../data/data_output/abundance_data/clovergeno_nodd_pca_matrix_ra.csv", row.names = F)
# write.csv(p1.data_clover, file = "../data/data_output/abundance_data/clovergeno_reca_pca_matrix_ra.csv", row.names = F)
write.csv(p1.data_clover, file = "../data/data_output/abundance_data/clovergeno_rpob_pca_matrix_ra.csv", row.names = F)

#save csv for log transformed data
# CHANGE DEPENDING ON THE GENE OF INTEREST
# write.csv(p1.log.data_clover, file = "../data/data_output/abundance_data/clovergeno_noda_pca_matrix_ra_logtrans.csv", row.names = F)
# write.csv(p1.log.data_clover, file = "../data/data_output/abundance_data/clovergeno_nodd_pca_matrix_ra_logtrans.csv", row.names = F)
# write.csv(p1.log.data_clover, file = "../data/data_output/abundance_data/clovergeno_reca_pca_matrix_ra_logtrans.csv", row.names = F)
write.csv(p1.log.data_clover, file = "../data/data_output/abundance_data/clovergeno_rpob_pca_matrix_ra_logtrans.csv", row.names = F)

# the output files for "clovergeno_rpob_pca_matrix_withingene_ra_logtrans.csv" and "clovergeno_rpob_pca_matrix_withingene_ra.csv" were made manually by combining the data from all 4 gene csv files generated here. (Just concatenate columns in excel)

rm(data, data_clovergeno, p1.data_clover, p1.log.data_clover, x, env_data)



# UpSetR Venn diagram Block 1 ONLY ----------------


# for each gene individually

# change relative abundance to presence/absence 
# read in ra file rather than ra_logtrans
# data <- read.csv('../data/data_output/abundance_data/clovergeno_allgenes_pca_matrix_withingene_ra.csv', row.names = 1)
# data <- read.csv('../data/data_output/abundance_data/clovergeno_noda_pca_matrix_ra.csv', row.names = 1)
# data <- read.csv('../data/data_output/abundance_data/clovergeno_nodd_pca_matrix_ra.csv', row.names = 1)
# data <- read.csv('../data/data_output/abundance_data/clovergeno_reca_pca_matrix_ra.csv', row.names = 1)
data <- read.csv('../data/data_output/abundance_data/clovergeno_rpob_pca_matrix_ra.csv', row.names = 1)

# remove the env data at the end
# check in dataframe how many columns and then do two less than this to remove categorical plot variables.
x2 = ncol(data) -2 

# change the final column value to be n-2 the total number of columns 
# removes some of environment data but also want to keep only F2 column so remove 2 environment columns
# before that
data_subset <- data[,1:x2]
data_subset <- data_subset[ , !(names(data_subset) %in% c('plot', 'F2_plot'))]

# remove block 2 plots
data_subset <- data_subset[1:30, ]

# combine data that are same cross
data_subset2 <- aggregate(. ~ F2, data = data_subset, sum, na.rm=TRUE)

# make F2 row names
row.names(data_subset2) <- data_subset2$F2
data_subset2$F2 <- NULL

# convert anything >0 to 1. Now its a presence absence matrix
data_subset2[ data_subset2 > 0] <- 1

# transform data and make as dataframe
data_trans <- t(data_subset2)
data_trans <- as.data.frame(data_trans)


# make the UpSetR diagrams for each gene
# code taken from https://stackoverflow.com/questions/67094573/upsetr-sets-bar-interacting-different-color-and-its-sets-intersections

# all genes chart

pdf('../data/data_output/figures/Fig2/allgenes_trial1_seqPA_UpSetdiagram.pdf', w = 10, h = 5)

upset(data_trans, c("Klondike", "Cross 4", "Cross 3", "Cross 2", "Cross 1"),
      intersections='all',
      sort_intersections_by='degree',
      sort_sets=F,
      sort_intersections='descending',
      name='Intersection',
      queries=list(
        upset_query(set = "Klondike", fill = "#CC79A7"),
        upset_query(set = "Cross 4", fill = "#D55E00"),
        upset_query(set = "Cross 3", fill = "#009E73"),
        upset_query(set = "Cross 2", fill = "#56B4E9"),
        upset_query(set = "Cross 1", fill = "#E69F00")
      ),
      base_annotations=list(
        "Intersection size"=(
          intersection_size(
            bar_number_threshold=1,  # show all numbers on top of bars
            width=0.5,   # reduce width of the bars
          )
          + ylab('Number of observations')
          # add some space on the top of the bars
          + scale_y_continuous(expand=expansion(mult=c(0, 0.05)))
          + theme(
            # hide grid lines
            panel.grid.major=element_blank(),
            panel.grid.minor=element_blank(),
            # show axis lines
            axis.line=element_line(colour='black')
          )
        )
      ),
      stripes=upset_stripes(
        geom=geom_segment(linewidth=12),  # make the stripes larger
        colors=c('grey95', 'white')
      ),
      # to prevent connectors from getting the coloured
      # use `fill` instead of `color`, together with `shape='circle filled'`
      matrix=intersection_matrix(
        geom=geom_point(
          shape='circle filled',
          size=3.5,
          stroke=0.45
        )
      ),
      set_sizes=(
        upset_set_size(geom=geom_bar(width=0.4))
        + ylab('Alleles per cross')
        + theme(
          axis.line.x=element_line(colour='black'),
          axis.ticks.x=element_line()
        )
      )
)



dev.off()


# nodA chart

pdf('../data/data_output/figures/Fig2/noda_trial1_seqPA_UpSetdiagram.pdf', w = 5.5, h = 5)

upset(data_trans, c("Klondike", "Cross 4", "Cross 3", "Cross 2", "Cross 1"),
      intersections='all',
      sort_intersections_by='degree',
      sort_sets=F,
      sort_intersections='descending',
      name='Intersection',
      queries=list(
        upset_query(set = "Klondike", fill = "#CC79A7"),
        upset_query(set = "Cross 4", fill = "#D55E00"),
        upset_query(set = "Cross 3", fill = "#009E73"),
        upset_query(set = "Cross 2", fill = "#56B4E9"),
        upset_query(set = "Cross 1", fill = "#E69F00")
      ),
      base_annotations=list(
        "Intersection size"=(
          intersection_size(
            bar_number_threshold=1,  # show all numbers on top of bars
            width=0.5,   # reduce width of the bars
          )
          + ylab('Number of observations')
          # add some space on the top of the bars
          + scale_y_continuous(expand=expansion(mult=c(0, 0.05)))
          + theme(
            # hide grid lines
            panel.grid.major=element_blank(),
            panel.grid.minor=element_blank(),
            # show axis lines
            axis.line=element_line(colour='black')
          )
        )
      ),
      stripes=upset_stripes(
        geom=geom_segment(linewidth=12),  # make the stripes larger
        colors=c('grey95', 'white')
      ),
      # to prevent connectors from getting the coloured
      # use `fill` instead of `color`, together with `shape='circle filled'`
      matrix=intersection_matrix(
        geom=geom_point(
          shape='circle filled',
          size=2.5,
          stroke=0.35
        )
      ),
      set_sizes=(
        upset_set_size(geom=geom_bar(width=0.4))
        + ylab(substitute(paste(italic('nodA'), ' alleles per cross')))
        + theme(
          axis.line.x=element_line(colour='black'),
          axis.ticks.x=element_line()
        )
      )
)

dev.off()


# nodD chart

pdf('../data/data_output/figures/Fig2/nodd_trial1_seqPA_UpSetdiagram.pdf', w = 5.5, h = 5)

upset(data_trans, c("Klondike", "Cross 4", "Cross 3", "Cross 2", "Cross 1"),
      intersections='all',
      sort_intersections_by='degree',
      sort_sets=F,
      sort_intersections='descending',
      name='Intersection',
      queries=list(
        upset_query(set = "Klondike", fill = "#CC79A7"),
        upset_query(set = "Cross 4", fill = "#D55E00"),
        upset_query(set = "Cross 3", fill = "#009E73"),
        upset_query(set = "Cross 2", fill = "#56B4E9"),
        upset_query(set = "Cross 1", fill = "#E69F00")
      ),
      base_annotations=list(
        "Intersection size"=(
          intersection_size(
            bar_number_threshold=1,  # show all numbers on top of bars
            width=0.5,   # reduce width of the bars
          )
          + ylab('Number of observations')
          # add some space on the top of the bars
          + scale_y_continuous(expand=expansion(mult=c(0, 0.05)))
          + theme(
            # hide grid lines
            panel.grid.major=element_blank(),
            panel.grid.minor=element_blank(),
            # show axis lines
            axis.line=element_line(colour='black')
          )
        )
      ),
      stripes=upset_stripes(
        geom=geom_segment(linewidth=12),  # make the stripes larger
        colors=c('grey95', 'white')
      ),
      # to prevent connectors from getting the coloured
      # use `fill` instead of `color`, together with `shape='circle filled'`
      matrix=intersection_matrix(
        geom=geom_point(
          shape='circle filled',
          size=2.5,
          stroke=0.35
        )
      ),
      set_sizes=(
        upset_set_size(geom=geom_bar(width=0.4))
        + ylab(substitute(paste(italic('nodD'), ' alleles per cross')))
        + theme(
          axis.line.x=element_line(colour='black'),
          axis.ticks.x=element_line()
        )
      )
)

dev.off()


# recA chart

pdf('../data/data_output/figures/Fig2/reca_trial1_seqPA_UpSetdiagram.pdf', w = 5.5, h = 5)

upset(data_trans, c("Klondike", "Cross 4", "Cross 3", "Cross 2", "Cross 1"),
      intersections='all',
      sort_intersections_by='degree',
      sort_sets=F,
      sort_intersections='descending',
      name='Intersection',
      queries=list(
        upset_query(set = "Klondike", fill = "#CC79A7"),
        upset_query(set = "Cross 4", fill = "#D55E00"),
        upset_query(set = "Cross 3", fill = "#009E73"),
        upset_query(set = "Cross 2", fill = "#56B4E9"),
        upset_query(set = "Cross 1", fill = "#E69F00")
      ),
      base_annotations=list(
        "Intersection size"=(
          intersection_size(
            bar_number_threshold=1,  # show all numbers on top of bars
            width=0.5,   # reduce width of the bars
          )
          + ylab('Number of observations')
          # add some space on the top of the bars
          + scale_y_continuous(expand=expansion(mult=c(0, 0.05)))
          + theme(
            # hide grid lines
            panel.grid.major=element_blank(),
            panel.grid.minor=element_blank(),
            # show axis lines
            axis.line=element_line(colour='black')
          )
        )
      ),
      stripes=upset_stripes(
        geom=geom_segment(linewidth=12),  # make the stripes larger
        colors=c('grey95', 'white')
      ),
      # to prevent connectors from getting the coloured
      # use `fill` instead of `color`, together with `shape='circle filled'`
      matrix=intersection_matrix(
        geom=geom_point(
          shape='circle filled',
          size=2.5,
          stroke=0.35
        )
      ),
      set_sizes=(
        upset_set_size(geom=geom_bar(width=0.4))
        + ylab(substitute(paste(italic('recA'), ' alleles per cross')))
        + theme(
          axis.line.x=element_line(colour='black'),
          axis.ticks.x=element_line()
        )
      )
)

dev.off()


# rpoB chart

pdf('../data/data_output/figures/Fig2/rpob_trial1_seqPA_UpSetRdiagram.pdf', w = 5.5, h = 5)

upset(data_trans, c("Klondike", "Cross 4", "Cross 3", "Cross 2", "Cross 1"),
      intersections='all',
      sort_intersections_by='degree',
      sort_sets=F,
      sort_intersections='descending',
      name='Intersection',
      queries=list(
        upset_query(set = "Klondike", fill = "#CC79A7"),
        upset_query(set = "Cross 4", fill = "#D55E00"),
        upset_query(set = "Cross 3", fill = "#009E73"),
        upset_query(set = "Cross 2", fill = "#56B4E9"),
        upset_query(set = "Cross 1", fill = "#E69F00")
      ),
      base_annotations=list(
        "Intersection size"=(
          intersection_size(
            bar_number_threshold=1,  # show all numbers on top of bars
            width=0.5,   # reduce width of the bars
          )
          + ylab('Number of observations')
          # add some space on the top of the bars
          + scale_y_continuous(expand=expansion(mult=c(0, 0.05)))
          + theme(
            # hide grid lines
            panel.grid.major=element_blank(),
            panel.grid.minor=element_blank(),
            # show axis lines
            axis.line=element_line(colour='black')
          )
        )
      ),
      stripes=upset_stripes(
        geom=geom_segment(linewidth=12),  # make the stripes larger
        colors=c('grey95', 'white')
      ),
      # to prevent connectors from getting the coloured
      # use `fill` instead of `color`, together with `shape='circle filled'`
      matrix=intersection_matrix(
        geom=geom_point(
          shape='circle filled',
          size=2.5,
          stroke=0.35
        )
      ),
      set_sizes=(
        upset_set_size(geom=geom_bar(width=0.4))
        + ylab(substitute(paste(italic('rpoB'), ' alleles per cross')))
        + theme(
          axis.line.x=element_line(colour='black'),
          axis.ticks.x=element_line()
        )
      )
)

dev.off()



# number of alleles for each clover genotype -------------


# do some clover genotypes have more alleles than others?

# make barchart with x = clover genotype, y = number of alleles in nodules, legend = gene

# # read in relative abundance counts 
data <-  read.csv('../data/data_output/abundance_data/clovergeno_allgenes_pca_matrix_withingene_ra.csv', sep = ',', row.names = 1)

# remove the env data at the end
# check in dataframe how many columns and then do two less than this to remove categorical variables.
x2 = ncol(data) -2 

# change the final column value to be n-2 the total number of columns 
# removes some of environment data but also want to keep only F2 column so remove 2 environment columns
# before that
data_subset <- data[,1:x2]
data_subset <- data_subset[ , !(names(data_subset) %in% c('plot', 'F2_plot'))]

# remove trial 2 plots
data_subset <- data_subset[1:30, ]

# combine data that are same cross
data_subset2 <- aggregate(. ~ F2, data = data_subset, sum, na.rm=TRUE)

# make F2 row names
row.names(data_subset2) <- data_subset2$F2
data_subset2$F2 <- NULL

# convert anything >0 to 1. Now its a presence absence matrix
data_subset2[ data_subset2 > 0] <- 1

# get F2 column back 
data_subset2$F2 <- row.names(data_subset2)

# melt the data into a long format for graph
p1.data <- melt(data_subset2, id='F2')
# make values numerical
p1.data$value <- as.numeric(p1.data$value)

# Create gene column for facetting 
p2.data <- data.frame(do.call(rbind, strsplit(as.character(p1.data$variable), "_")))
p1.data$gene <- p2.data$X3  

# change labels for gene names
p1.data$gene <- factor(p1.data$gene, levels = c('rpob', 'reca', 'noda', 'nodd'),
                       labels = c('rpoB', 'recA', 'nodA', 'nodD'))

# combine data that are same cross
p3.data <- aggregate(value ~ F2 + gene, data = p1.data, sum, na.rm=TRUE)

# Plot barchart of abundances
(bargraph <-  ggplot(p3.data, aes(x = gene, y = value, fill = F2, col = F2), group = F2) + 
    geom_bar(stat = 'identity', position = position_dodge(0.7), width = 0.6) +
    labs(x = "Gene", y = "Number of unique alleles", 
         fill = 'Clover genotype', col = 'Clover genotype') +
    scale_fill_manual(values = c("#E69F00", "#56B4E9", "#009E73", "#D55E00", "#CC79A7")) +
    scale_colour_manual(values = c("#E69F00", "#56B4E9", "#009E73", "#D55E00", "#CC79A7")) +
    theme_bw() +
    theme(axis.title = element_text(size = 22),
          axis.text.y = element_text(size = 20),
          axis.text.x = element_text(size = 20, face = "italic"),
          legend.text = element_text(size = 20),
          legend.title = element_text(size = 22))
  
)

#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Fig2/unique_allele_abundance_crossconfidential_barchart_v2.pdf', plot = bargraph, width = 20, height = 20, unit = 'cm')



# Heatmap sequence abundance for Block 1 ONLY ---------------


# # read in relative abundance counts 
data <-  read.csv('../data/data_output/abundance_data/clovergeno_allgenes_pca_matrix_withingene_ra_logtrans.csv')

# remove the env data at the end
# check in dataframe how many columns and then do four less than this to remove categorical plot variable.
x2 = ncol(data) -5 
data <- data[,1:x2]

# rename sample column name
names(data)[1] <- "sampleID"

# melt the data into a long format for graph
p1.data <- melt(data, id='sampleID')

# make the ra log value numerical
p1.data$value <- as.numeric(p1.data$value)

# Create gene column for facetting 
p2.data <- data.frame(do.call(rbind, strsplit(as.character(p1.data$variable), "_")))
p1.data$gene <- p2.data$X3  

# change labels for gene names
p1.data$gene <- factor(p1.data$gene, levels = c('rpob', 'reca', 'noda', 'nodd'),
                       labels = c('rpoB', 'recA', 'nodA', 'nodD'))

# remove Block 2 plots
p1.data <- p1.data %>%
  filter(!sampleID %in% c('7-31A', '7-31B', '7-31C', '7-18A', '7-18B',
                          '7-18C', '7-23A', '7-23B', '7-23C')) %>%
  droplevels()

# change level order for sampleID names
p1.data$sampleID <- factor(p1.data$sampleID, levels = c('6-10A', '6-10B', '6-10C', '6-24A', '6-24B',
                                                        '6-24C', '6-12A', '6-12B', '6-12C', '6-26A',
                                                        '6-26B', '6-26C', '6-16A', '6-16B', '6-16C',
                                                        '6-21A', '6-21B', '6-21C', '6-18A', '6-18B',
                                                        '6-18C', '6-23A', '6-23B', '6-23C', '6-2A',
                                                        '6-2B', '6-2C', '6-31A', '6-31B', '6-31C'))

# Heatmap   
(heatmap <-  ggplot(p1.data, aes(x=variable, y=sampleID, fill=value)) + 
    geom_tile() +
    scale_y_discrete(expand=c(0,0)) +
    scale_x_discrete(expand=c(0,0)) +
    facet_grid(~gene, switch = "x", scales = "free_x", space = "free_x") + 
    labs(x="Gene", y = "Sample ID") +
    theme_bw() +
    theme(axis.text.x=element_blank(),
          axis.ticks.x=element_blank(),
          axis.ticks.y=element_blank(),
          axis.title=element_text(size = 30),
          axis.text.y = element_text(size = 25),
          legend.text = element_text(size = 25),
          legend.title = element_blank(),
          strip.text.x = element_text(size = 25),
          strip.text = element_text(face = "italic")) +
    theme(legend.key.size = unit(1, "cm")) +
    scale_fill_viridis()
)

#function to save specific ggplot graph.  additional parameters(width=,height=,units='cm')
ggsave('../data/data_output/figures/Fig3/allgenes_clovergeno_ra_log10trans_trial156ONLY_heatmap3.pdf', plot = heatmap, width = 50, height = 23, unit = 'cm')



